@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _TASK_
 #define _TASK_
@@ -55,7 +55,7 @@ class ACTIVE_TASK {
     int _task_state;
 public:
 #ifdef _WIN32
-    HANDLE pid_handle, thread_handle, shm_handle;
+    HANDLE pid_handle, shm_handle;
     bool kill_all_children();
 #endif
     SHMEM_SEG_NAME shmem_seg_name;
@@ -92,6 +92,10 @@ public:
     int current_disk_usage(double&);
         // disk used by output files and temp files of this task
     char slot_dir[256];      // directory where process runs (relative)
+    char slot_path[512];        // same, absolute
+        // This is used only to run graphics apps
+        // (that way don't have to worry about top-level dirs
+        // being non-readable, etc).
     double max_cpu_time;    // abort if total CPU exceeds this
     double max_disk_usage;  // abort if disk usage (in+out+temp) exceeds this
     double max_mem_usage;   // abort if memory usage exceeds this
@@ -102,27 +106,31 @@ public:
     int want_network;
         // This task wants to do network comm (for F@h)
         // this is passed via share-memory message (app_status channel)
-    double abort_time;      // when we sent an abort message to this app
-                            // kill it 5 seconds later if it doesn't exit
+    double abort_time;
+        // when we sent an abort message to this app
+        // kill it 5 seconds later if it doesn't exit
+    double quit_time;
+        // when we sent a quit message; kill if still there after 10 sec
+    int premature_exit_count;
 
     APP_CLIENT_SHM app_client_shm;        // core/app shared mem
     MSG_QUEUE graphics_request_queue;
     MSG_QUEUE process_control_queue;
+    bool coprocs_reserved;
+    void reserve_coprocs();
+    void free_coprocs();
 
     // info related to app's graphics mode (win, screensaver, etc.)
     //
     int graphics_mode_acked;            // mode acked by app
     int graphics_mode_before_ss;        // mode before last screensaver request
-    bool is_ss_app;
     double graphics_mode_ack_timeout;
-    bool exit_requested;
-    int premature_exit_count;
 
 #ifdef SIM
     double cpu_time_left;
 #endif
 
-#if (defined (__APPLE__) && defined(__i386__))
+#if (defined (__APPLE__) && (defined(__i386__) || defined(__x86_64__)))
     // PowerPC apps emulated on i386 Macs crash if running graphics
     int powerpc_emulated_on_i386;
     int is_native_i386_app(char*);
@@ -173,7 +181,7 @@ public:
 #else
     void handle_exited_app(int stat);
 #endif
-    void handle_exit_external(bool&);
+    void handle_premature_exit(bool&);
 
     bool check_max_disk_exceeded();
 
@@ -228,11 +236,7 @@ public:
     bool slot_taken(int);
     void get_memory_usage();
 
-    // screensaver-related functions
-    ACTIVE_TASK* get_ss_app();
-    void save_app_modes();
-    void hide_apps();
-    void restore_apps();
+    // graphics-related functions
     void graphics_poll();
     void process_control_poll();
     void request_reread_prefs(PROJECT*);
