@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef CLIENT_MSG_LOG_H
 #define CLIENT_MSG_LOG_H
@@ -25,8 +25,10 @@
 //     msg_printf();
 // }
 
+#include <algorithm>
 #include <deque>
 #include <string>
+#include <string.h>
 
 #include "log_flags.h"
 
