@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _CLIENT_STATE_
 #define _CLIENT_STATE_
@@ -42,9 +42,9 @@ using std::vector;
 #include "pers_file_xfer.h"
 #include "prefs.h"
 #include "scheduler_op.h"
-#include "ss_logic.h"
 #include "time_stats.h"
 #include "http_curl.h"
+#include "coproc.h"
 
 #define WORK_FETCH_DONT_NEED 0
     // project: suspended, deferred, or no new work (can't ask for more work)
@@ -79,11 +79,11 @@ public:
     HOST_INFO host_info;
     GLOBAL_PREFS global_prefs;
     NET_STATS net_stats;
-    SS_LOGIC ss_logic;
     GUI_RPC_CONN_SET gui_rpcs;
     TIME_STATS time_stats;
     PROXY_INFO proxy_info;
     GUI_HTTP gui_http;
+    COPROCS coprocs;
 
     VERSION_INFO core_client_version;
     string statefile_platform_name;
@@ -158,6 +158,7 @@ public:
         // this affects auto-update
     bool run_by_updater;
     double now;
+    double client_start_time;
     double last_wakeup_time;
     bool initialized;
     bool cant_write_state_file;
@@ -201,10 +202,6 @@ public:
     double all_projects_list_check_time;
     string newer_version;
 
-// --------------- app_graphics.C:
-public:
-    ACTIVE_TASK* get_next_graphics_capable_app();
-
 // --------------- auto_update.C:
 public:
     AUTO_UPDATE auto_update;
@@ -225,10 +222,12 @@ public:
     FILE_INFO* lookup_file_info(PROJECT*, const char* name);
     RESULT* lookup_result(PROJECT*, const char*);
     WORKUNIT* lookup_workunit(PROJECT*, const char*);
-    APP_VERSION* lookup_app_version(APP*, char* platform, int ver);
+    APP_VERSION* lookup_app_version(
+        APP*, char* platform, int ver, char* plan_class
+    );
     int detach_project(PROJECT*);
     int report_result_error(RESULT&, const char *format, ...);
-    int reset_project(PROJECT*);
+    int reset_project(PROJECT*, bool detaching);
     bool no_gui_rpc;
 private:
     int link_app(PROJECT*, APP*);
@@ -265,7 +264,7 @@ private:
     bool enforce_schedule();
     bool no_work_for_a_cpu();
     void rr_simulation();
-    void make_running_task_heap(vector<ACTIVE_TASK*>&);
+    void make_running_task_heap(vector<ACTIVE_TASK*>&, double&);
     void print_deadline_misses();
 public:
     double retry_shmem_time;
@@ -293,6 +292,9 @@ public:
         // - an app fails to start (CS::schedule_cpus())
         // - any project op is done via RPC (suspend/resume)
         // - any result op is done via RPC (suspend/resume)
+    bool sufficient_coprocs(APP_VERSION&);
+    void reserve_coprocs(APP_VERSION&);
+    void free_coprocs(APP_VERSION&);
 
 // --------------- cs_account.C:
 public:
@@ -476,10 +478,6 @@ public:
 
 extern CLIENT_STATE gstate;
 
-#ifdef SANDBOX
-#define BOINC_PROJECT_GROUP_NAME "boinc_project"
-#endif
-
 // return a random double in the range [MIN,min(e^n,MAX))
 //
 extern double calculate_exponential_backoff(
