@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 // If you change anything, make sure you also change:
 // client_types.C         (to write and parse it)
@@ -34,6 +34,7 @@
 
 #include "md5_file.h"
 #include "hostinfo.h"
+#include "coproc.h"
 #include "miofile.h"
 
 #define P_LOW 1
@@ -122,9 +123,8 @@ public:
 // or the app will be connected by the given fd (in which case fd is nonzero)
 //
 struct FILE_REF {
-    char file_name[256];
-    char open_name[256];
-    int fd;
+    char file_name[256];    // physical name
+    char open_name[256];    // logical name
     bool main_program;
     FILE_INFO* file_info;
     bool copy_file;
@@ -234,6 +234,7 @@ public:
                             // use those apps rather then getting from server
     bool non_cpu_intensive;
     bool verify_files_on_app_start;
+    bool use_symlinks;
 
     // items send in scheduler replies, requesting that
     // various things be sent in the next request
@@ -405,10 +406,19 @@ struct APP_VERSION {
     char app_name[256];
     int version_num;
     char platform[256];
+    char plan_class[64];
+    char api_version[16];
+    double avg_ncpus;
+    double max_ncpus;
+    double flops;
+    char cmdline[256];      // additional cmdline args
+    COPROCS coprocs;
+
     APP* app;
     PROJECT* project;
     std::vector<FILE_REF> app_files;
     int ref_cnt;
+    char graphics_exec_path[512];
 
     APP_VERSION(){}
     ~APP_VERSION(){}
@@ -417,6 +427,7 @@ struct APP_VERSION {
     bool had_download_failure(int& failnum);
     void get_file_errors(std::string&);
     void clear_errors();
+    int api_major_version();
 };
 
 struct WORKUNIT {
@@ -450,6 +461,7 @@ struct RESULT {
     char wu_name[256];
     double report_deadline;
     int version_num;        // identifies the app used
+    char plan_class[64];
     char platform[256];
     APP_VERSION* avp;
     std::vector<FILE_REF> output_files;
@@ -534,8 +546,7 @@ struct RESULT {
         // used to keep cpu scheduler from scheduling a result twice
         // transient; used only within schedule_cpus()
     double computation_deadline();
-        // used by the CPU scheduler to determine if there is a cause for
-        // a pre-emption of running results.
+        // report deadline - prefs.work_buf_min - time slice
     bool rr_sim_misses_deadline;
     bool last_rr_sim_missed_deadline;
 
