@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(_WIN32) && !defined(__CYGWIN32__)
 
@@ -30,8 +30,13 @@
 #endif
 
 #if !defined(_WIN32) || defined(__CYGWIN32__)
-#include "config.h"
-#include <iostream>
-#include <vector>
-#include <string>
+// Please don't create a header of headers for UNIX systems.
+// This is partially causes the mess with looking for symbols named "*open64"
+// Not to mention the assumption that every source file wants these 
+// headers is wrong.
+// #include "config.h"
+// #include <iostream>
+// #include <vector>
+// #include <string>
+// #include <cstring>
 #endif
