@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #define MAX_CPU_BENCHMARKS_SECONDS	300
 #define CPU_BENCHMARKS_RUNNING		0
@@ -26,7 +26,7 @@
 #define BM_TYPE_FP       0
 #define BM_TYPE_INT      1
 
-extern void dhrystone(double& vax_mips, double& loops, double& cpu_time);
-extern void whetstone(double& flops);
+extern int dhrystone(double& vax_mips, double& loops, double& cpu_time, double min_cpu_time);
+extern int whetstone(double& flops, double& cpu_time, double min_cpu_time);
 extern void benchmark_wait_to_start(int which);
 extern bool benchmark_time_to_stop(int which);
