@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _FILE_NAMES_
 #define _FILE_NAMES_
@@ -48,7 +48,6 @@ extern void get_sched_request_filename(PROJECT&, char*, int len);
 extern void get_sched_reply_filename(PROJECT&, char*, int len);
 extern void get_master_filename(PROJECT&, char*, int len);
 extern void job_log_filename(PROJECT&, char*, int);
-extern int set_to_project_group(const char* path);
 extern void boinc_version_dir(PROJECT&, VERSION_INFO&, char*);
 extern bool is_version_dir(char*, VERSION_INFO&);
 extern void send_log_after(const char* filename, double t, MIOFILE& mf);
@@ -69,7 +68,6 @@ extern void send_log_after(const char* filename, double t, MIOFILE& mf);
 #define STDERR_FILE_NAME            "stderr.txt"
 #define STDOUT_FILE_NAME            "stdout.txt"
 #define CPU_BENCHMARKS_FILE_NAME    "cpu_benchmarks"
-#define LOCK_FILE_NAME              "lockfile"
 #define APP_INFO_FILE_NAME			"app_info.xml"
 #define REMOTEHOST_FILE_NAME        "remote_hosts.cfg"
 #define ACCT_MGR_REQUEST_FILENAME   "acct_mgr_request.xml"
@@ -90,5 +88,6 @@ extern void send_log_after(const char* filename, double t, MIOFILE& mf);
 #define TIME_STATS_LOG              "time_stats_log"
 #define JOB_LOG_BASE                "job_log_"
 #define CA_BUNDLE_FILENAME          "ca-bundle.crt"
+#define CLIENT_AUTH_FILENAME        "client_auth.xml"
 
 #endif
