@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 // keep track of the network performance of this host,
 // namely exponentially weighted averages of upload and download speeds
@@ -101,7 +101,6 @@ public:
 // It is used ONLY from the HTTP code, when a transaction fails
 //
 struct LOOKUP_WEBSITE_OP: public GUI_HTTP_OP {
-public:
     int error_num;
 
     virtual ~LOOKUP_WEBSITE_OP(){}
