@@ -133,6 +133,7 @@ public:
     GLOBAL_PREFS global_prefs;
     SIM_HOST host_info;
     TIME_STATS time_stats;
+    COPROCS coprocs;
     CLIENT_STATE();
     bool initialized;
     bool run_cpu_benchmarks;
@@ -177,7 +178,7 @@ private:
     bool enforce_schedule();
     bool no_work_for_a_cpu();
     void rr_simulation();
-    void make_running_task_heap(vector<ACTIVE_TASK*>&);
+    void make_running_task_heap(vector<ACTIVE_TASK*>&, double&);
     void print_deadline_misses();
 public:
     double retry_shmem_time;
@@ -195,6 +196,9 @@ public:
 
     void request_enforce_schedule(const char*);
     void request_schedule_cpus(const char*);
+    bool sufficient_coprocs(APP_VERSION&);
+    void reserve_coprocs(APP_VERSION&);
+    void free_coprocs(APP_VERSION&);
 
 // --------------- cs_apps.C:
 private:
@@ -216,7 +220,6 @@ public:
     double estimate_cpu_time(WORKUNIT&);
     double get_fraction_done(RESULT* result);
     int input_files_available(RESULT*, bool, FILE_INFO** f=0);
-    ACTIVE_TASK* get_next_graphics_capable_app();
     int ncpus;
         // number of usable cpus
 private:
