@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _TIME_STATS_
 #define _TIME_STATS_
@@ -60,6 +60,7 @@ public:
     void log_append_net(int);
     void trim_stats_log();
     void get_log_after(double, MIOFILE&);
+    void start();
     void quit();
 };
 
