@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "BOINCBaseFrame.h"
@@ -32,6 +32,7 @@
 #include "BOINCGUIApp.h"
 #include "SkinManager.h"
 #include "MainDocument.h"
+#include "BOINCClientManager.h"
 #include "BOINCTaskBar.h"
 #include "BOINCBaseFrame.h"
 #include "BOINCDialupManager.h"
@@ -79,6 +80,7 @@ CBOINCBaseFrame::CBOINCBaseFrame(wxWindow* parent, const wxWindowID id, const wx
 
     m_aSelectedComputerMRU.Clear();
 
+    m_bShowConnectionFailedAlert = false;
 
     m_pDialupManager = new CBOINCDialUpManager();
     wxASSERT(m_pDialupManager->IsOk());
@@ -170,6 +172,11 @@ void CBOINCBaseFrame::OnAlertPoll(wxTimerEvent& WXUNUSED(event)) {
             }
         }
 
+        if (m_bShowConnectionFailedAlert && IsShown()) {
+            m_bShowConnectionFailedAlert = false;
+            ShowConnectionFailedAlert();
+        }
+
         bAlreadyRunningLoop = false;
     }
 }
@@ -177,16 +184,6 @@ void CBOINCBaseFrame::OnAlertPoll(wxTimerEvent& WXUNUSED(event)) {
 
 void CBOINCBaseFrame::OnInitialized(CFrameEvent& WXUNUSED(event)) {
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseFrame::OnInitialized - Function Begin"));
-
-    CMainDocument*     pDoc = wxGetApp().GetDocument();
-
-    wxASSERT(pDoc);
-    wxASSERT(wxDynamicCast(pDoc, CMainDocument));
-
-    if (!pDoc->IsConnected()) {
-        pDoc->Connect(wxT("localhost"), wxEmptyString, TRUE, TRUE);
-    }
-
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseFrame::OnInitialized - Function End"));
 }
 
@@ -240,24 +237,21 @@ void CBOINCBaseFrame::OnAlert(CFrameAlertEvent& event) {
                 icon_type
             );
         }
-#else
-        // Notification only events on platforms other than Windows are currently
-        //   discarded.  On the Mac a model dialog box for a hidden window causes
-        //   the menus to be locked and the application to become unresponsive. On
-        //   Linux the application is restored and input focus is set on the
-        //   notification which interrupts whatever the user was up to.
+#elif defined (__WXMAC__)
+        // wxMessageBox() / ProcessResponse() hangs the Manager if hidden.
+        // Currently, the only non-notification-only alert is Connection Failed,
+        // which is now has logic to be displayed when Manager is maximized.
+
+        // Notification only events on platforms other than Windows are 
+        //   currently discarded.  Otherwise the application would be restored 
+        //   and input focus set on the notification which interrupts whatever 
+        //   the user was doing.
         if (IsShown() && !event.m_notification_only) {
-            if (!event.m_notification_only) {
-                int retval = 0;
+            int retval = 0;
 
-                if (!IsShown()) {
-                    Show();
-                }
-
-                retval = ::wxMessageBox(event.m_message, event.m_title, event.m_style, this);
-                if (event.m_alert_event_type == AlertProcessResponse) {
-                    event.ProcessResponse(retval);
-                }
+            retval = ::wxMessageBox(event.m_message, event.m_title, event.m_style, this);
+            if (event.m_alert_event_type == AlertProcessResponse) {
+                event.ProcessResponse(retval);
             }
         }
 #endif
@@ -344,7 +338,7 @@ void CBOINCBaseFrame::FireReloadSkin() {
 }
 
 
-void CBOINCBaseFrame::ShowConnectionBadPasswordAlert( bool bUsedDefaultPassword ) {
+void CBOINCBaseFrame::ShowConnectionBadPasswordAlert( bool bUsedDefaultPassword, int m_iReadGUIRPCAuthFailure ) {
     CSkinAdvanced*      pSkinAdvanced = wxGetApp().GetSkinManager()->GetAdvanced();
     wxString            strDialogTitle = wxEmptyString;
 
@@ -363,12 +357,29 @@ void CBOINCBaseFrame::ShowConnectionBadPasswordAlert( bool bUsedDefaultPassword
     );
 
     if ( bUsedDefaultPassword ) {
-        ShowAlert(
-            strDialogTitle,
-            _("Authorization failed connecting to running client.\n"
-              "Make sure you start this program in the same directory as the client."),
-            wxOK | wxICON_ERROR
-        );
+#ifdef __WXMSW__
+        if ( EACCES == m_iReadGUIRPCAuthFailure || ENOENT == m_iReadGUIRPCAuthFailure ) {
+            ShowAlert(
+                strDialogTitle,
+                _("You currently are not authorized to manage the client.\n"
+                  "Please contact your administrator to add you to the 'boinc_users' local user group."),
+                wxOK | wxICON_ERROR
+            );
+        } else 
+#endif
+        {
+            ShowAlert(
+                strDialogTitle,
+#ifndef __WXMAC__
+                _("Authorization failed connecting to running client."
+                  "\nMake sure you start this program in the same directory as the client."
+                ),
+#else
+                _("Authorization failed connecting to running client."),
+#endif
+                wxOK | wxICON_ERROR
+            );
+        }
     } else {
         ShowAlert(
             strDialogTitle,
@@ -383,20 +394,30 @@ void CBOINCBaseFrame::ShowConnectionBadPasswordAlert( bool bUsedDefaultPassword
 
 void CBOINCBaseFrame::ShowConnectionFailedAlert() {
     CSkinAdvanced*      pSkinAdvanced = wxGetApp().GetSkinManager()->GetAdvanced();
+    CMainDocument*      pDoc = wxGetApp().GetDocument();
+    wxString            strConnectedCompter = wxEmptyString;
     wxString            strDialogTitle = wxEmptyString;
     wxString            strDialogMessage = wxEmptyString;
 
-
     wxASSERT(pSkinAdvanced);
     wxASSERT(wxDynamicCast(pSkinAdvanced, CSkinAdvanced));
 
+    wxASSERT(pDoc);
+    wxASSERT(wxDynamicCast(pDoc, CMainDocument));
 
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseFrame::ShowConnectionFailedAlert - Function Begin"));
 
-
-    // Did BOINC crash? If so restart it.
-    wxGetApp().AutoRestartBOINC();
-
+    // Did BOINC crash on local computer? If so restart it and reconnect.
+    pDoc->GetConnectedComputerName(strConnectedCompter);
+    if (pDoc->IsComputerNameLocal(strConnectedCompter)) {
+        if (pDoc->m_pClientManager->AutoRestart()) {
+            boinc_sleep(0.5);       // Allow time for Client to restart
+            if (pDoc->m_pClientManager->IsBOINCCoreRunning()) {
+                pDoc->Reconnect();        
+                return;
+            }
+        }
+    }
 
     // %s is the application name
     //    i.e. 'BOINC Manager', 'GridRepublic Manager'
@@ -413,7 +434,7 @@ void CBOINCBaseFrame::ShowConnectionFailedAlert() {
         _("%s is not able to connect to a %s client.\n"
           "Would you like to try to connect again?"),
         pSkinAdvanced->GetApplicationName().c_str(),
-        pSkinAdvanced->GetProjectName().c_str()
+        pSkinAdvanced->GetApplicationShortName().c_str()
     );
 
     ShowAlert(
@@ -424,11 +445,14 @@ void CBOINCBaseFrame::ShowConnectionFailedAlert() {
         AlertProcessResponse
     );
 
+    // If we are minimized, set flag to show alert when maximized
+    m_bShowConnectionFailedAlert = !IsShown();
+    
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseFrame::ShowConnectionFailedAlert - Function End"));
 }
 
 
-void CBOINCBaseFrame::ShowNotCurrentlyConnectedAlert() {
+void CBOINCBaseFrame::ShowDaemonStartFailedAlert() {
     CSkinAdvanced*      pSkinAdvanced = wxGetApp().GetSkinManager()->GetAdvanced();
     wxString            strDialogTitle = wxEmptyString;
     wxString            strDialogMessage = wxEmptyString;
@@ -438,13 +462,74 @@ void CBOINCBaseFrame::ShowNotCurrentlyConnectedAlert() {
     wxASSERT(wxDynamicCast(pSkinAdvanced, CSkinAdvanced));
 
 
+    wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseFrame::ShowDaemonStartFailedAlert - Function Begin"));
+
+
+    // %s is the application name
+    //    i.e. 'BOINC Manager', 'GridRepublic Manager'
+    strDialogTitle.Printf(
+        _("%s - Daemon Start Failed"),
+        pSkinAdvanced->GetApplicationName().c_str()
+    );
+
+    // 1st %s is the application name
+    //    i.e. 'BOINC Manager', 'GridRepublic Manager'
+    // 2st %s is the project name
+    //    i.e. 'BOINC', 'GridRepublic'
+#ifdef __WXMSW__
+    strDialogMessage.Printf(
+        _("%s is not able to start a %s client.\n"
+          "Please launch the Control Panel->Administative Tools->Services "
+          "applet and start the BOINC service."),
+        pSkinAdvanced->GetApplicationName().c_str(),
+        pSkinAdvanced->GetApplicationShortName().c_str()
+    );
+#else
+    strDialogMessage.Printf(
+        _("%s is not able to start a %s client.\n"
+          "Please start the daemon and try again."),
+        pSkinAdvanced->GetApplicationName().c_str(),
+        pSkinAdvanced->GetApplicationShortName().c_str()
+    );
+#endif
+
+    ShowAlert(
+        strDialogTitle,
+        strDialogMessage,
+        wxOK | wxICON_ERROR
+    );
+
+    wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseFrame::ShowDaemonStartFailedAlert - Function End"));
+}
+
+
+void CBOINCBaseFrame::ShowNotCurrentlyConnectedAlert() {
+    CSkinAdvanced*      pSkinAdvanced = wxGetApp().GetSkinManager()->GetAdvanced();
+    CMainDocument*      pDoc = wxGetApp().GetDocument();
+    wxString            strConnectedCompter = wxEmptyString;
+    wxString            strDialogTitle = wxEmptyString;
+    wxString            strDialogMessage = wxEmptyString;
+
+    wxASSERT(pSkinAdvanced);
+    wxASSERT(wxDynamicCast(pSkinAdvanced, CSkinAdvanced));
+
+    wxASSERT(pDoc);
+    wxASSERT(wxDynamicCast(pDoc, CMainDocument));
+
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseFrame::ShowNotCurrentlyConnectedAlert - Function Begin"));
 
-
-    // Did BOINC crash? If so restart it.
-    wxGetApp().AutoRestartBOINC();
-
-
+    // Did BOINC crash on local computer? If so restart it and reconnect.
+    pDoc->GetConnectedComputerName(strConnectedCompter);
+    if (pDoc->IsComputerNameLocal(strConnectedCompter)) {
+        if (pDoc->m_pClientManager->AutoRestart()) {
+            boinc_sleep(0.5);       // Allow time for Client to restart
+            if (pDoc->m_pClientManager->IsBOINCCoreRunning()) {
+                pDoc->Reconnect();        
+                return;
+            }
+        }
+    }
+    
     // %s is the application name
     //    i.e. 'BOINC Manager', 'GridRepublic Manager'
     strDialogTitle.Printf(
@@ -463,8 +548,8 @@ void CBOINCBaseFrame::ShowNotCurrentlyConnectedAlert() {
           "Please use the 'Advanced\\Select Computer...' menu option to connect up to a %s client.\n"
           "To connect up to your local computer please use 'localhost' as the host name."),
         pSkinAdvanced->GetApplicationName().c_str(),
-        pSkinAdvanced->GetProjectName().c_str(),
-        pSkinAdvanced->GetProjectName().c_str()
+        pSkinAdvanced->GetApplicationShortName().c_str(),
+        pSkinAdvanced->GetApplicationShortName().c_str()
     );
     ShowAlert(
         strDialogTitle,
@@ -654,4 +739,4 @@ void CFrameAlertEvent::ProcessResponse(const int response) const {
 }
 
 
-const char *BOINC_RCSID_0a1bd38a5b = "$Id: BOINCBaseFrame.cpp 12704 2007-05-21 16:07:10Z romw $";
+const char *BOINC_RCSID_0a1bd38a5b = "$Id: BOINCBaseFrame.cpp 15524 2008-07-01 04:19:29Z charlief $";
