@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "BOINCBaseView.h"
@@ -46,6 +46,7 @@ CBOINCBaseView::CBOINCBaseView(wxNotebook* pNotebook) :
     m_bProcessingListRenderEvent = false;
 
     m_bForceUpdateSelection = true;
+    m_bIgnoreUIEvents = false;
 
     //
     // Setup View
@@ -69,6 +70,7 @@ CBOINCBaseView::CBOINCBaseView(
     m_bProcessingListRenderEvent = false;
 
     m_bForceUpdateSelection = true;
+    m_bIgnoreUIEvents = false;
 
     //
     // Setup View
@@ -290,9 +292,11 @@ bool CBOINCBaseView::OnRestoreState(wxConfigBase* pConfig) {
 void CBOINCBaseView::OnListSelected(wxListEvent& event) {
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseView::OnListSelected - Function Begin"));
 
-    m_bForceUpdateSelection = true;
-    UpdateSelection();
-    event.Skip();
+    if (!m_bIgnoreUIEvents) {
+        m_bForceUpdateSelection = true;
+        UpdateSelection();
+        event.Skip();
+    }
 
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseView::OnListSelected - Function End"));
 }
@@ -301,9 +305,11 @@ void CBOINCBaseView::OnListSelected(wxListEvent& event) {
 void CBOINCBaseView::OnListDeselected(wxListEvent& event) {
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseView::OnListDeselected - Function Begin"));
 
-    m_bForceUpdateSelection = true;
-    UpdateSelection();
-    event.Skip();
+    if (!m_bIgnoreUIEvents) {
+        m_bForceUpdateSelection = true;
+        UpdateSelection();
+        event.Skip();
+    }
 
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseView::OnListDeselected - Function End"));
 }
@@ -327,9 +333,11 @@ wxListItemAttr* CBOINCBaseView::OnListGetItemAttr(long WXUNUSED(item)) const {
 void CBOINCBaseView::OnGridSelectCell( wxGridEvent& event ) {
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseView::OnGridSelectCell - Function Begin"));
 
-	m_bForceUpdateSelection = true;
-    UpdateSelection();
-    event.Skip();
+    if (!m_bIgnoreUIEvents) {
+	    m_bForceUpdateSelection = true;
+        UpdateSelection();
+        event.Skip();
+    }
 
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseView::OnGridSelectCell - Function End"));
 }
@@ -337,9 +345,11 @@ void CBOINCBaseView::OnGridSelectCell( wxGridEvent& event ) {
 void CBOINCBaseView::OnGridSelectRange( wxGridRangeSelectEvent& event ) {
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseView::OnGridSelectRange - Function Begin"));
 
-    m_bForceUpdateSelection = true;
-    UpdateSelection();
-	event.Skip();
+    if (!m_bIgnoreUIEvents) {
+        m_bForceUpdateSelection = true;
+        UpdateSelection();
+	    event.Skip();
+    }
 
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseView::OnGridSelectRange - Function End"));
 }
@@ -804,4 +814,4 @@ wxString CBOINCBaseView::HtmlEntityDecode(wxString strRaw) {
 }
 
 
-const char *BOINC_RCSID_0a1bd38a5a = "$Id: BOINCBaseView.cpp 12764 2007-05-29 16:16:33Z romw $";
+const char *BOINC_RCSID_0a1bd38a5a = "$Id: BOINCBaseView.cpp 14938 2008-03-18 18:19:49Z romw $";
