@@ -71,6 +71,7 @@ bool CBOINCGUIApp::OnInit() {
     // Setup variables with default values
     m_strBOINCArguments = wxEmptyString;
     m_strBOINCMGRRootDirectory = wxEmptyString;
+    m_strBOINCMGRDataDirectory = wxEmptyString;
     m_pLocale = NULL;
     m_pSkinManager = NULL;
     m_pFrame = NULL;
@@ -323,6 +324,27 @@ bool CBOINCGUIApp::OnInit() {
         m_pConfig->Read(wxT("Skin"), m_pSkinManager->GetDefaultSkinName())
     );
 
+
+    // Perform any last minute checks that should keep the manager
+    // from starting up.
+    wxString strRebootPendingFile = 
+        GetRootDirectory() + wxFileName::GetPathSeparator() + wxT("RebootPending.txt");
+    
+    wxFileInputStream fisRebootPending(strRebootPendingFile);
+    if (fisRebootPending.IsOk()) {
+
+        wxMessageDialog dialog(
+            NULL,
+            _("A reboot is required in order for BOINC to run properly.\nPlease reboot your computer and try again."),
+            _("BOINC Manager"),
+            wxOK|wxICON_ERROR
+        );
+
+        dialog.ShowModal();
+        return false;
+    }
+
+
     // Initialize the main document
     m_pDocument = new CMainDocument();
     wxASSERT(m_pDocument);
@@ -749,4 +771,4 @@ int CBOINCGUIApp::ConfirmExit() {
 }
 
 
-const char *BOINC_RCSID_487cbf3018 = "$Id: BOINCGUIApp.cpp 15451 2008-06-23 17:57:07Z romw $";
+const char *BOINC_RCSID_487cbf3018 = "$Id: BOINCGUIApp.cpp 15611 2008-07-16 17:00:15Z romw $";
