@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _BOINCGUIAPP_H_
 #define _BOINCGUIAPP_H_
@@ -52,11 +52,7 @@ protected:
 
     void                InitSupportedLanguages();
 
-    bool                IsBOINCCoreRunning();
-    void                StartupBOINCCore();
-    void                ShutdownBOINCCore();
 #ifdef __WXMAC__
-    bool                ProcessExists(pid_t thePID);
     static OSErr        QuitAppleEventHandler( const AppleEvent *appleEvt, AppleEvent* reply, UInt32 refcon );
 #endif
 
@@ -73,11 +69,10 @@ protected:
     CTaskBarIcon*       m_pTaskBarIcon;
 #ifdef __WXMAC__
     CMacSystemMenu*     m_pMacSystemMenu;
-    bool                m_bClientRunningAsDaemon;
 #endif
 
-    bool                m_bBOINCStartedByManager;
     wxString            m_strBOINCMGRRootDirectory;
+    wxString            m_strBOINCMGRDataDirectory;
     wxString            m_strBOINCArguments;
 
     int                 m_iDisplayExitWarning;
@@ -85,10 +80,7 @@ protected:
     bool                m_bGUIVisible;
     int                 m_iGUISelected;
 
-    int                 m_lBOINCCoreProcessId;
-
 #ifdef __WXMSW__
-    HANDLE              m_hBOINCCoreProcess;
     HINSTANCE           m_hClientLibraryDll;
 #endif
 
@@ -104,8 +96,6 @@ public:
 
     bool                OnInit();
 
-    bool                AutoRestartBOINC();
-
     int                 UpdateSystemIdleDetection();
 
     int                 StartBOINCScreensaverTest();
@@ -114,6 +104,9 @@ public:
     CSkinManager*       GetSkinManager()            { return m_pSkinManager; }
     CBOINCBaseFrame*    GetFrame()                  { return m_pFrame; }
     CMainDocument*      GetDocument()               { return m_pDocument; }
+    wxString            GetArguments()              { return m_strBOINCArguments; }
+    wxString            GetRootDirectory()          { return m_strBOINCMGRRootDirectory; }
+    wxString            GetDataDirectory()          { return m_strBOINCMGRDataDirectory; }
 #if defined(__WXMSW__) || defined(__WXMAC__)
     CTaskBarIcon*       GetTaskBarIcon()            { return m_pTaskBarIcon; }
 #endif
