@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "BOINCListCtrl.h"
@@ -203,4 +203,4 @@ wxListItemAttr* CBOINCListCtrl::OnGetItemAttr(long item) const {
 }
 
 
-const char *BOINC_RCSID_5cf411daa0 = "$Id: BOINCListCtrl.cpp 12125 2007-02-21 04:56:46Z charlief $";
+const char *BOINC_RCSID_5cf411daa0 = "$Id: BOINCListCtrl.cpp 13804 2007-10-09 11:35:47Z fthomas $";
