@@ -381,7 +381,8 @@ void CTaskBarIcon::OnMouseMove(wxTaskBarIconEvent& WXUNUSED(event)) {
                 //   enough room to display them all, so just tell the user how many are
                 //   currently running.
                 strBuffer.Printf(
-                    _("%d tasks running.")
+                    _("%d tasks running."),
+                    iActiveTaskCount
                 );
                 if (strMessage.Length() > 0) strMessage += wxT("\n");
                 strMessage += strBuffer;
@@ -688,4 +689,4 @@ void CTaskBarIcon::AdjustMenuItems(wxMenu* pMenu) {
     }
 }
 
-const char *BOINC_RCSID_531575eeaa = "$Id: BOINCTaskBar.cpp 15481 2008-06-26 16:20:03Z romw $";
+const char *BOINC_RCSID_531575eeaa = "$Id: BOINCTaskBar.cpp 15595 2008-07-11 16:20:52Z romw $";
