@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _BOINCTASKBAR_H_
 #define _BOINCTASKBAR_H_
@@ -64,7 +64,7 @@ public:
 
 #ifdef __APPLE__
     wxMenu *CreatePopupMenu();
-    bool SetIcon(const wxIcon& icon, const wxString& tooltip);
+    bool SetIcon(const wxIcon& icon);
 #endif
 
 #ifndef __WXMSW__
@@ -81,7 +81,6 @@ public:
 
 private:
     wxDateTime m_dtLastHoverDetected;
-    wxDateTime m_dtLastBalloonDisplayed;
 
     wxTimer*   m_pRefreshTimer;
 
