@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "BOINCTaskCtrl.h"
@@ -236,4 +236,4 @@ bool CBOINCTaskCtrl::OnRestoreState(wxConfigBase* pConfig) {
 }
 
 
-const char *BOINC_RCSID_125ef3d14d = "$Id: BOINCTaskCtrl.cpp 6788 2005-07-24 08:35:57Z rwalton $";
+const char *BOINC_RCSID_125ef3d14d = "$Id: BOINCTaskCtrl.cpp 13804 2007-10-09 11:35:47Z fthomas $";
