@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "DlgAdvPreferences.h"
@@ -230,7 +230,7 @@ void CDlgAdvPreferences::ReadPreferenceSettings() {
 	buffer.Printf(wxT("%.2f"),prefs.cpu_scheduling_period_minutes);
 	*m_txtProcSwitchEvery << buffer;
 	// max cpus
-	buffer.Printf(wxT("%d"),prefs.max_cpus);
+	buffer.Printf(wxT("%.2f"),prefs.max_ncpus_pct);
 	*m_txtProcUseProcessors << buffer;
 	//cpu limit
 	buffer.Printf(wxT("%.2f"),prefs.cpu_usage_limit);
@@ -303,7 +303,6 @@ void CDlgAdvPreferences::ReadPreferenceSettings() {
 /* write overridden preferences to disk (global_prefs_override.xml) */
 bool CDlgAdvPreferences::SavePreferencesSettings() {
 	double td;
-	long tl;
 
 	mask.clear();
 	//clear special times settings
@@ -317,8 +316,8 @@ bool CDlgAdvPreferences::SavePreferencesSettings() {
 	mask.run_if_user_active=true;
 	//
 	if(m_txtProcIdleFor->IsEnabled()) {
-		m_txtProcIdleFor->GetValue().ToLong(&tl);
-		prefs.idle_time_to_run=tl;
+		m_txtProcIdleFor->GetValue().ToDouble(&td);
+		prefs.idle_time_to_run=td;
 		mask.idle_time_to_run=true;
 	}
 	//
@@ -345,9 +344,11 @@ bool CDlgAdvPreferences::SavePreferencesSettings() {
 	prefs.cpu_scheduling_period_minutes=td;
 	mask.cpu_scheduling_period_minutes=true;
 	//
-	m_txtProcUseProcessors->GetValue().ToLong(&tl);
-	prefs.max_cpus=tl;;
-	mask.max_cpus=true;
+
+	m_txtProcUseProcessors->GetValue().ToDouble(&td);
+	prefs.max_ncpus_pct=td;
+	mask.max_ncpus_pct=true;
+
 	//
 	m_txtProcUseCPUTime->GetValue().ToDouble(&td);
 	prefs.cpu_usage_limit=td;
@@ -684,7 +685,7 @@ void CDlgAdvPreferences::OnOK(wxCommandEvent& ev) {
 
 // handles Help button clicked
 void CDlgAdvPreferences::OnHelp(wxCommandEvent& ev) {
-	wxString url = wxGetApp().GetSkinManager()->GetAdvanced()->GetCompanyWebsite();
+	wxString url = wxGetApp().GetSkinManager()->GetAdvanced()->GetOrganizationWebsite();
 	url += wxT("/prefs.php");//this seems not the right url, but which instead ?
 	wxHyperLink::ExecuteLink(url);
 	ev.Skip();
