@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "DlgSelectComputer.h"
@@ -211,4 +211,4 @@ void CDlgSelectComputer::OnComputerNameUpdated( wxCommandEvent& WXUNUSED(event)
     }
 }
 
-const char *BOINC_RCSID_28d78701f5="$Id: DlgSelectComputer.cpp 13418 2007-08-20 20:01:32Z romw $";
+const char *BOINC_RCSID_28d78701f5="$Id: DlgSelectComputer.cpp 13804 2007-10-09 11:35:47Z fthomas $";
