@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "Localization.h"
@@ -160,4 +160,4 @@ CLocalization::CLocalization() {
 
 }
 
-const char *BOINC_RCSID_4632804e37="$Id: Localization.cpp 9032 2005-12-04 22:17:07Z jens $";
+const char *BOINC_RCSID_4632804e37="$Id: Localization.cpp 13804 2007-10-09 11:35:47Z fthomas $";
