@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "LogBOINC.h"
@@ -41,4 +41,4 @@ void wxLogBOINC::DoLogString(const wxChar *szString, time_t t) {
     wxLogStderr::DoLogString(szString, t);
 }
 
-const char *BOINC_RCSID_4f7bf42814="$Id: LogBOINC.cpp 5940 2005-04-27 01:34:35Z rwalton $";
+const char *BOINC_RCSID_4f7bf42814="$Id: LogBOINC.cpp 13804 2007-10-09 11:35:47Z fthomas $";
