@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "MainDocument.h"
@@ -25,10 +25,14 @@
 
 #include "error_numbers.h"
 #include "util.h"
+#ifdef _WIN32
+#include "proc_control.h"
+#endif
 
 #include "BOINCGUIApp.h"
 #include "BOINCBaseFrame.h"
 #include "MainDocument.h"
+#include "BOINCClientManager.h"
 
 #ifndef _WIN32
 #include <sys/wait.h>
@@ -38,6 +42,8 @@
 #include <grp.h>
 #endif
 
+bool g_use_sandbox = false;
+
 using std::string;
 
 CNetworkConnection::CNetworkConnection(CMainDocument* pDocument) :
@@ -56,6 +62,8 @@ CNetworkConnection::CNetworkConnection(CMainDocument* pDocument) :
     m_bReconnectOnError = false;
     m_bNewConnection = false;
     m_bUsedDefaultPassword = false;
+    m_iPort = GUI_RPC_PORT,
+    m_iReadGUIRPCAuthFailure = 0;
 }
 
 
@@ -63,12 +71,12 @@ CNetworkConnection::~CNetworkConnection() {
 }
 
 
-void CNetworkConnection::GetLocalPassword(wxString& strPassword){
+int CNetworkConnection::GetLocalPassword(wxString& strPassword){
     char buf[256];
+    strcpy(buf, "");
 
     FILE* f = fopen("gui_rpc_auth.cfg", "r");
-    if (!f) return;
-    strcpy(buf, "");
+    if (!f) return errno;
     fgets(buf, 256, f);
     fclose(f);
     int n = (int)strlen(buf);
@@ -78,7 +86,9 @@ void CNetworkConnection::GetLocalPassword(wxString& strPassword){
             buf[n] = 0;
         }
     }
+
     strPassword = wxString(buf, wxConvUTF8);
+    return 0;
 }
 
 
@@ -96,9 +106,11 @@ void CNetworkConnection::Poll() {
             // Wait until we can establish a connection to the core client before reading
             //   the password so that the client has time to create one when it needs to.
             if (m_bUseDefaultPassword) {
-                GetLocalPassword(m_strNewComputerPassword);
+                m_iReadGUIRPCAuthFailure = 0;
                 m_bUseDefaultPassword = FALSE;
                 m_bUsedDefaultPassword = true;
+
+                m_iReadGUIRPCAuthFailure = GetLocalPassword(m_strNewComputerPassword);
             }
 
             retval = m_pDocument->rpc.authorize(m_strNewComputerPassword.mb_str());
@@ -149,9 +161,9 @@ void CNetworkConnection::Poll() {
             //   timeout event right after boot-up.
             //
             if (IsComputerNameLocal(strComputer)) {
-                retval = m_pDocument->rpc.init_asynch(NULL, 60.0, true);
+                retval = m_pDocument->rpc.init_asynch(NULL, 60.0, true, m_iPort);
             } else {
-                retval = m_pDocument->rpc.init_asynch(strComputer.mb_str(), 60.0, false);
+                retval = m_pDocument->rpc.init_asynch(strComputer.mb_str(), 60.0, false, m_iPort);
             }
 
             if (!retval) {
@@ -189,28 +201,42 @@ int CNetworkConnection::GetConnectingComputerName(wxString& strMachine) {
 
 
 bool CNetworkConnection::IsComputerNameLocal(const wxString& strMachine) {
+    static wxString strHostName = wxEmptyString;
+    static wxString strFullHostName = wxEmptyString;
+
+    if (strHostName.empty()) {
+        strHostName = ::wxGetHostName().Lower();
+    }
+    if (strFullHostName.empty()) {
+        strFullHostName = ::wxGetFullHostName().Lower();
+    }
+
     if (strMachine.empty()) {
         return true;
     } else if (wxT("localhost") == strMachine.Lower()) {
         return true;
     } else if (wxT("localhost.localdomain") == strMachine.Lower()) {
         return true;
-    } else if (::wxGetHostName().Lower() == strMachine.Lower()) {
+    } else if (strHostName == strMachine.Lower()) {
         return true;
-    } else if (::wxGetFullHostName().Lower() == strMachine.Lower()) {
+    } else if (strFullHostName == strMachine.Lower()) {
         return true;
     }
     return false;
 }
 
 
-int CNetworkConnection::SetComputer(const wxChar* szComputer, const wxChar* szPassword,  const bool bUseDefaultPassword) {
+int CNetworkConnection::SetComputer(
+    const wxChar* szComputer, const int iPort, const wxChar* szPassword,
+    const bool bUseDefaultPassword
+) {
     m_strNewComputerName.Empty();
     m_strNewComputerPassword.Empty();
     m_bUseDefaultPassword = FALSE;
 
     m_bNewConnection = true;
     m_strNewComputerName = szComputer;
+    m_iPort = iPort;
     m_strNewComputerPassword = szPassword;
     m_bUseDefaultPassword = bUseDefaultPassword;
     return 0;
@@ -227,7 +253,7 @@ void CNetworkConnection::SetStateErrorAuthentication() {
 
         m_bConnectEvent = false;
 
-        pFrame->ShowConnectionBadPasswordAlert(m_bUsedDefaultPassword);
+        pFrame->ShowConnectionBadPasswordAlert(m_bUsedDefaultPassword, m_iReadGUIRPCAuthFailure);
     }
 }
 
@@ -306,6 +332,7 @@ IMPLEMENT_DYNAMIC_CLASS(CMainDocument, wxObject)
 
 
 CMainDocument::CMainDocument() {
+
 #ifdef __WIN32__
     int retval;
     WSADATA wsdata;
@@ -316,6 +343,8 @@ CMainDocument::CMainDocument() {
     }
 #endif
 
+    m_bClientStartCheckCompleted = false;
+
     m_fProjectTotalResourceShare = 0.0;
 
     m_iMessageSequenceNumber = 0;
@@ -324,20 +353,102 @@ CMainDocument::CMainDocument() {
     m_dtCachedCCStatusTimestamp = wxDateTime((time_t)0);
     m_dtProjecStatusTimestamp = wxDateTime((time_t)0);
     m_dtResultsTimestamp = wxDateTime((time_t)0);
+    m_dtKillInactiveGfxTimestamp = wxDateTime((time_t)0);
     m_dtFileTransfersTimestamp = wxDateTime((time_t)0);
     m_dtDiskUsageTimestamp = wxDateTime((time_t)0);
     m_dtStatisticsStatusTimestamp = wxDateTime((time_t)0);
-	m_dtCachedSimpleGUITimestamp = wxDateTime((time_t)0);
+    m_dtCachedSimpleGUITimestamp = wxDateTime((time_t)0);
 }
 
 
 CMainDocument::~CMainDocument() {
+    KillAllRunningGraphicsApps();
 #ifdef __WIN32__
     WSACleanup();
 #endif
 }
 
 
+int CMainDocument::OnInit() {
+    int iRetVal = -1;
+
+    m_pNetworkConnection = new CNetworkConnection(this);
+    wxASSERT(m_pNetworkConnection);
+
+    m_pClientManager = new CBOINCClientManager();
+    wxASSERT(m_pClientManager);
+
+    return iRetVal;
+}
+
+
+int CMainDocument::OnExit() {
+    int iRetVal = 0;
+
+    if (m_pClientManager) {
+        m_pClientManager->ShutdownBOINCCore();
+
+        delete m_pClientManager;
+        m_pClientManager = NULL;
+    }
+
+    if (m_pNetworkConnection) {
+        delete m_pNetworkConnection;
+        m_pNetworkConnection = NULL;
+    }
+
+    return iRetVal;
+}
+
+
+int CMainDocument::OnPoll() {
+    int iRetVal = 0;
+
+    wxASSERT(wxDynamicCast(m_pClientManager, CBOINCClientManager));
+    wxASSERT(wxDynamicCast(m_pNetworkConnection, CNetworkConnection));
+
+    if (!m_bClientStartCheckCompleted) {
+        m_bClientStartCheckCompleted = true;
+
+        CBOINCBaseFrame* pFrame = wxGetApp().GetFrame();
+        wxASSERT(wxDynamicCast(pFrame, CBOINCBaseFrame));
+
+        pFrame->UpdateStatusText(_("Starting client services; please wait..."));
+
+        if (m_pClientManager->StartupBOINCCore()) {
+            Connect(wxT("localhost"), GUI_RPC_PORT, wxEmptyString, TRUE, TRUE);
+        } else {
+            m_pNetworkConnection->ForceDisconnect();
+            pFrame->ShowDaemonStartFailedAlert();
+        }
+
+        pFrame->UpdateStatusText(wxEmptyString);
+    }
+
+    // Check connection state, connect if needed.
+    m_pNetworkConnection->Poll();
+
+    // Every 10 seconds, kill any running graphics apps 
+    // whose associated worker tasks are no longer running
+    wxTimeSpan ts(wxDateTime::Now() - m_dtKillInactiveGfxTimestamp);
+    if (ts.GetSeconds() > 10) {
+        m_dtKillInactiveGfxTimestamp = wxDateTime::Now();
+        KillInactiveGraphicsApps();
+    }
+
+    return iRetVal;
+}
+
+
+int CMainDocument::OnRefreshState() {
+    if (IsConnected()) {
+        CachedStateUpdate();
+    }
+
+    return 0;
+}
+
+
 int CMainDocument::CachedStateUpdate() {
     wxLogTrace(wxT("Function Start/End"), wxT("CMainDocument::CachedStateUpdate - Function Begin"));
 
@@ -371,54 +482,13 @@ int CMainDocument::CachedStateUpdate() {
 }
 
 
-int CMainDocument::OnInit() {
-    int iRetVal = -1;
-
-    // start the connect management thread
-    m_pNetworkConnection = new CNetworkConnection(this);
-
-    return iRetVal;
-}
-
-
-int CMainDocument::OnExit() {
-    int iRetVal = 0;
-
-    if (m_pNetworkConnection) {
-        delete m_pNetworkConnection;
-        m_pNetworkConnection = NULL;
-    }
-
-    return iRetVal;
-}
-
-
-int CMainDocument::OnPoll() {
-    int iRetVal = 0;
-
-    if (m_pNetworkConnection) {
-        m_pNetworkConnection->Poll();
-    }
-
-    return iRetVal;
-}
-
-
-int CMainDocument::OnRefreshState() {
-    if (IsConnected()) {
-        CachedStateUpdate();
-    }
-
-    return 0;
-}
-
-
 int CMainDocument::ResetState() {
     rpc.close();
     state.clear();
     host.clear_host_info();
     results.clear();
     ft.clear();
+    statistics_status.clear();
     disk_usage.clear();
     proxy_info.clear();
 
@@ -427,21 +497,19 @@ int CMainDocument::ResetState() {
 }
 
 
-int CMainDocument::Connect(const wxChar* szComputer, const wxChar* szComputerPassword, const bool bDisconnect, const bool bUseDefaultPassword) {
-       wxString strOldMachineName = wxEmptyString;
+int CMainDocument::Connect(const wxChar* szComputer, int iPort, const wxChar* szComputerPassword, const bool bDisconnect, const bool bUseDefaultPassword) {
+    wxString strOldMachineName = wxEmptyString;
 
    GetConnectedComputerName(strOldMachineName);
    
- if (bDisconnect) {
+   if (bDisconnect) {
         m_pNetworkConnection->ForceReconnect();
     }
 
-    m_pNetworkConnection->SetComputer(szComputer, szComputerPassword, bUseDefaultPassword);
+    m_pNetworkConnection->SetComputer(szComputer, iPort, szComputerPassword, bUseDefaultPassword);
     m_pNetworkConnection->FireReconnectEvent();
 
-    if (szComputer != strOldMachineName) {
-        ResetMessageState();
-    }
+    ResetMessageState();
     return 0;
 }
 
@@ -449,6 +517,7 @@ int CMainDocument::Connect(const wxChar* szComputer, const wxChar* szComputerPas
 int CMainDocument::Reconnect() {
     m_pNetworkConnection->ForceReconnect();
     m_pNetworkConnection->FireReconnectEvent();
+    ResetMessageState();
     return 0;
 }
 
@@ -516,6 +585,8 @@ int CMainDocument::GetCoreClientStatus(CC_STATUS& ccs, bool bForce) {
                         pFrame->Close(true);
                     }
                 }
+            } else {
+                m_pNetworkConnection->SetStateDisconnected();
             }
         } else {
             ccs = status;
@@ -668,12 +739,6 @@ int CMainDocument::CachedProjectStatusUpdate() {
 PROJECT* CMainDocument::project(unsigned int i) {
     PROJECT* pProject = NULL;
 
-    // It is not safe to assume that the vector actually contains the data,
-    //   doing so will lead to those annoying dialogs about the list control
-    //   not being able to find list item such and such.  In the worst case
-    //   scenario it'll lead to a crash, so for now we'll use the at() function
-    //   which will cause an exception which can be trapped and return a NULL
-    //   pointer when the exception is thrown.
     try {
         if (!state.projects.empty())
             pProject = state.projects.at(i);
@@ -907,12 +972,6 @@ int CMainDocument::CachedResultsStatusUpdate() {
 RESULT* CMainDocument::result(unsigned int i) {
     RESULT* pResult = NULL;
 
-    // It is not safe to assume that the vector actually contains the data,
-    //   doing so will lead to those annoying dialogs about the list control
-    //   not being able to find list item such and such.  In the worst case
-    //   scenario it'll lead to a crash, so for now we'll use the at() function
-    //   which will cause an exception which can be trapped and return a NULL
-    //   pointer when the exception is thrown.
     try {
         if (!results.results.empty())
             pResult = results.results.at(i);
@@ -925,26 +984,24 @@ RESULT* CMainDocument::result(unsigned int i) {
 }
 
 /* get the result not by index, but by name */
-RESULT* CMainDocument::result(const wxString& name) {
+RESULT* CMainDocument::result(const wxString& name, const wxString& project_url) {
     RESULT* pResult = NULL;
 
-    // It is not safe to assume that the vector actually contains the data,
-    //   doing so will lead to those annoying dialogs about the list control
-    //   not being able to find list item such and such.  In the worst case
-    //   scenario it'll lead to a crash, so for now we'll use the at() function
-    //   which will cause an exception which can be trapped and return a NULL
-    //   pointer when the exception is thrown.
     try {
-        if (!results.results.empty())
-			//iterating over the vector and find the right result
-			for(unsigned int i=0; i< results.results.size();i++) {
-				RESULT* tResult = results.results.at(i);
-				wxString resname(tResult->name.c_str(),wxConvUTF8);
-				if(resname.IsSameAs(name)){
-					pResult = tResult;
-					break;
-				}
-			}
+        if (!results.results.empty()) {
+            //iterating over the vector and find the right result
+            for(unsigned int i=0; i< results.results.size();i++) {
+                RESULT* tResult = results.results.at(i);
+                wxString resname(tResult->name.c_str(),wxConvUTF8);
+                if(resname.IsSameAs(name)){
+                    wxString resurl(tResult->project_url.c_str(),wxConvUTF8);
+                    if(resurl.IsSameAs(project_url)){
+                        pResult = tResult;
+                        break;
+                    }
+                }
+            }
+        }
     }
     catch (std::out_of_range e) {
         pResult = NULL;
@@ -994,23 +1051,251 @@ int CMainDocument::WorkResume(std::string& strProjectURL, std::string& strName)
 }
 
 
-int CMainDocument::WorkShowGraphics(
-    std::string& strProjectURL, std::string& strName, int iGraphicsMode,
-    std::string& strWindowStation, std::string& strDesktop, std::string& strDisplay)
+// If the graphics application for the current task is already 
+// running, return a pointer to its RUNNING_GFX_APP struct.
+RUNNING_GFX_APP* CMainDocument::GetRunningGraphicsApp(RESULT* result, int slot)
+{
+    bool exited = false;
+    std::vector<RUNNING_GFX_APP>::iterator gfx_app_iter;
+    
+    for( gfx_app_iter = m_running_gfx_apps.begin(); 
+        gfx_app_iter != m_running_gfx_apps.end(); 
+        gfx_app_iter++
+    ) {
+         if ( (slot >= 0) && ((*gfx_app_iter).slot != slot) ) continue;
+
+#ifdef _WIN32
+        unsigned long exit_code;
+        if (GetExitCodeProcess((*gfx_app_iter).pid, &exit_code)) {
+            if (exit_code != STILL_ACTIVE) {
+                exited = true;
+            }
+        }
+#else
+        if (waitpid((*gfx_app_iter).pid, 0, WNOHANG) == (*gfx_app_iter).pid) {
+            exited = true;
+        }
+#endif
+        if (! exited) {
+            if ( (result->name == (*gfx_app_iter).name) &&
+                (result->project_url == (*gfx_app_iter).project_url) ) {
+                return &(*gfx_app_iter);
+            }
+    
+            // Graphics app is still running but the slot now has a different task
+            KillGraphicsApp((*gfx_app_iter).pid);
+        }
+
+        // Either the graphics app had already exited or we just killed it
+        (*gfx_app_iter).name.clear();
+        (*gfx_app_iter).project_url.clear();
+        m_running_gfx_apps.erase(gfx_app_iter);
+        return NULL;
+    }
+    return NULL;
+}
+
+
+// Kill any running graphics apps whose worker tasks aren't running
+void CMainDocument::KillInactiveGraphicsApps()
+{
+/*
+    std::vector<RUNNING_GFX_APP>::iterator gfx_app_iter;
+    unsigned int i;
+    bool bStillRunning;
+
+    if (m_running_gfx_apps.size() <= 0) return;
+    
+    // If none of the Tasks displays are visible, we need to update 
+    // the results vector.  This call does nothing if recently updated
+    // by a call from CViewWork, CViewWorkGrid or CViewTabPage.
+    CachedResultsStatusUpdate();
+    
+    gfx_app_iter = m_running_gfx_apps.begin();
+    while (gfx_app_iter != m_running_gfx_apps.end()) {
+        bStillRunning = false;
+        
+        for (i=0; i<results.results.size(); i++) {
+            if ((results.results.at(i))->state != RESULT_FILES_DOWNLOADED) continue;
+            if (!(results.results.at(i))->active_task) continue;
+            if ((results.results.at(i))->scheduler_state != CPU_SCHED_SCHEDULED) continue;
+            if ((results.results.at(i))->name != (*gfx_app_iter).name) continue;
+            if ((results.results.at(i))->project_url != (*gfx_app_iter).project_url) continue;    
+            bStillRunning =  true;
+            break;
+        }
+        
+        if (!bStillRunning) {
+            KillGraphicsApp((*gfx_app_iter).pid);
+            gfx_app_iter = m_running_gfx_apps.erase(gfx_app_iter);
+        } else {
+            gfx_app_iter++;
+        }
+    }
+*/
+}
+
+
+void CMainDocument::KillAllRunningGraphicsApps()
+{
+    size_t i, n;
+    std::vector<RUNNING_GFX_APP>::iterator gfx_app_iter;
+
+    n = m_running_gfx_apps.size();
+    for (i=0; i<n; i++) {
+        gfx_app_iter = m_running_gfx_apps.begin(); 
+        KillGraphicsApp((*gfx_app_iter).pid);
+        (*gfx_app_iter).name.clear();
+        (*gfx_app_iter).project_url.clear();
+        m_running_gfx_apps.erase(gfx_app_iter);
+    }
+}
+
+
+#ifdef _WIN32
+void CMainDocument::KillGraphicsApp(HANDLE pid) {
+    kill_program(pid);
+}
+#else
+void CMainDocument::KillGraphicsApp(int pid) {
+    char* argv[6];
+    char currentDir[1024];
+    char thePIDbuf[10];
+    int id, iRetVal;
+    
+
+    if (g_use_sandbox) {
+        snprintf(thePIDbuf, sizeof(thePIDbuf), "%d", pid);
+        argv[0] = "switcher";
+        argv[1] = "/bin/kill";
+        argv[2] =  "kill";
+        argv[3] = "-KILL";
+        argv[4] = thePIDbuf;
+        argv[5] = 0;
+    
+        iRetVal = run_program(
+            getcwd(currentDir, sizeof(currentDir)),
+            "./switcher/switcher",
+            5,
+            argv,
+            0,
+            id
+        );
+    } else {
+        kill_program(pid);
+    }
+}
+#endif
+
+int CMainDocument::WorkShowGraphics(RESULT* result)
 {
     int iRetVal = 0;
-    DISPLAY_INFO di;
+    
+    if (!result->graphics_exec_path.empty()) {
+        // V6 Graphics
+        RUNNING_GFX_APP gfx_app;
+        RUNNING_GFX_APP* previous_gfx_app;
+        char *p;
+        int slot;
+#ifdef __WXMSW__
+        HANDLE   id;
+#else
+        int      id;
+#endif
 
-    strcpy(di.window_station, strWindowStation.c_str());
-    strcpy(di.desktop, strDesktop.c_str());
-    strcpy(di.display, strDisplay.c_str());
+        p = strrchr((char*)result->slot_path.c_str(), '/');
+        if (!p) return ERR_INVALID_PARAM;
+        slot = atoi(p+1);
+        
+        // See if we are already running the graphics application for this task
+        previous_gfx_app = GetRunningGraphicsApp(result, slot);
 
-    iRetVal = rpc.show_graphics(
-        strProjectURL.c_str(),
-        strName.c_str(),
-        iGraphicsMode,
-        di
-    );
+#ifndef __WXMSW__
+        char* argv[4];
+
+        if (previous_gfx_app) {
+#ifdef __WXMAC__
+        ProcessSerialNumber gfx_app_psn;
+            // If this graphics app is already running,
+            // just bring it to the front
+            //
+            if (!GetProcessForPID(previous_gfx_app->pid, &gfx_app_psn)) {
+                SetFrontProcess(&gfx_app_psn);
+            }
+#endif
+            // If graphics app is already running, don't launch a second instance
+            //
+            return 0;
+        }
+        argv[0] = "switcher";
+        // For unknown reasons on Macs, the graphics application 
+        // exits with "RegisterProcess failed (error = -50)" unless 
+        // we pass its full path twice in the argument list to execv.
+        //
+        argv[1] = (char *)result->graphics_exec_path.c_str();
+        argv[2] = (char *)result->graphics_exec_path.c_str();
+        argv[3] = 0;
+    
+         if (g_use_sandbox) {
+            iRetVal = run_program(
+                result->slot_path.c_str(),
+               "../../switcher/switcher",
+                3,
+                argv,
+                0,
+                id
+            );
+        } else {        
+            iRetVal = run_program(
+                result->slot_path.c_str(),
+                result->graphics_exec_path.c_str(),
+                1,
+                &argv[2],
+                0,
+                id
+            );
+        }
+#else
+        char* argv[2];
+
+        // If graphics app is already running, don't launch a second instance
+        //
+        if (previous_gfx_app) return 0;
+        argv[0] =0;
+        
+        iRetVal = run_program(
+            result->slot_path.c_str(),
+            result->graphics_exec_path.c_str(),
+            0,
+            argv,
+            0,
+            id
+        );
+#endif
+
+        if (!iRetVal) {
+            gfx_app.slot = slot;
+            gfx_app.project_url = result->project_url;
+            gfx_app.name = result->name;
+            gfx_app.pid = id;
+            m_running_gfx_apps.push_back(gfx_app);
+        }
+
+    } else {
+        // V5 and Older
+        DISPLAY_INFO di;
+
+        strcpy(di.window_station, (char*)wxGetApp().m_strDefaultWindowStation.c_str());
+        strcpy(di.desktop, (char*)wxGetApp().m_strDefaultDesktop.c_str());
+        strcpy(di.display, (char*)wxGetApp().m_strDefaultDisplay.c_str());
+
+        iRetVal = rpc.show_graphics(
+            result->project_url.c_str(),
+            result->name.c_str(),
+            MODE_WINDOW,
+            di
+        );
+    }
 
     return iRetVal;
 }
@@ -1050,7 +1335,7 @@ int CMainDocument::CachedMessageUpdate() {
             goto done;
         }
         if (messages.messages.size() != 0) {
-            int last_ind = messages.messages.size()-1;
+            size_t last_ind = messages.messages.size()-1;
             m_iMessageSequenceNumber = messages.messages[last_ind]->seqno;
         }
     } else {
@@ -1065,12 +1350,6 @@ done:
 MESSAGE* CMainDocument::message(unsigned int i) {
     MESSAGE* pMessage = NULL;
 
-    // It is not safe to assume that the vector actually contains the data,
-    //   doing so will lead to those annoying dialogs about the list control
-    //   not being able to find list item such and such.  In the worst case
-    //   scenario it'll lead to a crash, so for now we'll use the at() function
-    //   which will cause an exception which can be trapped and return a NULL
-    //   pointer when the exception is thrown.
     try {
         if (!messages.messages.empty())
             pMessage = messages.messages.at(i);
@@ -1128,12 +1407,6 @@ int CMainDocument::CachedFileTransfersUpdate() {
 FILE_TRANSFER* CMainDocument::file_transfer(unsigned int i) {
     FILE_TRANSFER* pFT = NULL;
 
-    // It is not safe to assume that the vector actually contains the data,
-    //   doing so will lead to those annoying dialogs about the list control
-    //   not being able to find list item such and such.  In the worst case
-    //   scenario it'll lead to a crash, so for now we'll use the at() function
-    //   which will cause an exception which can be trapped and return a NULL
-    //   pointer when the exception is thrown.
     try {
         if (!ft.file_transfers.empty())
             pFT = ft.file_transfers.at(i);
@@ -1145,26 +1418,23 @@ FILE_TRANSFER* CMainDocument::file_transfer(unsigned int i) {
     return pFT;
 }
 
-FILE_TRANSFER* CMainDocument::file_transfer(const wxString& fileName) {
+FILE_TRANSFER* CMainDocument::file_transfer(const wxString& fileName, const wxString& project_url) {
     FILE_TRANSFER* pFT = NULL;
 
-    // It is not safe to assume that the vector actually contains the data,
-    //   doing so will lead to those annoying dialogs about the list control
-    //   not being able to find list item such and such.  In the worst case
-    //   scenario it'll lead to a crash, so for now we'll use the at() function
-    //   which will cause an exception which can be trapped and return a NULL
-    //   pointer when the exception is thrown.
     try {
-		if (!ft.file_transfers.empty()) {
-			for(unsigned int i=0; i< ft.file_transfers.size();i++) {
-				FILE_TRANSFER* tFT = ft.file_transfers.at(i);
-				wxString fname(tFT->name.c_str(),wxConvUTF8);
-				if(fname.IsSameAs(fileName)) {
-					pFT = tFT;
-					break;
-				}
-			}
-		}
+        if (!ft.file_transfers.empty()) {
+            for(unsigned int i=0; i< ft.file_transfers.size();i++) {
+                FILE_TRANSFER* tFT = ft.file_transfers.at(i);
+                wxString fname(tFT->name.c_str(),wxConvUTF8);
+                if(fname.IsSameAs(fileName)) {
+                    wxString furl(tFT->project_url.c_str(),wxConvUTF8);
+                    if(furl.IsSameAs(project_url)){
+                        pFT = tFT;
+                        break;
+                    }
+                }
+            }
+        }
     }
     catch (std::out_of_range e) {
         pFT = NULL;
@@ -1199,11 +1469,11 @@ int CMainDocument::TransferRetryNow(int iIndex) {
     return iRetVal;
 }
 
-int CMainDocument::TransferRetryNow(const wxString& fileName) {
+int CMainDocument::TransferRetryNow(const wxString& fileName, const wxString& project_url) {
     FILE_TRANSFER* pFT = NULL;
     int iRetVal = 0;
 
-    pFT = file_transfer(fileName);
+    pFT = file_transfer(fileName, project_url);
 
     if (pFT)
         iRetVal = rpc.file_transfer_op((*pFT), "retry");
@@ -1224,11 +1494,11 @@ int CMainDocument::TransferAbort(int iIndex) {
     return iRetVal;
 }
 
-int CMainDocument::TransferAbort(const wxString& fileName) {
+int CMainDocument::TransferAbort(const wxString& fileName, const wxString& project_url) {
     FILE_TRANSFER* pFT = NULL;
     int iRetVal = 0;
 
-    pFT = file_transfer(fileName);
+    pFT = file_transfer(fileName, project_url);
 
     if (pFT)
         iRetVal = rpc.file_transfer_op((*pFT), "abort");
@@ -1244,8 +1514,9 @@ int CMainDocument::CachedDiskUsageUpdate() {
         wxTimeSpan ts(wxDateTime::Now() - m_dtDiskUsageTimestamp);
 
 		// don't get disk usage more than once per minute
+                // unless we just connected to a client
 		//
-        if (ts.GetSeconds() > 60) {
+        if ((ts.GetSeconds() > 60) || disk_usage.projects.empty()) {
             m_dtDiskUsageTimestamp = wxDateTime::Now();
 
             iRetVal = rpc.get_disk_usage(disk_usage);
@@ -1265,12 +1536,6 @@ int CMainDocument::CachedDiskUsageUpdate() {
 PROJECT* CMainDocument::DiskUsageProject(unsigned int i) {
     PROJECT* pProject = NULL;
 
-    // It is not safe to assume that the vector actually contains the data,
-    //   doing so will lead to those annoying dialogs about the list control
-    //   not being able to find list item such and such.  In the worst case
-    //   scenario it'll lead to a crash, so for now we'll use the at() function
-    //   which will cause an exception which can be trapped and return a NULL
-    //   pointer when the exception is thrown.
     try {
         if (!disk_usage.projects.empty()) {
             pProject = disk_usage.projects.at(i);
@@ -1288,7 +1553,7 @@ int CMainDocument::CachedStatisticsStatusUpdate() {
 
     if (IsConnected()) {
         wxTimeSpan ts(wxDateTime::Now() - m_dtStatisticsStatusTimestamp);
-        if (ts.GetSeconds() > 0) {
+        if ((ts.GetSeconds() > 0) || statistics_status.projects.empty()) {
             m_dtStatisticsStatusTimestamp = wxDateTime::Now();
 
             iRetVal = rpc.get_statistics(statistics_status);
@@ -1309,12 +1574,6 @@ PROJECT* CMainDocument::statistic(unsigned int i) {
     PROJECT* pProject = NULL;
 
 
-    // It is not safe to assume that the vector actually contains the data,
-    //   doing so will lead to those annoying dialogs about the list control
-    //   not being able to find list item such and such.  In the worst case
-    //   scenario it'll lead to a crash, so for now we'll use the at() function
-    //   which will cause an exception which can be trapped and return a NULL
-    //   pointer when the exception is thrown.
     try {
         if (!statistics_status.projects.empty())
             pProject = statistics_status.projects.at(i);
@@ -1417,4 +1676,4 @@ int CMainDocument::GetSimpleGUIWorkCount() {
 }
 
 
-const char *BOINC_RCSID_aa03a835ba = "$Id: MainDocument.cpp 14817 2008-02-28 20:27:00Z charlief $";
+const char *BOINC_RCSID_aa03a835ba = "$Id: MainDocument.cpp 15519 2008-07-01 02:26:30Z charlief $";
