@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _MAINDOCUMENT_H_
 #define _MAINDOCUMENT_H_
@@ -24,10 +24,26 @@
 #pragma interface "MainDocument.cpp"
 #endif
 
+#include <vector>
 #include "common_defs.h"
 #include "gui_rpc_client.h"
 
+typedef struct {
+    int slot;
+    std::string project_url;
+    std::string name;
+#ifdef _WIN32
+    HANDLE pid;
+#else
+    int pid;
+#endif
+} RUNNING_GFX_APP;
+
+
+extern bool g_use_sandbox;
+
 class CMainDocument;
+class CBOINCClientManager;
 
 class CNetworkConnection : public wxObject {
 public:
@@ -43,8 +59,11 @@ public:
     int            GetConnectedComputerVersion(wxString& strVersion);
     int            GetConnectingComputerName(wxString& strMachine);
     bool           IsComputerNameLocal(const wxString& strMachine);
-    void           GetLocalPassword(wxString& strPassword);
-    int            SetComputer(const wxChar* szComputer, const wxChar* szPassword, const bool bUseDefaultPassword);
+    int            GetLocalPassword(wxString& strPassword);
+    int SetComputer(
+        const wxChar* szComputer, const int iPort, const wxChar* szPassword,
+        const bool bUseDefaultPassword
+    );
     void           SetStateError();
     void           SetStateErrorAuthentication();
     void           SetStateReconnecting();
@@ -64,12 +83,14 @@ private:
     bool           m_bReconnecting;
     bool           m_bUseDefaultPassword;
     bool           m_bUsedDefaultPassword;
+    int            m_iReadGUIRPCAuthFailure;
     bool           m_bNewConnection;
     wxString       m_strNewComputerName;
     wxString       m_strNewComputerPassword;
     wxString       m_strConnectedComputerName;
     wxString       m_strConnectedComputerPassword;
     wxString       m_strConnectedComputerVersion;
+    int m_iPort;
 };
 
 
@@ -86,22 +107,21 @@ public:
 private:
 
     wxDateTime                  m_dtCachedCCStatusTimestamp;
+    bool                        m_bClientStartCheckCompleted;
 
 
 public:
-    int                         CachedStateUpdate();
-
-    CNetworkConnection*         m_pNetworkConnection;
-
     int                         OnInit();
     int                         OnExit();
     int                         OnPoll();
 
     int                         OnRefreshState();
+    int                         CachedStateUpdate();
     int                         ResetState();
 
     int                         Connect(
                                     const wxChar* szComputer,
+                                    const int iPort,
                                     const wxChar* szComputerPassword = wxEmptyString,
                                     const bool bDisconnect = FALSE,
                                     const bool bUseDefaultPassword = FALSE
@@ -131,6 +151,8 @@ public:
 
     bool                        IsUserAuthorized();
 
+    CNetworkConnection*         m_pNetworkConnection;
+    CBOINCClientManager*        m_pClientManager;
     RPC_CLIENT                  rpc;
     CC_STATE                    state;
     CC_STATUS                   status;
@@ -175,11 +197,21 @@ public:
 private:
     int                         CachedResultsStatusUpdate();
     wxDateTime                  m_dtResultsTimestamp;
+    wxDateTime                  m_dtKillInactiveGfxTimestamp;
+    std::vector<RUNNING_GFX_APP> m_running_gfx_apps;
+    RUNNING_GFX_APP*            GetRunningGraphicsApp(RESULT* result, int slot);
+    void                        KillAllRunningGraphicsApps();
+    void                        KillInactiveGraphicsApps();
+#ifdef _WIN32
+    void                        KillGraphicsApp(HANDLE pid);
+#else
+    void                        KillGraphicsApp(int tpid);
+#endif
 
 public:
     RESULTS                     results;
     RESULT*                     result(unsigned int);
-	RESULT*						result(const wxString& name);
+    RESULT*                     result(const wxString& name, const wxString& project_url);
 
     int                         GetWorkCount();
 
@@ -191,18 +223,12 @@ public:
                                     std::string& strProjectURL,
                                     std::string& strName
                                 );
-    int                         WorkShowGraphics(
-                                    std::string& strProjectURL,
-                                    std::string& strName,
-                                    int iGraphicsMode,
-                                    std::string& strWindowStation,
-                                    std::string& strDesktop,
-                                    std::string& strDisplay
-                                );
+    int                         WorkShowGraphics(RESULT* result);
     int                         WorkAbort(
                                     std::string& strProjectURL,
                                     std::string& strName
                                 );
+    CC_STATE*                   GetState() { return &state; };
 
 
     //
@@ -233,14 +259,14 @@ private:
 public:
     FILE_TRANSFERS              ft;
     FILE_TRANSFER*              file_transfer(unsigned int);
-	FILE_TRANSFER*              file_transfer(const wxString& fileName);
+    FILE_TRANSFER*              file_transfer(const wxString& fileName, const wxString& project_url);
 
     int                         GetTransferCount();
 
     int                         TransferRetryNow(int iIndex);
-	int                         TransferRetryNow(const wxString& fileName);
+    int                         TransferRetryNow(const wxString& fileName, const wxString& project_url);
     int                         TransferAbort(int iIndex);
-	int                         TransferAbort(const wxString& fileName);
+    int                         TransferAbort(const wxString& fileName, const wxString& project_url);
 
 
     //
