@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "SkinManager.h"
@@ -30,6 +30,7 @@
 #include "BOINCGUIApp.h"
 #include "BOINCBaseFrame.h"
 #include "SkinManager.h"
+#include "version.h"
 
 
 ////@begin XPM images
@@ -76,6 +77,7 @@
 #include "res/skins/default/graphic/advanced_link_image.xpm"
 #include "res/skins/default/graphic/dialog_background_image.xpm"
 #include "res/boinc.xpm"
+#include "res/boinc32.xpm"
 #include "res/boincdisconnect.xpm"
 #include "res/boincsnooze.xpm"
 #include "res/boinc_logo.xpm"
@@ -100,11 +102,11 @@ CSkinItem::~CSkinItem() {
 
 
 wxColour CSkinItem::ParseColor(wxString strColor) {
-    int red, green, blue;
+    long red, green, blue;
     wxStringTokenizer tkz(strColor, wxT(":"), wxTOKEN_RET_EMPTY);
-    wxString(tkz.GetNextToken()).ToLong((long*)&red);
-	wxString(tkz.GetNextToken()).ToLong((long*)&green);
-	wxString(tkz.GetNextToken()).ToLong((long*)&blue);
+    wxString(tkz.GetNextToken()).ToLong(&red);
+	wxString(tkz.GetNextToken()).ToLong(&green);
+	wxString(tkz.GetNextToken()).ToLong(&blue);
     return wxColour((unsigned char)red, (unsigned char)green, (unsigned char)blue);
 }
 
@@ -839,13 +841,15 @@ CSkinAdvanced::~CSkinAdvanced() {
 void CSkinAdvanced::Clear() {
     m_bIsBranded = false;
     m_strApplicationName = wxEmptyString;
+    m_strApplicationShortName = wxEmptyString;
     m_iconApplicationIcon.Clear();
+    m_iconApplicationIcon32.Clear();
     m_iconApplicationDisconnectedIcon.Clear();
     m_iconApplicationSnoozeIcon.Clear();
     m_bitmapApplicationLogo = wxNullBitmap;
-    m_strCompanyName = wxEmptyString;
-    m_strCompanyWebsite = wxEmptyString;
-    m_strProjectName = wxEmptyString;
+    m_strOrganizationName = wxEmptyString;
+    m_strOrganizationWebsite = wxEmptyString;
+    m_strOrganizationHelpUrl = wxEmptyString;
     m_bDefaultTabSpecified = false;
     m_iDefaultTab = 0;
     m_strExitMessage = wxEmptyString;
@@ -862,9 +866,15 @@ int CSkinAdvanced::Parse(MIOFILE& in) {
         else if (parse_str(buf, "<application_name>", strBuffer)) {
             m_strApplicationName = wxString(strBuffer.c_str(), wxConvUTF8);
             continue;
+        } else if (parse_str(buf, "<application_short_name>", strBuffer)) {
+            m_strApplicationShortName = wxString(strBuffer.c_str(), wxConvUTF8);
+            continue;
         } else if (match_tag(buf, "<application_icon>")) {
             m_iconApplicationIcon.Parse(in);
             continue;
+        } else if (match_tag(buf, "<application_icon32>")) {
+            m_iconApplicationIcon32.Parse(in);
+            continue;
         } else if (match_tag(buf, "<application_disconnected_icon>")) {
             m_iconApplicationDisconnectedIcon.Parse(in);
             continue;
@@ -880,14 +890,14 @@ int CSkinAdvanced::Parse(MIOFILE& in) {
                 m_bitmapApplicationLogo = wxBitmap(wxImage(str.c_str(), wxBITMAP_TYPE_ANY));
             }
             continue;
-        } else if (parse_str(buf, "<company_name>", strBuffer)) {
-            m_strCompanyName = wxString(strBuffer.c_str(), wxConvUTF8);
+        } else if (parse_str(buf, "<organizaton_name>", strBuffer)) {
+            m_strOrganizationName = wxString(strBuffer.c_str(), wxConvUTF8);
             continue;
-        } else if (parse_str(buf, "<company_website>", strBuffer)) {
-            m_strCompanyWebsite = wxString(strBuffer.c_str(), wxConvUTF8);
+        } else if (parse_str(buf, "<organizaton_website>", strBuffer)) {
+            m_strOrganizationWebsite = wxString(strBuffer.c_str(), wxConvUTF8);
             continue;
-        } else if (parse_str(buf, "<project_name>", strBuffer)) {
-            m_strProjectName = wxString(strBuffer.c_str(), wxConvUTF8);
+        } else if (parse_str(buf, "<organizaton_help_url>", strBuffer)) {
+            m_strOrganizationHelpUrl = wxString(strBuffer.c_str(), wxConvUTF8);
             continue;
         } else if (parse_int(buf, "<open_tab>", m_iDefaultTab)) {
             m_bDefaultTabSpecified = true;
@@ -905,7 +915,16 @@ int CSkinAdvanced::Parse(MIOFILE& in) {
 
 
 wxString CSkinAdvanced::GetApplicationName() {
-    return m_strApplicationName;
+    wxString strApplicationName = m_strApplicationName;
+#ifdef BOINC_PRERELEASE
+        strApplicationName += wxT(" (Pre-release)");
+#endif
+    return strApplicationName;
+}
+
+
+wxString CSkinAdvanced::GetApplicationShortName() {
+    return m_strApplicationShortName;
 }
 
 
@@ -913,6 +932,9 @@ wxIcon* CSkinAdvanced::GetApplicationIcon() {
     return m_iconApplicationIcon.GetIcon();
 }
 
+wxIcon* CSkinAdvanced::GetApplicationIcon32() {
+    return m_iconApplicationIcon32.GetIcon();
+}
 
 wxIcon* CSkinAdvanced::GetApplicationDisconnectedIcon() { 
     return m_iconApplicationDisconnectedIcon.GetIcon();
@@ -929,18 +951,18 @@ wxBitmap* CSkinAdvanced::GetApplicationLogo() {
 }
 
 
-wxString CSkinAdvanced::GetCompanyName() { 
-    return m_strCompanyName;
+wxString CSkinAdvanced::GetOrganizationName() { 
+    return m_strOrganizationName;
 }
 
 
-wxString CSkinAdvanced::GetCompanyWebsite() {
-    return m_strCompanyWebsite;
+wxString CSkinAdvanced::GetOrganizationWebsite() {
+    return m_strOrganizationWebsite;
 }
 
 
-wxString CSkinAdvanced::GetProjectName() {
-    return m_strProjectName;
+wxString CSkinAdvanced::GetOrganizationHelpUrl() {
+    return m_strOrganizationHelpUrl;
 }
 
 
@@ -972,7 +994,15 @@ bool CSkinAdvanced::InitializeDelayedValidation() {
         m_strApplicationName = wxT("BOINC Manager");
         wxASSERT(!m_strApplicationName.IsEmpty());
     }
+    if (m_strApplicationShortName.IsEmpty()) {
+        if (!disable_error_msgs) {
+            fprintf(stderr, "Skin Manager: Application short name was not defined. Using default.\n");
+        }
+        m_strApplicationShortName = wxT("BOINC");
+        wxASSERT(!m_strApplicationShortName.IsEmpty());
+    }
     m_iconApplicationIcon.SetDefaults(wxT("application"), (const char**)boinc_xpm);
+    m_iconApplicationIcon32.SetDefaults(wxT("application"), (const char**)boinc32_xpm);
     m_iconApplicationDisconnectedIcon.SetDefaults(wxT("application disconnected"), (const char**)boincdisconnect_xpm);
     m_iconApplicationSnoozeIcon.SetDefaults(wxT("application snooze"), (const char**)boincsnooze_xpm);
     if (!m_bitmapApplicationLogo.Ok()) {
@@ -982,26 +1012,26 @@ bool CSkinAdvanced::InitializeDelayedValidation() {
         m_bitmapApplicationLogo = wxBitmap((const char**)boinc_logo_xpm);
         wxASSERT(m_bitmapApplicationLogo.Ok());
     }
-    if (m_strCompanyName.IsEmpty()) {
+    if (m_strOrganizationName.IsEmpty()) {
         if (!disable_error_msgs) {
-            fprintf(stderr, "Skin Manager: Company name was not defined. Using default.\n");
+            fprintf(stderr, "Skin Manager: Organization name was not defined. Using default.\n");
         }
-        m_strCompanyName = wxT("Space Sciences Laboratory, U.C. Berkeley");
-        wxASSERT(!m_strCompanyName.IsEmpty());
+        m_strOrganizationName = wxT("Space Sciences Laboratory, U.C. Berkeley");
+        wxASSERT(!m_strOrganizationName.IsEmpty());
     }
-    if (m_strCompanyWebsite.IsEmpty()) {
+    if (m_strOrganizationWebsite.IsEmpty()) {
         if (!disable_error_msgs) {
-            fprintf(stderr, "Skin Manager: Company web site was not defined. Using default.\n");
+            fprintf(stderr, "Skin Manager: Organization web site was not defined. Using default.\n");
         }
-        m_strCompanyWebsite = wxT("http://boinc.berkeley.edu");
-        wxASSERT(!m_strCompanyWebsite.IsEmpty());
+        m_strOrganizationWebsite = wxT("http://boinc.berkeley.edu");
+        wxASSERT(!m_strOrganizationWebsite.IsEmpty());
     }
-    if (m_strProjectName.IsEmpty()) {
+    if (m_strOrganizationHelpUrl.IsEmpty()) {
         if (!disable_error_msgs) {
-            fprintf(stderr, "Skin Manager: Project name was not defined. Using default.\n");
+            fprintf(stderr, "Skin Manager: Organization help url was not defined. Using default.\n");
         }
-        m_strProjectName = wxT("BOINC");
-        wxASSERT(!m_strProjectName.IsEmpty());
+        m_strOrganizationHelpUrl = wxT("http://boinc.berkeley.edu/manager_links.php");
+        wxASSERT(!m_strOrganizationHelpUrl.IsEmpty());
     }
     if (!m_bDefaultTabSpecified) {
         if (!disable_error_msgs) {
@@ -1021,11 +1051,11 @@ bool CSkinAdvanced::InitializeDelayedValidation() {
               "In most cases, it is better just to close the %s window\n"
               "rather than to exit the application; that will allow %s to run its\n"
               "tasks at the times you selected in your preferences."),
-                m_strProjectName.c_str(),
+                m_strApplicationShortName.c_str(),
                 m_strApplicationName.c_str(),
-                m_strProjectName.c_str(),
+                m_strApplicationShortName.c_str(),
                 m_strApplicationName.c_str(),
-                m_strProjectName.c_str()
+                m_strApplicationShortName.c_str()
             );
 
         wxASSERT(!m_strExitMessage.IsEmpty());
@@ -1376,7 +1406,17 @@ wxString CSkinManager::GetSkinFileName() {
 
 wxString CSkinManager::GetSkinsLocation() {
     // Construct path to skins directory
-    return wxString(wxGetCwd() + wxString(wxFileName::GetPathSeparator()) + wxT("skins"));
+    wxString strSkinLocation = wxEmptyString;
+
+#ifdef __WXMSW__
+    strSkinLocation  = wxGetApp().GetRootDirectory();
+    strSkinLocation += wxFileName::GetPathSeparator();
+    strSkinLocation += wxT("skins");
+#else
+    strSkinLocation = wxString(wxGetCwd() + wxString(wxFileName::GetPathSeparator()) + wxT("skins"));
+#endif
+
+    return strSkinLocation;
 }
 
 
@@ -1436,3 +1476,4 @@ bool CSkinManager::InitializeDelayedValidation() {
            m_WizardsSkin.InitializeDelayedValidation();
 }
 
+
