@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _SKINMANAGER_H_
 #define _SKINMANAGER_H_
@@ -290,13 +290,15 @@ public:
     bool InitializeDelayedValidation();
 
     wxString    GetApplicationName();
+    wxString    GetApplicationShortName();
     wxIcon*     GetApplicationIcon();
+    wxIcon*     GetApplicationIcon32();
     wxIcon*     GetApplicationDisconnectedIcon();
     wxIcon*     GetApplicationSnoozeIcon();
     wxBitmap*   GetApplicationLogo();
-    wxString    GetCompanyName();
-    wxString    GetCompanyWebsite();
-    wxString    GetProjectName();
+    wxString    GetOrganizationName();
+    wxString    GetOrganizationWebsite();
+    wxString    GetOrganizationHelpUrl();
     int         GetDefaultTab();
     wxString    GetExitMessage();
     bool        IsBranded();
@@ -305,13 +307,15 @@ public:
 private:
     bool        m_bIsBranded;
     wxString    m_strApplicationName;
+    wxString    m_strApplicationShortName;
     CSkinIcon   m_iconApplicationIcon;
+    CSkinIcon   m_iconApplicationIcon32;
     CSkinIcon   m_iconApplicationDisconnectedIcon;
     CSkinIcon   m_iconApplicationSnoozeIcon;
     wxBitmap    m_bitmapApplicationLogo;
-    wxString    m_strCompanyName;
-    wxString    m_strCompanyWebsite;
-    wxString    m_strProjectName;
+    wxString    m_strOrganizationName;
+    wxString    m_strOrganizationWebsite;
+    wxString    m_strOrganizationHelpUrl;
     bool        m_bDefaultTabSpecified;
     int         m_iDefaultTab;
     wxString    m_strExitMessage;
