@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "ValidateAccountKey.h"
@@ -139,4 +139,4 @@ bool CValidateAccountKey::CheckValidator() const {
 }
 
 
-const char *BOINC_RCSID_0c2c4c6b07 = "$Id: ValidateAccountKey.cpp 8245 2005-09-28 11:59:34Z rwalton $";
+const char *BOINC_RCSID_0c2c4c6b07 = "$Id: ValidateAccountKey.cpp 13804 2007-10-09 11:35:47Z fthomas $";
