@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "ViewMessages.h"
@@ -35,13 +35,6 @@
 #include "res/mess.xpm"
 
 
-// BUGBUG: Don't have a clue why the build env is acting wierd
-#ifdef  __WXGTK__
-#ifndef __WXGTK20__
-#undef  wxUSE_CLIPBOARD
-#endif
-#endif
-
 #define COLUMN_PROJECT              0
 #define COLUMN_TIME                 1
 #define COLUMN_MESSAGE              2
@@ -237,7 +230,7 @@ void CViewMessages::OnListRender (wxTimerEvent& event) {
     CMainDocument* pDoc     = wxGetApp().GetDocument();
     wxASSERT(pDoc);
     wxASSERT(wxDynamicCast(pDoc, CMainDocument));
-
+    
     if (!m_bProcessingListRenderEvent) {
         m_bProcessingListRenderEvent = true;
 
@@ -458,4 +451,4 @@ bool CViewMessages::CloseClipboard() {
 #endif
 
 
-const char *BOINC_RCSID_0be7149475 = "$Id: ViewMessages.cpp 14813 2008-02-28 09:57:09Z charlief $";
+const char *BOINC_RCSID_0be7149475 = "$Id: ViewMessages.cpp 15130 2008-05-05 19:27:29Z romw $";
