@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "ViewProjectsGrid.h"
@@ -43,6 +43,8 @@
 #define COLUMN_AVGCREDIT            4
 #define COLUMN_RESOURCESHARE        5
 #define COLUMN_STATUS               6
+#define COLUMN_HIDDEN_URL           7
+#define NUM_COLUMNS                 (COLUMN_HIDDEN_URL+1)
 
 // groups that contain buttons
 #define GRP_TASKS    0
@@ -67,7 +69,9 @@ BEGIN_EVENT_TABLE (CViewProjectsGrid, CBOINCBaseView)
     EVT_CUSTOM_RANGE(wxEVT_COMMAND_BUTTON_CLICKED, ID_TASK_PROJECT_WEB_PROJDEF_MIN, ID_TASK_PROJECT_WEB_PROJDEF_MAX, CViewProjectsGrid::OnProjectWebsiteClicked)
 	EVT_GRID_SELECT_CELL(CViewProjectsGrid::OnGridSelectCell)
 	EVT_GRID_RANGE_SELECT(CViewProjectsGrid::OnGridSelectRange)
+#if PREVENT_MULTIPLE_PROJECT_SELECTIONS
         EVT_GRID_CELL_LEFT_CLICK(CViewProjectsGrid::OnCellLeftClick)
+#endif
 END_EVENT_TABLE ()
 
 
@@ -158,25 +162,32 @@ CViewProjectsGrid::CViewProjectsGrid(wxNotebook* pNotebook) :
     // Create Task Pane Items
     m_pTaskPane->UpdateControls();
 
-	// Create Grid
-	m_pGridPane->Setup();
-	m_pGridPane->SetTable(new CBOINCGridTable(1,7));
-	m_pGridPane->SetSelectionMode(wxGrid::wxGridSelectRows);
-	// init grid columns
-	wxInt32 colSizes[] = {150,80,80,80,80,85,150};
-	wxString colTitles[] = {_("Project"),_("Account"),_("Team"),_("Work done"),_("Avg. work done"),_("Resource share"),_("Status")};
-	for(int i=0; i<= COLUMN_STATUS;i++){
-		m_pGridPane->SetColLabelValue(i,colTitles[i]);
-		m_pGridPane->SetColSize(i,colSizes[i]);
-	}
-	//change the default cell renderer
-	m_pGridPane->SetDefaultRenderer(new CBOINCGridCellProgressRenderer(COLUMN_RESOURCESHARE,false));
-	//set column sort types
-	m_pGridPane->SetColumnSortType(COLUMN_TOTALCREDIT,CST_FLOAT);
-	m_pGridPane->SetColumnSortType(COLUMN_RESOURCESHARE,CST_FLOAT);
-	m_pGridPane->SetColumnSortType(COLUMN_AVGCREDIT,CST_FLOAT);
-	//
-	m_pGridPane->SetPrimaryKeyColumn(COLUMN_PROJECT);
+    // Create Grid
+    m_pGridPane->Setup();
+    m_pGridPane->SetTable(new CBOINCGridTable(1,NUM_COLUMNS));
+    m_pGridPane->SetSelectionMode(wxGrid::wxGridSelectRows);
+    // init grid columns
+    wxInt32 colSizes[] = {150,80,80,80,80,85,150,0};
+    wxString colTitles[] = {_("Project"),_("Account"),_("Team"),_("Work done"),
+                            _("Avg. work done"),_("Resource share"),_("Status"),wxEmptyString
+                            };
+    for(int i=0; i<NUM_COLUMNS;i++){
+            m_pGridPane->SetColLabelValue(i,colTitles[i]);
+            m_pGridPane->SetColSize(i,colSizes[i]);
+    }
+    //change the default cell renderer
+    m_pGridPane->SetDefaultRenderer(new CBOINCGridCellProgressRenderer(COLUMN_RESOURCESHARE,false));
+    //set column sort types
+    m_pGridPane->SetColumnSortType(COLUMN_TOTALCREDIT,CST_FLOAT);
+    m_pGridPane->SetColumnSortType(COLUMN_RESOURCESHARE,CST_FLOAT);
+    m_pGridPane->SetColumnSortType(COLUMN_AVGCREDIT,CST_FLOAT);
+    //
+    m_pGridPane->SetPrimaryKeyColumns(COLUMN_HIDDEN_URL,-1);
+    // Hide the URL column
+    int min_width = m_pGridPane->GetColMinimalAcceptableWidth();
+    m_pGridPane->SetColMinimalAcceptableWidth(0);
+    m_pGridPane->SetColSize(COLUMN_HIDDEN_URL,0);
+    m_pGridPane->SetColMinimalAcceptableWidth(min_width);
     UpdateSelection();
 }
 
@@ -206,9 +217,10 @@ const char** CViewProjectsGrid::GetViewIcon() {
 void CViewProjectsGrid::OnProjectUpdate( wxCommandEvent& WXUNUSED(event) ) {
     wxLogTrace(wxT("Function Start/End"), wxT("CViewProjectsGrid::OnProjectUpdate - Function Begin"));
 
-    wxString        strProjectName = wxEmptyString;
+    wxString        strProjectURL  = wxEmptyString;
     CMainDocument*  pDoc           = wxGetApp().GetDocument();
     CAdvancedFrame* pFrame         = wxDynamicCast(GetParent()->GetParent()->GetParent(), CAdvancedFrame);
+    int i, n;
 
     wxASSERT(pDoc);
     wxASSERT(wxDynamicCast(pDoc, CMainDocument));
@@ -218,10 +230,14 @@ void CViewProjectsGrid::OnProjectUpdate( wxCommandEvent& WXUNUSED(event) ) {
 
     pFrame->UpdateStatusText(_("Updating project..."));
 
-    strProjectName = m_pGridPane->GetCellValue(m_pGridPane->GetFirstSelectedRow(), COLUMN_PROJECT);
-
-    pDoc->ProjectUpdate(HtmlEntityEncode(strProjectName).Trim(false));
+    wxArrayInt arrSelRows = m_pGridPane->GetSelectedRows2();	
+    n = (int)arrSelRows.GetCount();
+    for(i=0; i<n; i++) {
+        strProjectURL = m_pGridPane->GetCellValue(arrSelRows[i], COLUMN_HIDDEN_URL);
 
+        pDoc->ProjectUpdate(HtmlEntityEncode(strProjectURL).Trim(false));
+    }
+    
     pFrame->UpdateStatusText(wxT(""));
 
     m_bForceUpdateSelection = true;
@@ -236,9 +252,10 @@ void CViewProjectsGrid::OnProjectUpdate( wxCommandEvent& WXUNUSED(event) ) {
 void CViewProjectsGrid::OnProjectSuspend( wxCommandEvent& WXUNUSED(event) ) {
     wxLogTrace(wxT("Function Start/End"), wxT("CViewProjectsGrid::OnProjectSuspend - Function Begin"));
 
-    wxString        strProjectName = wxEmptyString;
+    wxString        strProjectURL  = wxEmptyString;
     CMainDocument*  pDoc           = wxGetApp().GetDocument();
     CAdvancedFrame* pFrame         = wxDynamicCast(GetParent()->GetParent()->GetParent(), CAdvancedFrame);
+    int i, n;
 
     wxASSERT(pDoc);
     wxASSERT(wxDynamicCast(pDoc, CMainDocument));
@@ -246,24 +263,27 @@ void CViewProjectsGrid::OnProjectSuspend( wxCommandEvent& WXUNUSED(event) ) {
     wxASSERT(wxDynamicCast(pFrame, CAdvancedFrame));
     wxASSERT(m_pGridPane);
 
-    strProjectName = 
-        HtmlEntityEncode(
-            m_pGridPane->GetCellValue(
-                m_pGridPane->GetFirstSelectedRow(),
-                COLUMN_PROJECT
-            ).Trim(false)
-        );
-    PROJECT* project = pDoc->project(strProjectName);
-
-    if (project->suspended_via_gui) {
-        pFrame->UpdateStatusText(_("Resuming project..."));
-        pDoc->ProjectResume(strProjectName);
-        pFrame->UpdateStatusText(wxT(""));
-    } else {
-        pFrame->UpdateStatusText(_("Suspending project..."));
-        pDoc->ProjectSuspend(strProjectName);
-        pFrame->UpdateStatusText(wxT(""));
+    wxArrayInt arrSelRows = m_pGridPane->GetSelectedRows2();	
+    n = (int)arrSelRows.GetCount();
+    for(i=0; i<n; i++) {
+        strProjectURL = 
+            HtmlEntityEncode(
+                m_pGridPane->GetCellValue(
+                    arrSelRows[i],
+                    COLUMN_HIDDEN_URL
+                ).Trim(false)
+            );
+        PROJECT* project = pDoc->project(strProjectURL);
+        
+        if (project->suspended_via_gui) {
+            pFrame->UpdateStatusText(_("Resuming project..."));
+            pDoc->ProjectResume(strProjectURL);
+        } else {
+            pFrame->UpdateStatusText(_("Suspending project..."));
+            pDoc->ProjectSuspend(strProjectURL);
+        }
     }
+    pFrame->UpdateStatusText(wxT(""));
 	
     m_bForceUpdateSelection = true;
     UpdateSelection();
@@ -276,9 +296,10 @@ void CViewProjectsGrid::OnProjectSuspend( wxCommandEvent& WXUNUSED(event) ) {
 void CViewProjectsGrid::OnProjectNoNewWork( wxCommandEvent& WXUNUSED(event) ) {
     wxLogTrace(wxT("Function Start/End"), wxT("CViewProjectsGrid::OnProjectNoNewWork - Function Begin"));
 
-    wxString        strProjectName = wxEmptyString;
+    wxString        strProjectURL = wxEmptyString;
     CMainDocument*  pDoc           = wxGetApp().GetDocument();
     CAdvancedFrame* pFrame         = wxDynamicCast(GetParent()->GetParent()->GetParent(), CAdvancedFrame);
+    int i, n;
 
     wxASSERT(pDoc);
     wxASSERT(wxDynamicCast(pDoc, CMainDocument));
@@ -286,25 +307,28 @@ void CViewProjectsGrid::OnProjectNoNewWork( wxCommandEvent& WXUNUSED(event) ) {
     wxASSERT(wxDynamicCast(pFrame, CAdvancedFrame));
     wxASSERT(m_pGridPane);
 
-    strProjectName = 
-        HtmlEntityEncode(
-            m_pGridPane->GetCellValue(
-                m_pGridPane->GetFirstSelectedRow(),
-                COLUMN_PROJECT
-            ).Trim(false)
-        );
-    PROJECT* project = pDoc->project(strProjectName);
+    wxArrayInt arrSelRows = m_pGridPane->GetSelectedRows2();	
+    n = (int)arrSelRows.GetCount();
+    for(i=0; i<n; i++) {
+        strProjectURL = 
+            HtmlEntityEncode(
+                m_pGridPane->GetCellValue(
+                    arrSelRows[i],
+                    COLUMN_HIDDEN_URL
+                ).Trim(false)
+            );
+        PROJECT* project = pDoc->project(strProjectURL);
 
-    if (project->dont_request_more_work) {
-        pFrame->UpdateStatusText(_("Telling project to allow additional task downloads..."));
-        pDoc->ProjectAllowMoreWork(strProjectName);
-        pFrame->UpdateStatusText(wxT(""));
-    } else {
-        pFrame->UpdateStatusText(_("Telling project to not fetch any additional tasks..."));
-        pDoc->ProjectNoMoreWork(strProjectName);
-        pFrame->UpdateStatusText(wxT(""));
+        if (project->dont_request_more_work) {
+            pFrame->UpdateStatusText(_("Telling project to allow additional task downloads..."));
+            pDoc->ProjectAllowMoreWork(strProjectURL);
+        } else {
+            pFrame->UpdateStatusText(_("Telling project to not fetch any additional tasks..."));
+            pDoc->ProjectNoMoreWork(strProjectURL);
+        }
     }
-
+    pFrame->UpdateStatusText(wxT(""));
+    
     m_bForceUpdateSelection = true;
     UpdateSelection();
     pFrame->FireRefreshView();
@@ -320,9 +344,11 @@ void CViewProjectsGrid::OnProjectReset( wxCommandEvent& WXUNUSED(event) ) {
 
     wxInt32         iAnswer        = 0;
     wxString        strProjectName = wxEmptyString;
+    wxString        strProjectURL  = wxEmptyString;
     wxString        strMessage     = wxEmptyString;
     CMainDocument*  pDoc           = wxGetApp().GetDocument();
     CAdvancedFrame* pFrame         = wxDynamicCast(GetParent()->GetParent()->GetParent(), CAdvancedFrame);
+    int i, n;
 
     wxASSERT(pDoc);
     wxASSERT(wxDynamicCast(pDoc, CMainDocument));
@@ -335,24 +361,29 @@ void CViewProjectsGrid::OnProjectReset( wxCommandEvent& WXUNUSED(event) ) {
 
     pFrame->UpdateStatusText(_("Resetting project..."));
 
-    strProjectName = m_pGridPane->GetCellValue(m_pGridPane->GetFirstSelectedRow(), COLUMN_PROJECT);
+    wxArrayInt arrSelRows = m_pGridPane->GetSelectedRows2();	
+    n = (int)arrSelRows.GetCount();
+    for(i=0; i<n; i++) {
+        strProjectName = m_pGridPane->GetCellValue(arrSelRows[i], COLUMN_PROJECT);
+        strProjectURL = m_pGridPane->GetCellValue(arrSelRows[i], COLUMN_HIDDEN_URL);
 
-    strMessage.Printf(
-        _("Are you sure you want to reset project '%s'?"),
-        strProjectName.c_str()    
-    );
+        strMessage.Printf(
+            _("Are you sure you want to reset project '%s'?"),
+            strProjectName.c_str()    
+        );
 
-    iAnswer = ::wxMessageBox(
-        strMessage,
-        _("Reset Project"),
-        wxYES_NO | wxICON_QUESTION,
-        this
-    );
+        iAnswer = ::wxMessageBox(
+            strMessage,
+            _("Reset Project"),
+            wxYES_NO | wxICON_QUESTION,
+            this
+        );
 
-    if (wxYES == iAnswer) {
-        pDoc->ProjectReset(HtmlEntityEncode(strProjectName.Trim(false)));
+        if (wxYES == iAnswer) {
+            pDoc->ProjectReset(HtmlEntityEncode(strProjectURL.Trim(false)));
+        }
     }
-
+    
     pFrame->UpdateStatusText(wxT(""));
 
     m_bForceUpdateSelection = true;
@@ -368,9 +399,11 @@ void CViewProjectsGrid::OnProjectDetach( wxCommandEvent& WXUNUSED(event) ) {
 
     wxInt32         iAnswer        = 0;
     wxString        strProjectName = wxEmptyString;
+    wxString        strProjectURL  = wxEmptyString;
     wxString        strMessage     = wxEmptyString;
     CMainDocument*  pDoc           = wxGetApp().GetDocument();
     CAdvancedFrame* pFrame         = wxDynamicCast(GetParent()->GetParent()->GetParent(), CAdvancedFrame);
+    int i, n;
 
     wxASSERT(pDoc);
     wxASSERT(wxDynamicCast(pDoc, CMainDocument));
@@ -383,24 +416,29 @@ void CViewProjectsGrid::OnProjectDetach( wxCommandEvent& WXUNUSED(event) ) {
 
     pFrame->UpdateStatusText(_("Detaching from project..."));
 
-    strProjectName = m_pGridPane->GetCellValue(m_pGridPane->GetFirstSelectedRow(), COLUMN_PROJECT);
+    wxArrayInt arrSelRows = m_pGridPane->GetSelectedRows2();	
+    n = (int)arrSelRows.GetCount();
+    for(i=0; i<n; i++) {
+        strProjectName = m_pGridPane->GetCellValue(arrSelRows[i], COLUMN_PROJECT);
+        strProjectURL = m_pGridPane->GetCellValue(arrSelRows[i], COLUMN_HIDDEN_URL);
 
-    strMessage.Printf(
-        _("Are you sure you want to detach from project '%s'?"),
-        strProjectName.c_str()
-    );
+        strMessage.Printf(
+            _("Are you sure you want to detach from project '%s'?"),
+            strProjectName.c_str()
+        );
 
-    iAnswer = ::wxMessageBox(
-        strMessage,
-        _("Detach from Project"),
-        wxYES_NO | wxICON_QUESTION,
-        this
-    );
+        iAnswer = ::wxMessageBox(
+            strMessage,
+            _("Detach from Project"),
+            wxYES_NO | wxICON_QUESTION,
+            this
+        );
 
-    if (wxYES == iAnswer) {
-        pDoc->ProjectDetach(HtmlEntityEncode(strProjectName.Trim(false)));
+        if (wxYES == iAnswer) {
+            pDoc->ProjectDetach(HtmlEntityEncode(strProjectURL.Trim(false)));
+        }
     }
-
+    
     pFrame->UpdateStatusText(wxT(""));
 
     m_bForceUpdateSelection = true;
@@ -440,6 +478,7 @@ wxInt32 CViewProjectsGrid::GetDocCount() {
     return wxGetApp().GetDocument()->GetProjectCount();
 }
 
+#if PREVENT_MULTIPLE_PROJECT_SELECTIONS
 void CViewProjectsGrid::OnGridSelectRange( wxGridRangeSelectEvent& event ) {
     // Disallow multiple selections
     if (m_pGridPane->GetSelectedRows2().size() > 1) {
@@ -457,22 +496,36 @@ void CViewProjectsGrid::OnCellLeftClick( wxGridEvent& event ) {
     m_pGridPane->ClearSelection();
     m_pGridPane->SelectRow(theRow);
 }
-
+#endif
 
 void CViewProjectsGrid::UpdateSelection() {
-    wxString        strProjectName = wxEmptyString;
+    wxString        strProjectURL = wxEmptyString;
     CTaskItemGroup* pGroup = NULL;
     PROJECT*        project = NULL;
     CMainDocument*  pDoc = wxGetApp().GetDocument();
+    int             i, n;
+    bool            wasSuspended=false, wasNoNewWork=false;
+    static int      lastCount = 0;
 
     wxASSERT(pDoc);
     wxASSERT(wxDynamicCast(pDoc, CMainDocument));
     wxASSERT(m_pTaskPane);
     wxASSERT(m_pGridPane);
 
-	if(!m_bForceUpdateSelection) {
-		return;
-	}
+    wxArrayInt arrSelRows = m_pGridPane->GetSelectedRows2();	
+    n = (int)arrSelRows.GetCount();
+
+    // Normally, OnGridSelectRange() is called twice: one for deselecting the previous item 
+    //  and again for selecting the new item, but occasionally it is not triggered for the 
+    //  new selection.  This hack works around that bug.
+    if (n != lastCount) {
+        m_bForceUpdateSelection = true;
+        lastCount = n;
+    }
+    
+    if(!m_bForceUpdateSelection) {
+        return;
+    }
 
     CBOINCBaseView::PreUpdateSelection();
 
@@ -480,20 +533,33 @@ void CViewProjectsGrid::UpdateSelection() {
     // Update the tasks static box buttons
     //
     pGroup = m_TaskGroups[0];
+    
+    if (n > 0) {
+        m_pTaskPane->EnableTaskGroupTasks(pGroup);
+    } else {
+        m_pTaskPane->DisableTaskGroupTasks(pGroup);
+        UpdateWebsiteSelection(GRP_WEBSITES, NULL);
+        if(m_TaskGroups.size()>1) {
+            m_pTaskPane->DisableTaskGroupTasks(m_TaskGroups[1]);
+        }
+    }
+   
+    for(i=0; i<n; i++) {
+        strProjectURL = HtmlEntityEncode(
+            m_pGridPane->GetCellValue(arrSelRows[i],COLUMN_HIDDEN_URL).Trim(false)
+        );
+        project = pDoc->project(strProjectURL);
+        if (!project) {
+            m_pTaskPane->DisableTaskGroupTasks(pGroup);
+            if(m_TaskGroups.size()>1) {
+                m_pTaskPane->DisableTaskGroupTasks(m_TaskGroups[1]);
+            }
+            return;
+        }
 
-	if (m_pGridPane->GetSelectedRows2().size() == 1) {
-        strProjectName = 
-            HtmlEntityEncode(
-                m_pGridPane->GetCellValue(
-                    m_pGridPane->GetFirstSelectedRow(),
-                    COLUMN_PROJECT
-                ).Trim(false)
-            );
-        project = pDoc->project(strProjectName);
-        m_pTaskPane->EnableTask(pGroup->m_Tasks[BTN_UPDATE]);
-        m_pTaskPane->EnableTask(pGroup->m_Tasks[BTN_SUSPEND]);
-        if (project) {
-            if (project->suspended_via_gui) {
+        if (i == 0) {
+            wasSuspended = project->suspended_via_gui;
+             if (project->suspended_via_gui) {
                 m_pTaskPane->UpdateTask(
                     pGroup->m_Tasks[BTN_SUSPEND], _("Resume"), _("Resume tasks for this project.")
                 );
@@ -502,9 +568,16 @@ void CViewProjectsGrid::UpdateSelection() {
                     pGroup->m_Tasks[BTN_SUSPEND], _("Suspend"), _("Suspend tasks for this project.")
                 );
             }
+        } else {
+            if (wasSuspended != project->suspended_via_gui) {
+                // Disable Suspend / Resume button if the multiple selection
+                // has a mix of suspended and not suspended projects
+                m_pTaskPane->DisableTask(pGroup->m_Tasks[BTN_SUSPEND]);
+            }
         }
-        m_pTaskPane->EnableTask(pGroup->m_Tasks[BTN_NOWORK]);
-        if (project) {
+
+        if (i == 0) {
+            wasNoNewWork = project->dont_request_more_work;
             if (project->dont_request_more_work) {
                 m_pTaskPane->UpdateTask(
                     pGroup->m_Tasks[BTN_NOWORK], _("Allow new tasks"), _("Allow fetching new tasks for this project.")
@@ -514,26 +587,34 @@ void CViewProjectsGrid::UpdateSelection() {
                     pGroup->m_Tasks[BTN_NOWORK], _("No new tasks"), _("Don't fetch new tasks for this project.")
                 );
             }
-        }
-        m_pTaskPane->EnableTask(pGroup->m_Tasks[BTN_RESET]);
-        if (project && project->attached_via_acct_mgr) {
-            m_pTaskPane->DisableTask(pGroup->m_Tasks[BTN_DETACH]);
         } else {
-            m_pTaskPane->EnableTask(pGroup->m_Tasks[BTN_DETACH]);
+            if (wasNoNewWork != project->dont_request_more_work) {
+                // Disable Allow New Work / No New Work button if the multiple 
+                // selection has a mix of Allow New Work and No New Work projects
+                m_pTaskPane->DisableTask(pGroup->m_Tasks[BTN_NOWORK]);
+            }
+        }
+        
+        if (project->attached_via_acct_mgr) {
+            m_pTaskPane->DisableTask(pGroup->m_Tasks[BTN_DETACH]);
+        }
+        
+        if (n == 1) {
+            UpdateWebsiteSelection(GRP_WEBSITES, project);
+            if(m_TaskGroups.size()>1) {
+                m_pTaskPane->EnableTaskGroupTasks(m_TaskGroups[1]);
+            }
+        } else {
+            UpdateWebsiteSelection(GRP_WEBSITES, NULL);
+            if(m_TaskGroups.size()>1) {
+                m_pTaskPane->DisableTaskGroupTasks(m_TaskGroups[1]);
+            }
         }
-
-        UpdateWebsiteSelection(GRP_WEBSITES, project);
-
-    } else {
-        m_pTaskPane->DisableTaskGroupTasks(pGroup);
-		//disable website buttons if they exist
-		if(m_TaskGroups.size()>1) {
-			m_pTaskPane->DisableTaskGroupTasks(m_TaskGroups[1]);
-		}
     }
 
     CBOINCBaseView::PostUpdateSelection();
-	m_bForceUpdateSelection=false;
+
+    m_bForceUpdateSelection=false;
 }
 
 void CViewProjectsGrid::UpdateWebsiteSelection(long lControlGroup, PROJECT* project){
@@ -546,51 +627,55 @@ void CViewProjectsGrid::UpdateWebsiteSelection(long lControlGroup, PROJECT* proj
 
     // Update the websites list
     //
-    if (m_TaskGroups.size() > 1) {
+    if (m_bForceUpdateSelection) {
+        if (m_TaskGroups.size() > 1) {
 
-        // Delete task group, objects, and controls.
-        pGroup = m_TaskGroups[lControlGroup];
+            // Delete task group, objects, and controls.
+            pGroup = m_TaskGroups[lControlGroup];
 
-        m_pTaskPane->DeleteTaskGroupAndTasks(pGroup);
-        for (i=0; i<pGroup->m_Tasks.size(); i++) {
-            delete pGroup->m_Tasks[i];
+            m_pTaskPane->DeleteTaskGroupAndTasks(pGroup);
+            for (i=0; i<pGroup->m_Tasks.size(); i++) {
+                delete pGroup->m_Tasks[i];
+            }
+            pGroup->m_Tasks.clear();
+            delete pGroup;
+
+            pGroup = NULL;
+
+            m_TaskGroups.erase( m_TaskGroups.begin() + 1 );
         }
-        pGroup->m_Tasks.clear();
-        delete pGroup;
 
-        pGroup = NULL;
+        // If something is selected create the tasks and controls
+        if (m_pGridPane->GetSelectedRows2().size() == 1) {
+            if (project) {
+                // Create the web sites task group
+                pGroup = new CTaskItemGroup( _("Web sites") );
+                m_TaskGroups.push_back( pGroup );
 
-        m_TaskGroups.erase( m_TaskGroups.begin() + 1 );
-    }
-
-    // If something is selected create the tasks and controls
-	if (m_pGridPane->GetSelectedRows2().size()==1) {
-        if (project) {
-            // Create the web sites task group
-            pGroup = new CTaskItemGroup( _("Web sites") );
-            m_TaskGroups.push_back( pGroup );
-
-            // Default project url
-            pItem = new CTaskItem(
-                wxString(project->project_name.c_str(), wxConvUTF8),
-                wxT(""),
-                wxString(project->master_url.c_str(), wxConvUTF8),
-                ID_TASK_PROJECT_WEB_PROJDEF_MIN
-            );
-            pGroup->m_Tasks.push_back(pItem);
-
-
-            // Project defined urls
-            for (i=0;(i<project->gui_urls.size())&&(i<=ID_TASK_PROJECT_WEB_PROJDEF_MAX);i++) {
+                // Default project url
                 pItem = new CTaskItem(
-                    wxGetTranslation(wxString(project->gui_urls[i].name.c_str(), wxConvUTF8)),
-                    wxGetTranslation(wxString(project->gui_urls[i].description.c_str(), wxConvUTF8)),
-                    wxString(project->gui_urls[i].url.c_str(), wxConvUTF8),
-                    ID_TASK_PROJECT_WEB_PROJDEF_MIN + 1 + i
+                    wxString(project->project_name.c_str(), wxConvUTF8),
+                    wxT(""),
+                    wxString(project->master_url.c_str(), wxConvUTF8),
+                    ID_TASK_PROJECT_WEB_PROJDEF_MIN
                 );
                 pGroup->m_Tasks.push_back(pItem);
+
+
+                // Project defined urls
+                for (i=0;(i<project->gui_urls.size())&&(i<=ID_TASK_PROJECT_WEB_PROJDEF_MAX);i++) {
+                    pItem = new CTaskItem(
+                        wxGetTranslation(wxString(project->gui_urls[i].name.c_str(), wxConvUTF8)),
+                        wxGetTranslation(wxString(project->gui_urls[i].description.c_str(), wxConvUTF8)),
+                        wxString(project->gui_urls[i].url.c_str(), wxConvUTF8),
+                        ID_TASK_PROJECT_WEB_PROJDEF_MIN + 1 + i
+                    );
+                    pGroup->m_Tasks.push_back(pItem);
+                }
             }
         }
+
+        m_bForceUpdateSelection = false;
     }
 }
 
@@ -673,10 +758,18 @@ void CViewProjectsGrid::FormatStatus(wxInt32 item, wxString& strBuffer) {
             append_to_status(strBuffer, _("Communication deferred ") + tsNextRPC.Format());
         }
     }
-	if(wxEmptyString == strBuffer)
-	{
-		append_to_status(strBuffer, wxT("---"));
-	}
+    
+    if(wxEmptyString == strBuffer) {
+        append_to_status(strBuffer, wxT("---"));
+    }
+}
+
+
+void CViewProjectsGrid::FormatProjectURL(wxInt32 item, wxString& strBuffer) {
+    PROJECT* project = wxGetApp().GetDocument()->project(item);
+    if (project) {
+         strBuffer = wxString(project->master_url.c_str(), wxConvUTF8);
+    }
 }
 
 
@@ -771,57 +864,71 @@ void CViewProjectsGrid::OnListRender( wxTimerEvent& WXUNUSED(event) ) {
     if(docCount != m_pGridPane->GetNumberRows()) {
         if (docCount > m_pGridPane->GetNumberRows()) {
     	    m_pGridPane->AppendRows(docCount - m_pGridPane->GetNumberRows());
-        } else {
-		    m_pGridPane->DeleteRows(0, m_pGridPane->GetNumberRows() - docCount);
+         } else {
+            m_pGridPane->DeleteRows(0, m_pGridPane->GetNumberRows() - docCount);
+            m_bForceUpdateSelection = true;
         }
         wxASSERT(docCount == m_pGridPane->GetNumberRows());
     }
 
-	wxString strBuffer;
-	int iMax = m_pGridPane->GetNumberRows();
-	for(int iRow = 0; iRow < iMax; iRow++) {
+    m_bIgnoreUIEvents = true;
+    m_pGridPane->SaveSelection();
+    m_bIgnoreUIEvents = false;
+
+    wxString strBuffer;
+    int iMax = m_pGridPane->GetNumberRows();
+    for(int iRow = 0; iRow < iMax; iRow++) {
 		
         FormatProjectName(iRow, strBuffer);
         if (m_pGridPane->GetCellValue(iRow, COLUMN_PROJECT) != strBuffer) {
-		    m_pGridPane->SetCellValue(iRow, COLUMN_PROJECT, strBuffer);
+            m_pGridPane->SetCellValue(iRow, COLUMN_PROJECT, strBuffer);
         }
 
-		FormatAccountName(iRow, strBuffer);
+        FormatAccountName(iRow, strBuffer);
         if (m_pGridPane->GetCellValue(iRow, COLUMN_ACCOUNTNAME) != strBuffer) {
-		    m_pGridPane->SetCellValue(iRow, COLUMN_ACCOUNTNAME, strBuffer);
+            m_pGridPane->SetCellValue(iRow, COLUMN_ACCOUNTNAME, strBuffer);
         }
 
-		FormatTeamName(iRow, strBuffer);
+        FormatTeamName(iRow, strBuffer);
         if (m_pGridPane->GetCellValue(iRow, COLUMN_TEAMNAME) != strBuffer) {
-	    	m_pGridPane->SetCellValue(iRow, COLUMN_TEAMNAME, strBuffer);
+            m_pGridPane->SetCellValue(iRow, COLUMN_TEAMNAME, strBuffer);
         }
 
-		FormatTotalCredit(iRow, strBuffer);
+        FormatTotalCredit(iRow, strBuffer);
         if (m_pGridPane->GetCellValue(iRow, COLUMN_TOTALCREDIT) != strBuffer) {
-    		m_pGridPane->SetCellValue(iRow, COLUMN_TOTALCREDIT, strBuffer);
+            m_pGridPane->SetCellValue(iRow, COLUMN_TOTALCREDIT, strBuffer);
         }
 
-		FormatAVGCredit(iRow, strBuffer);
+        FormatAVGCredit(iRow, strBuffer);
         if (m_pGridPane->GetCellValue(iRow, COLUMN_AVGCREDIT) != strBuffer) {
-		    m_pGridPane->SetCellValue(iRow, COLUMN_AVGCREDIT, strBuffer);
+            m_pGridPane->SetCellValue(iRow, COLUMN_AVGCREDIT, strBuffer);
         }
 
-		FormatResourceShare(iRow, strBuffer);
+        FormatResourceShare(iRow, strBuffer);
         if (m_pGridPane->GetCellValue(iRow, COLUMN_RESOURCESHARE) != strBuffer) {
-	    	m_pGridPane->SetCellValue(iRow, COLUMN_RESOURCESHARE, strBuffer);
-		    m_pGridPane->SetCellAlignment(iRow, COLUMN_RESOURCESHARE, wxALIGN_CENTRE, wxALIGN_CENTRE);
+            m_pGridPane->SetCellValue(iRow, COLUMN_RESOURCESHARE, strBuffer);
+            m_pGridPane->SetCellAlignment(iRow, COLUMN_RESOURCESHARE, wxALIGN_CENTRE, wxALIGN_CENTRE);
+    }
+
+        strBuffer = wxEmptyString;
+        FormatStatus(iRow, strBuffer);
+        if (m_pGridPane->GetCellValue(iRow, COLUMN_STATUS) != strBuffer) {
+            m_pGridPane->SetCellValue(iRow, COLUMN_STATUS, strBuffer);
         }
 
-		strBuffer = wxEmptyString;
-		FormatStatus(iRow, strBuffer);
-        if (m_pGridPane->GetCellValue(iRow, COLUMN_STATUS) != strBuffer) {
-    		m_pGridPane->SetCellValue(iRow, COLUMN_STATUS, strBuffer);
+        FormatProjectURL(iRow, strBuffer);
+        if (m_pGridPane->GetCellValue(iRow, COLUMN_HIDDEN_URL) != strBuffer) {
+            m_pGridPane->SetCellValue(iRow, COLUMN_HIDDEN_URL, strBuffer);
         }
     }
 
     m_pGridPane->SortData();
 
-	UpdateSelection();
+    m_bIgnoreUIEvents = true;
+    m_pGridPane->RestoreSelection();
+    m_bIgnoreUIEvents = false;
+
+    UpdateSelection();
 
     wxLogTrace(wxT("Function Start/End"), wxT("CViewProjectsGrid::OnListRender - Function End"));
 }
