@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _VIEWRESOURCES_H_
 #define _VIEWRESOURCES_H_
@@ -54,8 +54,6 @@ protected:
 	wxPieCtrl*				m_pieCtrlBOINC;
 	wxPieCtrl*				m_pieCtrlTotal;
 
-	wxArrayColour			m_aProjectColours;
-
 	bool					m_BOINCwasEmpty;
 
     virtual void            UpdateSelection();
