@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "ViewStatistics.h"
@@ -2112,4 +2112,4 @@ void CViewStatistics::UpdateSelection() {
 }
 
 
-const char *BOINC_RCSID_7aadb93333 = "$Id: ViewStatistics.cpp 12761 2007-05-29 05:07:35Z romw $";
+const char *BOINC_RCSID_7aadb93333 = "$Id: ViewStatistics.cpp 13804 2007-10-09 11:35:47Z fthomas $";
