@@ -585,7 +585,8 @@ wxInt32 CViewWork::FormatApplicationName(wxInt32 item, wxString& strBuffer) cons
     CMainDocument* pDoc = wxGetApp().GetDocument();
     RESULT* result = wxGetApp().GetDocument()->result(item);
     RESULT* state_result = NULL;
-    wxString strLocalBuffer;
+    wxString strAppBuffer = wxEmptyString;
+    wxString strClassBuffer = wxEmptyString;
 
     wxASSERT(pDoc);
     wxASSERT(wxDynamicCast(pDoc, CMainDocument));
@@ -600,23 +601,27 @@ wxInt32 CViewWork::FormatApplicationName(wxInt32 item, wxString& strBuffer) cons
 
         wxString strLocale = wxString(setlocale(LC_NUMERIC, NULL), wxConvUTF8);
         setlocale(LC_NUMERIC, "C");
+
         if (state_result->wup->app->user_friendly_name.size()) {
-            strLocalBuffer = HtmlEntityDecode(wxString(state_result->app->user_friendly_name.c_str(), wxConvUTF8));
+            strAppBuffer = HtmlEntityDecode(wxString(state_result->app->user_friendly_name.c_str(), wxConvUTF8));
         } else {
-            strLocalBuffer = HtmlEntityDecode(wxString(state_result->wup->avp->app_name.c_str(), wxConvUTF8));
+            strAppBuffer = HtmlEntityDecode(wxString(state_result->wup->avp->app_name.c_str(), wxConvUTF8));
         }
-        char buf[256];
+        
         if (state_result->wup->avp->plan_class.size()) {
-            sprintf(buf, " (%s)", state_result->wup->avp->plan_class.c_str());
-        } else {
-            strcpy(buf, "");
+            strClassBuffer.Printf(
+                wxT(" (%s)"),
+                wxString(state_result->wup->avp->plan_class.c_str(), wxConvUTF8).c_str()
+            );
         }
+        
         strBuffer.Printf(
             wxT(" %s %.2f%s"), 
-            strLocalBuffer.c_str(),
+            strAppBuffer.c_str(),
             state_result->wup->avp->version_num/100.0,
-            buf
+            strClassBuffer.c_str()
         );
+
         setlocale(LC_NUMERIC, (const char*)strLocale.mb_str());
     }
     return 0;
@@ -845,4 +850,4 @@ wxInt32 CViewWork::FormatStatus(wxInt32 item, wxString& strBuffer) const {
 }
 
 
-const char *BOINC_RCSID_34f860f736 = "$Id: ViewWork.cpp 15024 2008-04-07 09:31:15Z charlief $";
+const char *BOINC_RCSID_34f860f736 = "$Id: ViewWork.cpp 15586 2008-07-09 16:45:38Z romw $";
