@@ -5,7 +5,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     24/3/98
-// RCS-ID:      $Id: taskbarex.h 12240 2007-03-17 19:37:56Z rwalton $
+// RCS-ID:      $Id: taskbarex.h 15453 2008-06-23 18:48:59Z romw $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////
@@ -44,10 +44,9 @@ public:
 
 // Operations
 
-    bool SetIcon(
-        const wxIcon& icon,
-        const wxString& tooltip = wxEmptyString
-    );
+    bool SetIcon( const wxIcon& icon );
+
+    bool SetTooltip( const wxString& message );
 
     bool SetBalloon(
         const wxIcon& icon, 
@@ -58,6 +57,7 @@ public:
     );
 
     bool RemoveIcon();
+    void UpdateIcon();
 
     bool PopupMenu(wxMenu *menu); //, int x, int y);
 
