@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 
 #if defined(__GNUG__) && !defined(__APPLE__)
@@ -41,6 +41,7 @@
 #include "WizardAttachProject.h"
 #include "WizardAccountManager.h"
 #include "error_numbers.h"
+#include "version.h"
 
 #include "sg_BoincSimpleGUI.h"
 #include "sg_ImageLoader.h"
@@ -59,8 +60,9 @@ BEGIN_EVENT_TABLE(CSimpleFrame, CBOINCBaseFrame)
     EVT_HELP(wxID_ANY, CSimpleFrame::OnHelp)
     EVT_FRAME_RELOADSKIN(CSimpleFrame::OnReloadSkin)
     // We can't eliminate the Mac Help menu, so we might as well make it useful.
-    EVT_MENU(ID_HELPBOINCMANAGER, CSimpleFrame::OnHelpBOINCManager)
-    EVT_MENU(ID_HELPBOINCWEBSITE, CSimpleFrame::OnHelpBOINCWebsite)
+    EVT_MENU(ID_HELPBOINC, CSimpleFrame::OnHelpBOINC)
+    EVT_MENU(ID_HELPBOINCMANAGER, CSimpleFrame::OnHelpBOINC)
+    EVT_MENU(ID_HELPBOINCWEBSITE, CSimpleFrame::OnHelpBOINC)
 END_EVENT_TABLE()
 
 CSimpleFrame::CSimpleFrame() {
@@ -69,7 +71,7 @@ CSimpleFrame::CSimpleFrame() {
 }
 
 
-CSimpleFrame::CSimpleFrame(wxString title, wxIcon* icon) : 
+CSimpleFrame::CSimpleFrame(wxString title, wxIcon* icon, wxIcon* icon32) : 
     CBOINCBaseFrame((wxFrame *)NULL, ID_SIMPLEFRAME, title, wxDefaultPosition, 
 #ifdef __WXMAC__
                     wxSize(409, 561),
@@ -83,7 +85,10 @@ CSimpleFrame::CSimpleFrame(wxString title, wxIcon* icon) :
     RestoreState();
 
     // Initialize Application
-    SetIcon(*icon);
+    wxIconBundle icons;
+    icons.AddIcon(*icon);
+    icons.AddIcon(*icon32);
+    SetIcons(icons);
     
 #ifdef __WXMAC__
     // We can't eliminate the Mac menu bar or the Help menu, so we 
@@ -106,6 +111,24 @@ CSimpleFrame::CSimpleFrame(wxString title, wxIcon* icon) :
     // Help menu
     wxMenu *menuHelp = new wxMenu;
 
+    // %s is the project name
+    //    i.e. 'BOINC', 'GridRepublic'
+    strMenuName.Printf(
+        _("%s &help"), 
+        pSkinAdvanced->GetApplicationShortName().c_str()
+    );
+    // %s is the project name
+    //    i.e. 'BOINC', 'GridRepublic'
+    strMenuDescription.Printf(
+        _("Show information about %s"), 
+        pSkinAdvanced->GetApplicationShortName().c_str()
+    );
+    menuHelp->Append(
+        ID_HELPBOINC,
+        strMenuName, 
+        strMenuDescription
+    );
+
     // %s is the application name
     //    i.e. 'BOINC Manager', 'GridRepublic Manager'
     strMenuName.Printf(
@@ -128,7 +151,7 @@ CSimpleFrame::CSimpleFrame(wxString title, wxIcon* icon) :
     //    i.e. 'BOINC', 'GridRepublic'
     strMenuName.Printf(
         _("%s &website"), 
-        pSkinAdvanced->GetProjectName().c_str()
+        pSkinAdvanced->GetApplicationShortName().c_str()
     );
     // %s is the application name
     //    i.e. 'BOINC Manager', 'GridRepublic Manager'
@@ -280,11 +303,15 @@ void CSimpleFrame::OnHelp(wxHelpEvent& event) {
 
     if (IsShown()) {
 		std::string url;
-		url = wxGetApp().GetSkinManager()->GetAdvanced()->GetCompanyWebsite().mb_str();
-		canonicalize_master_url(url);
+		url = wxGetApp().GetSkinManager()->GetAdvanced()->GetOrganizationHelpUrl().mb_str();
 
 		wxString wxurl;
-		wxurl.Printf(wxT("%smanager_links.php?target=simple&controlid=%d"), url.c_str(), event.GetId());
+		wxurl.Printf(
+            wxT("%s?target=simple&version=%s&controlid=%d"),
+            url.c_str(),
+            BOINC_VERSION_STRING,
+            event.GetId()
+        );
         ExecuteBrowserLink(wxurl);
     }
 
@@ -292,32 +319,24 @@ void CSimpleFrame::OnHelp(wxHelpEvent& event) {
 }
 
 
-void CSimpleFrame::OnHelpBOINCManager(wxCommandEvent& WXUNUSED(event)) {
-    wxLogTrace(wxT("Function Start/End"), wxT("CAdvancedFrame::OnHelpBOINCManager - Function Begin"));
+void CSimpleFrame::OnHelpBOINC(wxCommandEvent& event) {
+    wxLogTrace(wxT("Function Start/End"), wxT("CAdvancedFrame::OnHelpBOINC - Function Begin"));
 
     if (IsShown()) {
 		std::string url;
-		url = wxGetApp().GetSkinManager()->GetAdvanced()->GetCompanyWebsite().mb_str();
-		canonicalize_master_url(url);
+		url = wxGetApp().GetSkinManager()->GetAdvanced()->GetOrganizationHelpUrl().mb_str();
 
 		wxString wxurl;
-		wxurl.Printf(wxT("%smanager_links.php?target=simple"),url.c_str());
+		wxurl.Printf(
+            wxT("%s?target=simple&version=%s&controlid=%d"),
+            url.c_str(),
+            BOINC_VERSION_STRING,
+            event.GetId()
+        );
 		ExecuteBrowserLink(wxurl);
     }
 
-    wxLogTrace(wxT("Function Start/End"), wxT("CAdvancedFrame::OnHelpBOINCManager - Function End"));
-}
-
-
-void CSimpleFrame::OnHelpBOINCWebsite(wxCommandEvent& WXUNUSED(event)) {
-    wxLogTrace(wxT("Function Start/End"), wxT("CAdvancedFrame::OnHelpBOINCWebsite - Function Begin"));
-
-    if (IsShown()) {
-        wxString url = wxGetApp().GetSkinManager()->GetAdvanced()->GetCompanyWebsite().c_str();
-        ExecuteBrowserLink(url);
-    }
-
-    wxLogTrace(wxT("Function Start/End"), wxT("CAdvancedFrame::OnHelpBOINCWebsite - Function End"));
+    wxLogTrace(wxT("Function Start/End"), wxT("CAdvancedFrame::OnHelpBOINC - Function End"));
 }
 
 
@@ -397,8 +416,8 @@ void CSimpleFrame::OnConnect(CFrameEvent& WXUNUSED(event)) {
             Show();
         }
 
-        pAMWizard = new CWizardAccountManager(this);
-        if (pAMWizard->Run()) {
+       pAMWizard = new CWizardAccountManager(this);
+       if (pAMWizard->Run()) {
             // If successful, hide the main window
             Hide();
         }
@@ -654,3 +673,4 @@ void CSimplePanel::OnEraseBackground(wxEraseEvent& event){
     dc->DrawBitmap(*pSkinSimple->GetBackgroundImage()->GetBitmap(), 0, 0);
 }
 
+
