@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "sg_DlgPreferences.h"
@@ -33,6 +33,8 @@
 #include "SkinManager.h"
 #include "MainDocument.h"
 #include "hyperlink.h"
+#include "version.h"
+
 #include "sg_CustomControls.h"
 #include "sg_DlgPreferences.h"
 
@@ -564,7 +566,7 @@ void CPanelPreferences::OnButtonHelp( wxCommandEvent& WXUNUSED(event) ) {
     wxLogTrace(wxT("Function Start/End"), wxT("CPanelPreferences::OnHelp - Function Begin"));
 
 	std::string url;
-	url = wxGetApp().GetSkinManager()->GetAdvanced()->GetCompanyWebsite().mb_str();
+	url = wxGetApp().GetSkinManager()->GetAdvanced()->GetOrganizationWebsite().mb_str();
 	canonicalize_master_url(url);
 
 	wxString wxurl;
@@ -1066,11 +1068,15 @@ void CDlgPreferences::OnHelp(wxHelpEvent& event) {
 
     if (IsShown()) {
 		std::string url;
-		url = wxGetApp().GetSkinManager()->GetAdvanced()->GetCompanyWebsite().mb_str();
-		canonicalize_master_url(url);
+		url = wxGetApp().GetSkinManager()->GetAdvanced()->GetOrganizationHelpUrl().mb_str();
 
 		wxString wxurl;
-		wxurl.Printf(wxT("%smanager_links.php?target=simple_preferences&controlid=%d"), url.c_str(), event.GetId());
+	    wxurl.Printf(
+            wxT("%s?target=simple_preferences&version=%s&controlid=%d"),
+            url.c_str(),
+            BOINC_VERSION_STRING,
+            event.GetId()
+        );
         wxHyperLink::ExecuteLink(wxurl);
     }
 
