@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "sg_ViewTabPage.h"
@@ -136,7 +136,7 @@ void CViewTabPage::CreatePage()
 	FormatCPUTime(resultWU, elapsedTimeValue);
 	FormatTimeToCompletion(resultWU, timeRemainingValue);
 	// show graphic button 
-	if (resultWU->supports_graphics) {
+	if (resultWU->supports_graphics || !resultWU->graphics_exec_path.empty()) {
 		m_hasGraphic = true;
 	}
 	int status = ComputeState();
@@ -265,7 +265,7 @@ void CViewTabPage::UpdateInterface()
 
 	wxString strBuffer = wxEmptyString;
 	//Gauge
-	gaugeWUMain->UpdateValue(floor(resultWU->fraction_done * 100000)/1000);
+	gaugeWUMain->SetValue(floor(resultWU->fraction_done * 100000)/1000);
 	//percent
 	percNum = (wxFloat64)(floor(resultWU->fraction_done * 100000)/1000);
     percStr.Printf(_("%.1lf"), percNum);
@@ -282,7 +282,7 @@ void CViewTabPage::UpdateInterface()
 
 	// check to see if we can display graphics
 	bool changed = false;
-	if (resultWU->supports_graphics && isRunning(resultWU) ) {
+	if ((resultWU->supports_graphics || !resultWU->graphics_exec_path.empty()) && isRunning(resultWU) ) {
 		if ( !m_hasGraphic ) {
 			changed = true;
 		}
@@ -407,7 +407,7 @@ void CViewTabPage::SGUITimeFormat(float fBuffer, wxString& strBuffer) const {
 }
 
 void CViewTabPage::OnWorkShowGraphics() {
-	CMainDocument* pDoc     = wxGetApp().GetDocument();
+    CMainDocument* pDoc     = wxGetApp().GetDocument();
     wxInt32  iAnswer        = 0; 
     wxString strMachineName = wxEmptyString;
     
@@ -428,18 +428,8 @@ void CViewTabPage::OnWorkShowGraphics() {
     iAnswer = wxYES;
 #endif
 
-	if (wxYES == iAnswer) {
-		std::string strDefaultWindowStation = std::string((const char*)wxGetApp().m_strDefaultWindowStation.mb_str());
-		std::string strDefaultDesktop = std::string((const char*)wxGetApp().m_strDefaultDesktop.mb_str());
-		std::string strDefaultDisplay = std::string((const char*)wxGetApp().m_strDefaultDisplay.mb_str());
-        pDoc->WorkShowGraphics(
-            m_prjUrl,
-            m_name,
-            MODE_WINDOW,
-            strDefaultWindowStation,
-            strDefaultDesktop,
-            strDefaultDisplay
-        );
+    if (wxYES == iAnswer) {
+        pDoc->WorkShowGraphics(resultWU);
     }
 }
 
@@ -455,8 +445,8 @@ void CViewTabPage::WriteText(wxDC* dc) {
 	dc->GetTextExtent(_("Time Remaining: "), &width, &height);
 	width = width + 20; // add the starting x position
 
-	FormatText(wxT("Elapsed Time: "), elapsedTimeValue, dc, wxPoint(20,230), width);
-	FormatText(wxT("Time Remaining: "), timeRemainingValue, dc, wxPoint(20,255), width);
+	FormatText(_("Elapsed Time: "), elapsedTimeValue, dc, wxPoint(20,230), width);
+	FormatText(_("Time Remaining: "), timeRemainingValue, dc, wxPoint(20,255), width);
 
     dc->DrawText(gaugePercent, wxPoint(290,283)); 
 
@@ -520,7 +510,7 @@ CSkinSimple* pSkinSimple = wxGetApp().GetSkinManager()->GetSimple();
     wxASSERT(wxDynamicCast(pSkinSimple, CSkinSimple));
 
     wxLogTrace(wxT("Function Start/End"), wxT("CViewTabPage::DrawText - Begin"));
-
+    
 #if wxCHECK_VERSION(2,8,0)
     // Workaround for unknown problem with newer versions of wxWidgets
     // At this point, the size of the panel has been reduced to 336,300
