@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include "stdwx.h"
 
@@ -23,4 +23,4 @@
 // and not in this file
 
 
-const char *BOINC_RCSID_4e0e4c54ab = "$Id: stdwx.cpp 12204 2007-03-09 23:44:34Z rwalton $";
+const char *BOINC_RCSID_4e0e4c54ab = "$Id: stdwx.cpp 13804 2007-10-09 11:35:47Z fthomas $";
