@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef __STDWX_H__
 #define __STDWX_H__
@@ -45,6 +45,10 @@
 
 #ifdef __APPLE__
 #include <Carbon/Carbon.h>
+
+// Use localtime_r and fmtime_r in wxWidgets and eliminate compiler warnings
+#define HAVE_LOCALTIME_R 1
+#define HAVE_GMTIME_R 1
 #endif
 
 #include <wx/wx.h>
