@@ -1,6 +1,323 @@
 <?
 
 $project_news = array(
+array("May 9, 2008",
+    "The <a href=http://boincfaq.mundayweb.com/>BOINC FAQ Service</a>
+    is now available in Spanish and French
+    (as well as English, German, and Dutch)."
+),
+array("May 7, 2008",
+    "<a href=http://www.predictioncenter.org/casp8/index.cgi>CASP8</a>,
+    a competition for protein structure prediction, starts soon.
+    <a href=http://www.rechenkraft.net>Rechenkraft.net</a> is
+    sponsoring a team credit-race to support
+    <a href=http://boinc.fzk.de/poem>POEM@home</a>,
+    one of the CASP participants.
+    Results will be reported at
+    <a href=http://starmageddon.dyndns.org/pboinc/index.php>Planet BOINC</a>."
+),
+array("May 6, 2008",
+    "Alpha testing of BOINC software is done by volunteers.
+    Many thanks to <a href=http://isaac.ssl.berkeley.edu/alpha/top_testers.php>this month's top testers</a>."
+),
+array("May 5, 2008",
+    "Version 3.0 of <a href=http://www.conmunix.net/offene-projekte/boinc-lcs/>Boinc LCS</a> (a free PHP script for monitoring remote BOINC clients) has been released."
+),
+array("Apr 20, 2008",
+    "The BOINC user documentation has been moved from
+    <a href=trac/wiki/RunningBoinc>Trac</a>
+    to <a href=wiki/User_manual>Mediawiki</a>,
+    which provides better navigation and editing interfaces.
+    Please help us fix the remaining broken links."
+),
+array("Apr 7, 2008",
+    "Congratulations to <a href=http://boinc.netsoft-online.com/e107_plugins/boinc/get_user.php?cpid=0c6075252a929a1c9e1a887d1cd85ac5&html=1>NEZ</a>,
+    whose contribution to BOINC-based projects recently exceeded 10 TeraFLOPS.
+    This would (and should) rank 136th on the
+    <a href=http://www.top500.org/>Top 500 Supercomputer</a> list."
+),
+array("Mar 31, 2008",
+    "The BOINC client software is now available for Fedora 7 and higher
+    from official repositories.
+    To install it, just type <code>yum install boinc-client boinc-manager</code> as root.
+    Thanks to Milos Jakubicek, with help from Eric Myers and Debarshi Ray."
+),
+array("Mar 28, 2008",
+    "Read about a new BOINC-based project,
+    <a href=http://qcn.stanford.edu/>Quake Catcher Network</a>,
+    in
+    <a href=http://www.wired.com/science/planetearth/news/2008/03/quake_network>Wired</a> and
+    <a href=http://www.nature.com/news/2008/080326/full/452397a.html>Nature News</a>."
+),
+array("Mar 20, 2008",
+    "Watch an excellent talk by CERN's Francois Grey,
+    <a href=http://www.liftconference.com/distributed-computing-distributed-thinking>From distributed computing to distributed thinking</a>."
+),
+array("Mar 5, 2008",
+    "Read <a href=http://www.linuxinsider.com/story/Volunteer-Computing-and-the-Search-for-Big-Answers-61943.html>Volunteer Computing and the Search for Big Answers</a>, an article about BOINC and volunteer computing  on LinuxInsider.com."
+),
+array("Feb 27, 2008",
+    "Scientific progress goes BOINC!  Read about the
+    <a href=http://boinc.berkeley.edu/trac/wiki/ProjectPapers>Scientific
+    publications of BOINC-based projects</a>."
+),
+array("Feb 12, 2008",
+    "Where is BOINC headed?  Marcin Cieslak's vision:
+    <a href=http://boinc.berkeley.edu/cieslak.pdf>BOINC on JXTA</a>."
+),
+array("Feb 11, 2008",
+    "Bulgarian BOINC users:
+    find forums and information in your language at
+    <a href=http://www.boinc-bulgaria.net>BOINC Bulgaria</a>."
+),
+array("Feb 7, 2008",
+    "<a href=http://biology.polytechnique.fr/proteinsathome>Proteins@Home</a>
+    has resumed operations.
+    Check out their <a href=http://www3.interscience.wiley.com/cgi-bin/abstract/117860966/ABSTRACT?CRETRY=1&SRETRY=0>paper on computational protein design</a>
+    in the Journal of Computational Chemistry."
+),
+array("Jan 31, 2008",
+    "The <a href=http://bob.myisland.as/tsp/>TSP project</a>
+    is featured in International Science Grid This Week: <a href=http://www.isgtw.org/?pid=1000844>Traveling salesman meets distributed computing</a>."
+),
+array("Jan 31, 2008",
+    "BOINC has broken the PetaFLOP barrier!
+    According to <a href=http://boincstats.com/>BOINCStats</a>,
+    106 million units of credit were granted yesterday,
+    which translates to 1.06 PetaFLOP/sec.
+    Congratulations to all projects and participants."
+),
+array("Jan 24, 2008",
+    "A paper describing results of the <a href=http://qah.uni-muenster.de/>Quantum Monte Carlo at Home</a> project recently appeared in the
+    <a href=http://pubs.acs.org/cgi-bin/abstract.cgi/jpcafh/asap/abs/jp077592t.html>Journal of Physical Chemistry A (JPCA)</a>."
+),
+array("Jan 15, 2008",
+    "A new article from the <a href=http://www.planetary.org>Planetary Society</a>: 
+    <a href=http://www.planetary.org/programs/projects/setiathome/setiathome_20080115.html>From SETI@home to Hominid Fossils: Citizen Cyberscience Reshapes Research Landscape</a>."
+),
+
+array("Jan 14, 2008",
+    "The cross-project statistics site
+    <a href=http://www.allprojectstats.com/>All Project Stats.com</a>
+    has many improvements and new features,
+    include <a href=http://www.allprojectstats.com/signature.php>credit-based signature images</a> for users and teams."
+),
+array("Jan 10, 2008",
+    "A new competition for BOINC teams,
+    <a href=http://www.myboinc.com/FormulaBoinc/>Formula BOINC</a>,
+    is based on their position with projects (as in Formula 1 racing)
+    rather than overall credit.
+    This rewards teams that are diversified across many projects."
+),
+array("Dec 26, 2007",
+    "A story in the Chicago Tribune, \"<a href=http://www.chicagotribune.com/services/newspaper/printedition/tuesday/chi-computer_25dec25,0,2528641.story>Bit by bit, home computers aid science</a>\",
+    highlights <a href=http://www.cosmologyathome.org/>Cosmology@home</a>."
+),
+array("Dec 18, 2007",
+    "<a href=http://boinc.umiacs.umd.edu/>The Lattice Project</a>,
+    based at the University of Maryland
+    Center for Bioinformatics and Computational Biology,
+    is now open to volunteers.
+    Lattice runs several applications, and supplies computing power to
+    a number of Life Sciences researchers.
+    Current areas of study include
+    evolutionary relationships based on DNA sequence data;
+    bacterial, plasmid, and virus protein sequences;
+    and biological diversity in nature reserves. "
+),
+
+array("Dec 5, 2007",
+    "Watch a <a href=http://www.youtube.com/watch?v=GzATbET3g54>YouTube video</a> about the science behind <a href=http://boinc.bakerlab.org/rosetta/>Rosetta@home</a>."
+),
+array("Dec 5, 2007",
+    "The <a href=http://bob.myisland.as/tsp/>TSP</a>
+    (Traveling Salesman Problem) project is using BOINC to
+    find the shortest path between the capitals of the lower 48 states."
+),
+array("Dec 3, 2007",
+    "This web site, and the BOINC-Wide Teams site,
+    will be down for about 18 hours starting at 3 PM PST, Dec 6."
+),
+array("November 28, 2007",
+    "Live in Washington DC?  Get together with other BOINC users via
+    <a href=http://opensource.meetup.com/84/?gj=sj2>Meetup</a>
+    (or <a href=http://opensource.meetup.com/>create a Meetup
+     in your own city</a>)."
+),
+array("November 16, 2007",
+    "<a href=http://boinc.gorlaeus.net/>Leiden Classical</a> allows students (and the public)
+    to submit particle-system simulation jobs,
+    and is thus a resource for both education and research.
+    The job-submission system used by Leiden Classical is now
+    <a href=http://boinc.berkeley.edu/trac/wiki/UserJobs>included in the BOINC source code distribution</a>."
+),
+array("November 2, 2007",
+    "BOINC needs more volunteer programmers!
+    If you're proficient in PHP and MySQL, C++ and WxWidgets,
+    or C++ system programming,
+    please <a href=http://boinc.berkeley.edu/trac/wiki/DevProjects>read
+    about how you can help</a>."
+),
+array("October 22, 2007",
+    "The BOINC-based <a href=http://www.bbc.co.uk/sn/climateexperiment>BBC
+    Climate Change Experiment</a> has won the prestigious
+    <a href=http://www.prix-europa.de/>Prix Europa</a>
+    award in the Internet category."
+),
+array("October 21, 2007",
+    'Conmunix has released version 3.0 beta of
+    <a href=http://www.conmunix.net/boinc-lcs>Boinc LCS</a>
+    (Live Client State), a PHP script that allows you to monitor
+    the current state and other information from each of
+    your BOINC clients.'
+),
+array("October 18, 2007",
+    "BOINC user John Koulouris has written <a href=http://www.angelfire.com/jkoulouris-boinc/>The Big BOINC! Projects and Chronology Page</a>,
+    a brief history of BOINC."
+),
+array("October 17, 2007",
+    "Congratulations to the <a href=http://www.ukboincteam.org.uk/>UK BOINC Team</a>,
+    which today became the first UK-specific team to
+    pass the 100 million combined credits mark."
+),
+array("October 17, 2007",
+    "An article in Nature,
+    <a href=http://www.nature.com/news/2007/071016/full/449765a.html>The shape of protein structures to come</a>, discusses the goals and progress of the
+    <a href= http://boinc.bakerlab.org/rosetta/>Rosetta@home</a> project from the University of Washington."
+),
+array("October 12, 2007",
+    "LHC@home has moved from CERN to the University of London.
+    Read about it <a href=http://www.interactions.org/cms/?pid=1025457>here</a>."
+),
+array("October 4, 2007",
+    "The National Science Foundation has awarded a three-year grant,
+    NSF award #OCI-0721124, to the BOINC project.
+    This will support our development efforts through August 2010."
+),
+array("September 26, 2007",
+    "The Third Pan-Galactic BOINC Workshop took place 5-6 Sept. in Geneva.
+    The proceedings, including talk slides and notes from
+    the breakout sessions, are
+    <a href=http://boinc.berkeley/edu/trac/wiki/WorkShop07/Summary>here</a>."
+),
+array("September 25, 2007",
+    "Check out the <a href=http://boinc.iaik.tugraz.at/>SHA-1 Collision Search Graz</a>
+    project, which is based at the Graz University of Technology
+    and does research in cryptography."
+),
+array("September 24, 2007",
+    "Team founders: you can now make your team
+    <a href=teams/>BOINC-wide</a>,
+    meaning that it will be created on all
+    current and future BOINC projects."
+),
+array("September 24, 2007",
+    "A one-day session on BOINC will be presented at the
+    <a href=http://acgrid.in2p3.fr>Advanced Computing and GRID technologies for Research</a> school in Hanoi, November 5-16, 2007."
+),
+array("September 21, 2007",
+    "A <a href=http://boinc.berkeley.edu/boinc_papers/client_sch_eval/client_sch_eval.pdf>paper about scheduling in BOINC</a>
+    will appear in the 3rd IEEE International Conference on e-Science and Grid Computing. Banagalore, India, December 10-13 2007."
+),
+array("September 7, 2007",
+    "The new BOINC logo is now available in
+    <a href=logo.php>a variety of formats and resolutions.</a>"
+),
+array("August 17, 2007",
+    "World Community Grid has announced that it is
+    <a href=http://www.worldcommunitygrid.org/forums/wcg/viewthread?thread=15715 >migrating fully to BOINC</a>.
+    Welcome to all WCG participants!"
+),
+array("July 25, 2007",
+    "BOINC finally has a new logo!
+    Many thanks Michal Krakowiak, the graphic designer who created it.
+    The logo (and icons based on it)
+    will soon appear on the BOINC client software
+    as well as the web site."
+),
+array("July 23, 2007",
+    "<a href=images/africa_workshop_7_07.jpg><img align=right src=images/workshop_200.jpg></a>
+    The Africa@home workshop on volunteer computing with BOINC,
+    sponsored by the Geneva International Academic Network (GIAN),
+    was held recently at the African Institute for Mathematical Sciences in Muizenberg, South Africa.
+    <br clear=all>"
+),
+array("July 20, 2007",
+    "A newly-launched project, <a href=http://eternity2.net/>Eternity2.net</a>,
+    offers a chance to compute for a share of a US$2,000,000 prize."
+),
+array("July 20, 2007",
+    "Team leaders: check out the
+    <a href=http://www.boincteams.com/>BOINC Team Leaders Forum</a>,
+    a place to chat and discuss team-building on BOINC projects."
+),
+array("July 16, 2007",
+    "If you use the Yahoo! Widget Engine,
+    check out version 1.1 of the <a href=http://boinc.berkeley.edu/addon_item.php?platform=browser&item=BOINC_server_status.zip>BOINC Server Status</a> widget."
+),
+array("July 16, 2007",
+    "BOINC is now the preferred client software at
+    <a href=http://worldcommunitygrid.org>World Community Grid</a>."
+),
+array("July 12, 2007",
+    "<a href=http://boinc.gorlaeus.net/>Leiden Classical</a>
+    is using BOINC for education - it provides a
+    <a href=http://boinc.gorlaeus.net/ClassicalBuilder.php>
+    high-performance computing resource</a> for
+    students of Theoretical Chemistry at Leiden University."
+),
+array("July 10, 2007",
+    "<a href=http://boinc.berkeley.edu/images/gw.jpg border=0><img align=right src=http://boinc.berkeley.edu/images/gw_small.jpg></a>
+    A growing number of 'skins' for the BOINC simple GUI are available
+    from <a href=http://crunching-family.at/dlc/>crunching-family.at</a>.
+    Here's an example.
+    "
+),
+array("July 6, 2007",
+     "Welcome to a new web site with cross-project BOINC statistics:
+     <a href=http://statsnstones.tswb.org/>Team Starfire World BOINC Stats 'N Stones</a>."
+),
+array("July 5, 2007",
+    "Windows users:
+    <a href=http://www.nuchill.de/nboinc/>version 2.0 of nBOiNC</a>,
+    an add-on application for viewing your up-to-the-minute credit totals,
+    has been released."
+),
+array("July 4, 2007",
+    "Docking@home is moving from Texas to Delaware. Volunteers should detach from the project; you will be emailed when the project is alive in Delaware."
+),
+array("July 2, 2007",
+    "Read <a href=http://www.isgtw.org/?pid=1000527>Volunteer computing: Grid or not Grid?</a> on International Science Grid This Week."
+),
+array("July 2, 2007",
+    "Amir Alexander of The Planetary Society talks about
+    <a href=http://www.boincuk.com/amir_alexander.mp3>SETI, distributed computing, and space exploration</a> in an interview by Mike of BOINC UK."
+),
+array("June 28, 2007",
+    "Linux users: if you use bash,
+    check out a cool <a href=http://boinc.berkeley.edu/trac/wiki/BashCommandCompletion>script</a>
+    that provides command completion in both boinc_cmd and boinc_client
+    (thanks to Frank S. Thomas)."
+),
+array("June 27, 2007",
+    "Help increase volunteer computing power -
+    <a href=http://boinc.berkeley.edu/trac/wiki/BoincPr>publicize BOINC</a> by writing to computer magazines."
+),
+array("June 26, 2007",
+    "There's a great new statistics site,
+    <a href=http://www.allprojectstats.com/>BOINC All Project Stats</a>.
+    It has lists of the top users and teams,
+    recent changes in rankings, graphs showing history and
+    breakdown by project, and many other features.
+    You can also see the stats and rankings
+    of an individual volunteer or team across all BOINC projects.
+    Thanks to Markus Tervooren for putting this together!"
+),
+array("June 26, 2007",
+    "There are reports that version 5.10.8 of the BOINC client software
+    causes a problem on Windows XP Pro in which the desktop becomes empty.
+    If you see this, please uninstall 5.10.8 and install version 5.8.16."
+),
 array("June 3, 2007",
     "BOINCstats and BAM! are now viewable in Finnish
     (<a href=http://fi.boincstats.com>http://fi.boincstats.com</a>). "
@@ -219,10 +536,10 @@ array("December 8, 2006",
     Olaf Bornack of
     <a href=http://www.boinc-halle-saale.de/>Team BOINC@Halle/Saale</a>
     has supplied
-    <a href=http://boinc.berkeley.edu/manager_skin.php#stencils>stencils</a>
+    <a href=http://boinc.berkeley.edu/http://boinc.berkeley.edu/trac/wiki/ManagerSkin#stencils>stencils</a>
     for creating skins for the new BOINC GUI.
     These have been used to make skins with
-    <a href=http://boinc.berkeley.edu/skins.php>BOINCcast,
+    <a href=http://boinc.berkeley.edu/http://boinc.berkeley.edu/trac/wiki/SkinExamples>BOINCcast,
     BOINC@Halle/Saale, and BOINCmas!</a> themes.
     <br clear=all>
     "
@@ -281,10 +598,10 @@ array("November 7, 2006",
     than the current BOINC manager.
     Projects can supply their own graphics
     (icons, application-specific slideshows) for use in this GUI;
-    see <a href=http://boinc.berkeley.edu/project_skin.php>instructions for how to do this</a>.
+    see <a href=http://boinc.berkeley.edu/ProjectSkin>instructions for how to do this</a>.
     In addition, the GUI itself is skinnable;
     a skin consists of
-    <a href=http://boinc.berkeley.edu/manager_skin.php>an XML
+    <a href=http://boinc.berkeley.edu/trac/wiki/ManagerSkin>an XML
     file and a collection of images</a>."
 ),
 array("October 17, 2006",
@@ -294,7 +611,7 @@ array("October 17, 2006",
 array("October 9, 2006",
     "Interested in getting a one-CPU-month job finished in five minutes?
     BOINC can potentially help you do this, but
-    <a href=low_latency.php>some work is needed</a>."
+    <a href=http://boinc.berkeley.edu/trac/wiki/LowLatency>some work is needed</a>."
 ),
 array("October 8, 2006",
     "Versions of BOINC (and some applications) are now
@@ -344,7 +661,7 @@ array("August 16, 2006",
     "New documents discuss using BOINC for
     <a href=dg.php>Desktop Grid Computing</a>
     and for creating
-    <a href=vcsc.php>Virtual Campus Supercomputing Centers</a>."
+    <a href=http://boinc.berkeley.edu/trac/wiki/VirtualCampusSupercomputerCenter>Virtual Campus Supercomputing Centers</a>."
 ),
 array("August 15, 2006",
     "A BBC Radio program on 'Citizen Science' - including
@@ -406,7 +723,7 @@ array("July 21, 2006",
     "The BOINC survey is now available in
     <a href=http://boinc.oocp.org/poll.php>Japanese</a>.
     If you'd like to translate it to another language,
-    please <a href=contact.php>contact us</a>."
+    please <a href=trac/wiki/ProjectPeople>contact us</a>."
 ),
 array("July 13, 2006",
     "We are conducting an <a href=poll.php>online survey</a>
@@ -447,7 +764,7 @@ array("June 29, 2006",
     will appear in the <a href=http://sc06.supercomp.org>SC06 conference</a>."
 ),
 array("June 28, 2006",
-    "A new <a href=sandbox_user.php>Secure BOINC Client</a>
+    "A new <a href=http://boinc.berkeley.edu/trac/wiki/SandboxUser>Secure BOINC Client</a>
     for the Macintosh is available for testing.
     This version limits BOINC applications' access to your system and data,
     thus protecting your computer from accidental or malicious damage
@@ -523,7 +840,7 @@ array("May 17, 2006",
 ),
 array("May 11, 2006",
     "Version 5.4 of the BOINC client software has been released.
-    This version lets you use <a href=acct_mgt.php>account managers</a> -
+    This version lets you use <a href=trac/wiki/AccountManagers>account managers</a> -
     special web sites that let you browse BOINC projects,
     attach/detach, change resource share and settings,
     all with point-and-click simplicity.
@@ -817,7 +1134,7 @@ array("June 24, 2005",
     will cause a deadline to be missed, it suspends work fetch."
 ),
 array("June 24, 2005",
-    "<a href=acct_mgt.php>Account management system</a>
+    "<a href=trac/wiki/AccountManagers>Account management system</a>
     are web sites that let participants sign up for
     multiple projects with just a few clicks (and no account keys).
     The BOINC manager (development version) now lets you
@@ -838,7 +1155,7 @@ array("June 16, 2005",
 ),
 array("June 3, 2005",
     "Two Wiki-based BOINC informational sites have been launched recently:
-    <a href=http://boinc-doc.net/boinc-wiki/>The Unofficial BOINC Wiki</a>
+    <a href=http://www.boinc-wiki.info/>The Unofficial BOINC Wiki</a>
     (in English) and
     <a href=http://faq.boinc.de/>Deutsche BOINC FAQ</a> (in German).
     Because these sites are Wikis,
@@ -886,7 +1203,7 @@ array("May 10, 2005",
 ),
 array("April 11, 2005",
     "Volunteers have ported SETI@home and BOINC to
-    <a href=http://boinc.berkeley.edu/download_other.php>a variety of platforms</a>,
+    <a href=http://boinc.berkeley.edu/trac/wiki/DownloadOther>a variety of platforms</a>,
     including Solaris/x86-64, Linux/x86-64, Linux/PPC, HP-UX, and FreeBSD."
 ),
 
@@ -911,10 +1228,10 @@ array(
 ),
 array(
     "February 17, 2005",
-    "We've added a <a href=web_translation.php>framework for web-site translations</a>
+    "We've added a <a href=trac/wiki/TranslateIntro>framework for web-site translations</a>
     (both BOINC-supplied and project-specific parts).
     We are adding support for
-    <a href=acct_mgt.php>account management systems</a>
+    <a href=trac/wiki/AccountManagers>account management systems</a>
     that simplify participation in multiple projects.
     Security enhancement: all application files are digitally signed.
     "
@@ -928,7 +1245,7 @@ array(
     "January 19, 2005",
     "BOINC-based projects projects now have
     80,721 participants in 188 countries.
-    Based on <a href=flops.php>current credit statistics</a>,
+    Based on <a href=http://boinc.berkeley.edu/trac/wiki/CreditSystem>current credit statistics</a>,
     together they supply 106 TeraFLOPS of computing power -
     far more than any conventional supercomputer."
 ),
@@ -1197,7 +1514,7 @@ to run a distributed version of CHARMM
 
 array("February 1, 2004",
 "BOINC now has an
-<a href=anonymous_platform.php>anonymous platform mechanism</a>
+<a href=http://boinc.berkeley/edu/trac/wiki/AnonymousPlatform>anonymous platform mechanism</a>
 which 1) allows computers of any type to participate
 in a BOINC project, and 2) allows participants to
 run only software they have compiled themselves,
