@@ -27,38 +27,42 @@ and help for BOINC is available <a href=help.php>here</a>.
 ";
 list_start();
 list_item(
-    "<a href=http://ssl.berkeley.edu/mailman/listinfo/boinc_announce>boinc_announce</a>",
+    "<a href=http://lists.ssl.berkeley.edu/mailman/listinfo/boinc_announce>boinc_announce</a>",
     "Announcements of new versions of BOINC client software."
 );
 list_item(
-    "<a href=http://ssl.berkeley.edu/mailman/listinfo/boinc_projects>boinc_projects</a>",
-    "An email list for people developing and operating BOINC projects.
-    Questions and problems involving BOINC server software.
+    "<a href=http://lists.ssl.berkeley.edu/mailman/listinfo/boinc_projects>boinc_projects</a>",
+    "For people developing and operating BOINC projects.
+    Questions and problems involving BOINC API and server software.
     Announcements of upgrades and changes.
 ");
-list_item("<a href=http://ssl.berkeley.edu/mailman/listinfo/boinc_dev>boinc_dev</a>",
+list_item("<a href=http://lists.ssl.berkeley.edu/mailman/listinfo/boinc_dev>boinc_dev</a>",
     "For people developing, debugging or porting the BOINC software
     (client, server, and Web).
+    Do NOT post questions about how to use the software.
 ");
-list_item("<a href=http://ssl.berkeley.edu/mailman/listinfo/boinc_loc>boinc_loc</a>",
+list_item("<a href=http://lists.ssl.berkeley.edu/mailman/listinfo/boinc_loc>boinc_loc</a>",
     "For people doing non-English translations
     of the BOINC GUI or web interfaces.
 ");
 list_item(
-    "<a href=http://www.ssl.berkeley.edu/mailman/listinfo/boinc_stats>boinc_stats</a>",
+    "<a href=http://lists.ssl.berkeley.edu/mailman/listinfo/boinc_stats>boinc_stats</a>",
     "For people developing web sites showing statistics for BOINC projects."
 );
-list_item("<a href=http://ssl.berkeley.edu/mailman/listinfo/boinc_cvs>boinc_cvs</a>",
+list_item("<a href=http://lists.ssl.berkeley.edu/mailman/listinfo/boinc_cvs>boinc_cvs</a>",
     "Summaries of BOINC CVS checkins are posted to this list.
     No other posts, please."
 );
-list_item("<a href=http://www.ssl.berkeley.edu/mailman/listinfo/boinc_opt>boinc_opt</a>",
+list_item("<a href=http://lists.ssl.berkeley.edu/mailman/listinfo/boinc_opt>boinc_opt</a>",
     "For people porting and optimizing BOINC applications."
 );
-list_item("<a href=http://www.ssl.berkeley.edu/mailman/listinfo/boinc_helpers>boinc_helpers</a>",
+list_item("<a href=http://lists.ssl.berkeley.edu/mailman/listinfo/boinc_helpers>boinc_helpers</a>",
     "For BOINC <a href=help.php>Help Volunteers</a>,
     to discuss policies and user problems."
 );
+list_item("<a href=http://groups.google.com/group/boinc-team-founders>BOINC team founders</a> (Google group)",
+    "Discussion of team-related issues."
+);
 list_end();
 
 echo "
