@@ -9,7 +9,7 @@ require_once("../inc/util.inc");
 require_once("../inc/ops.inc");
 
 cli_only();
-db_init_cli();
+db_init();
 
 set_time_limit(0);
 
@@ -426,11 +426,170 @@ function update_6_5_2007() {
     do_query("ALTER TABLE `forum_preferences` ADD `pm_notification` TINYINT( 1 ) UNSIGNED NOT NULL DEFAULT '1';");
 }
 
+function update_7_26_2007() {
+    do_query("create table team_delta (
+    userid              integer                 not null,
+    teamid              integer                 not null,
+    timestamp           integer                 not null,
+    joining             tinyint(1)              not null,
+    total_credit        double                  not null
+) TYPE=MyISAM;"
+    );
+    do_query("alter table team_delta
+        add index team_delta_teamid (teamid, timestamp);"
+    );
+}
+
+function update_9_26_2007() {
+    // Change field type from unsigned to signed
+    do_query("ALTER TABLE team CHANGE ping_user ping_user integer NOT NULL DEFAULT 0");
+}
+
+function update_9_28_2007() {
+    do_query("alter table team engine=myisam");
+    do_query("alter table team change description description text");
+    do_query("alter table team add fulltext index team_name_desc(name, description)");
+}
+
+function update_10_25_2007() {
+    do_query("update user set country='Serbia' where country='Serbia and Montenegro'");
+    do_query("update team set country='Serbia' where country='Serbia and Montenegro'");
+}
+
+function update_10_26_2007() {
+    do_query("create table banishment_vote (
+        id                  serial                  primary key,
+        userid              integer                 not null,
+        modid               integer                 not null,
+        start_time          integer                 not null,
+        end_time            integer                 not null
+        ) TYPE=MyISAM;"
+    );
+    do_query("create table banishment_votes (
+        id                  serial                  primary key,
+        voteid              integer                 not null,
+        modid               integer                 not null,
+        time                integer                 not null,
+        yes                 tinyint(1)              not null
+        ) TYPE=MyISAM;"
+    );
+}
+
+function update_11_7_2007() {
+    do_query("create table team_admin (
+        teamid              integer                 not null,
+        userid              integer                 not null,
+        create_time         integer                 not null,
+        rights              integer                 not null
+        ) type=MyISAM;"
+    );
+    do_query("alter table team_admin add unique (teamid, userid);");
+}
+
+function update_11_8_2007() {
+    do_query("alter table forum add parent_type integer not null");
+}
+
+function update_11_14_2007() {
+    do_query("alter table forum drop index category");
+    do_query("alter table forum add unique pct (parent_type, category, title)");
+}
+
+// pm_notification should be 0 by default.
+// We don't know who really wants it to be 1, so set everyone to 0;
+// projects might want to run a news item notifying user
+// that they need to explicitly set this if they want PM notification
+//
+function update_11_18_2007() {
+    do_query("update forum_preferences set pm_notification=0");
+    do_query("alter table forum_preferences change pm_notification pm_notification tinyint not null default 0");
+}
+
+function update_11_20_2007() {
+    do_query("alter table team add fulltext index team_name(name)");
+}
+
+function update_12_18_2007() {
+    do_query("create table friend (
+        user_src            integer         not null,
+        user_dest           integer         not null,
+        message             varchar(255)    not null,
+        create_time         integer         not null,
+        reciprocated        tinyint         not null
+        )
+    ");
+    do_query("create table notify (
+        id                  serial          primary key,
+        userid              integer         not null,
+        create_time         integer         not null,
+        type                integer         not null,
+        opaque              integer         not null
+        )
+    ");
+    do_query("alter table friend
+        add unique friend_u (user_src, user_dest)
+    ");
+    do_query("alter table notify
+        add index notify_u (userid)
+    ");
+}
+
+function update_12_28_2007() {
+    do_query("alter table notify drop index notify_u");
+    do_query("alter table notify
+        add unique notify_un (userid, type, opaque)
+    ");
+}
+
+function update_2_18_2008() {
+    do_query("create table assignment (
+        id                  integer     not null auto_increment,
+        create_time         integer     not null,
+        target_id           integer     not null,
+        target_type         integer     not null,
+        multi               tinyint     not null,
+        workunitid          integer     not null,
+        resultid            integer     not null,
+        primary key (id)
+        ) engine = InnoDB
+    ");
+}
+
+// If you haven't done 3_7, skip both of the following:
+//
+function update_3_7_2008() {
+    do_query("alter table workunit add column rsc_bandwidth_bound double not null after rsc_disk_bound");
+}
+function update_3_7_undo_2008() {
+    do_query("alter table workunit drop column rsc_bandwidth_bound");
+}
+
+function update_3_10_2008() {
+    do_query("alter table workunit add column rsc_bandwidth_bound double not null");
+}
+
+function update_3_13_2008() {
+    do_query("alter table app_version drop index appid");
+    do_query("alter table app_version add column plan_class varchar(254) not null default ''");
+    do_query("alter table app_version add unique apvp (appid, platformid, version_num, plan_class)");
+}
+
+// The following cleans up from a bug that causes "team transfer pending"
+// to be shown even after transfer is finished
+//
+function update_3_27_2008() {
+    do_query("update team set ping_user=0, ping_time=0 where ping_user=userid");
+}
+
+function update_3_31_2008() {
+    do_query("alter table app_version change column xml_doc xml_doc mediumblob");
+}
+
 // modify the following to call the function you want.
 // Make sure you do all needed functions, in order.
 // (Look at your DB structure using "explain" queries to see
 // which ones you need).
 
-//update_6_5_2007();
+//update_3_13_2008();
 
 ?>
