@@ -1,7 +1,7 @@
 #!/usr/bin/env php
 <?php
 
-require_once("../inc/forum.inc");
+require_once("../inc/forum_db.inc");
 
 define('MAX_REWARD', 4096);
 define('SCALAR', 0.9);
@@ -9,37 +9,30 @@ set_time_limit(0);
 
 echo date(DATE_RFC822), ": Starting\n";
 
-db_init();
-
 $now = time();
-$result = mysql_query("select * FROM thread");
-
-while ($thread = mysql_fetch_object($result)) {
-    $forum = getForum($thread->forum);
-    $category = getCategory($forum->category);
+$threads = BoincThread::enum();
+foreach ($threads as $thread) {
+    $forum = BoincForum::lookup_id($thread->forum);
+    $category = BoincCategory::lookup_id($forum->category);
     if ($category->is_helpdesk) {
         $diff = ($now - $thread->create_time)/86400;
         $activity = ($thread->sufferers+1)/$diff;
         echo "help $diff $activity\n";
     } else {
-        $sql = "select * from post where thread=$thread->id";
-        $result2 = mysql_query($sql);
+        $posts = BoincPost::enum("thread=$thread->id");
         $activity = 0;
     
-        while ($post = mysql_fetch_object($result2)) {
+        foreach ($posts as $post) {
             $diff = $now - $post->timestamp;
             $diff /= 7*86400;
             $activity += pow(2, -$diff);
         }
         echo "forum $activity\n";
     }
-    
-    $sql = "update thread set activity=$activity where id=$thread->id";
-    mysql_query($sql);
+    $thread->update("activity=$activity");
     
 }
 
 echo date(DATE_RFC822), ": Finished\n";
 
-
 ?>
