@@ -1,4 +1,4 @@
-#! /usr/local/bin/php
+#! /usr/bin/env php
 <?php
 
 // General-purpose watchdog script.
@@ -15,8 +15,7 @@
 
 function sound_alarm($x) {
     //echo "alarm: $x\n";
-    mail("davea@ssl.berkeley.edu", "BOINC problem", $x);
-    mail("eheien@ssl.berkeley.edu", "BOINC problem", $x);
+    mail(SYS_ADMIN_EMAIL, "BOINC problem", $x);
 }
 
 function check_log_file($file, $last_time) {
