@@ -1,19 +1,10 @@
 <?php
 
-require_once("../inc/db.inc");
+require_once("../inc/boinc_db.inc");
 require_once("../inc/util.inc");
 require_once("../inc/translation.inc");
 
-init_session();
-db_init();
-
-$platforms = array();
-$r2 = mysql_query("select * from platform");
-while ($platform = mysql_fetch_object($r2)) {
-    if ($platform->deprecated) continue;
-    array_push($platforms, $platform);
-}
-mysql_free_result($r2);
+$platforms = BoincPlatform::enum("deprecated=0");
 
 $xml = $_GET['xml'];
 if ($xml) {
@@ -21,30 +12,29 @@ if ($xml) {
     xml_header();
     echo "<app_versions>\n";
 } else {
-    page_head(tr(APPS_TITLE));
-    echo tr(APPS_DESCRIPTION)."<br><br>
+    page_head(tra("Applications"));
+    echo tra("%1 currently has the following applications. When you participate in %1, work for one or more of these applications will be assigned to your computer. The current version of the application will be downloaded to your computer. This happens automatically; you don't have to do anything.", PROJECT)."<br><br>
     ";
     start_table();
 }
-$result = mysql_query("select * from app where deprecated=0");
 
+$apps = BoincApp::enum("deprecated=0");
 
-while ($app = mysql_fetch_object($result)) {
+foreach ($apps as $app) {
     if ($xml) {
         echo "<application>\n";
         echo "    <name>$app->user_friendly_name</name>\n";
     } else {
         echo "
             <tr><th colspan=3>$app->user_friendly_name</th></tr>
-            <tr><th>".tr(APPS_PLATFORM)."</th><th>".tr(APPS_VERSION)."</th><th>".tr(APPS_INSTALLTIME)."</th></tr>\n
+            <tr><th>".tra("Platform")."</th><th>".tra("Current version")."</th><th>".tra("Installation time")."</th></tr>\n
         ";
     }
     for ($i=0; $i<sizeof($platforms); $i++) {
         $platform = $platforms[$i];
         $newest = null;
-        $r2 = mysql_query("select * from app_version where appid=$app->id and platformid = $platform->id");
-        while ($av = mysql_fetch_object($r2)) {
-            if ($av->deprecated) continue;
+        $avs = BoincAppVersion::enum("appid=$app->id and platformid = $platform->id and deprecated=0");
+        foreach($avs as $av) {
             if (!$newest || $av->version_num>$newest->version_num) {
                 $newest = $av;
             }
@@ -74,7 +64,7 @@ while ($app = mysql_fetch_object($result)) {
         echo "    </application>\n";
     }
 }
-mysql_free_result($result);
+
 if ($xml) {
     echo "</app_versions>\n";
 } else {
