@@ -1,13 +1,14 @@
 <?php
 
-include_once("../inc/db.inc");
+include_once("../inc/boinc_db.inc");
 include_once("../inc/util.inc");
 include_once("../inc/email.inc");
+include_once("../inc/user.inc");
 
 function show_error($str) {
     page_head("Can't create account");
     echo "$str<br>\n";
-    echo mysql_error();
+    echo BoincDb::error();
     echo "<p>Click your browser's <b>Back</b> button to try again.\n<p>\n";
     page_tail();
     exit();
@@ -24,9 +25,9 @@ if (parse_bool($config, "disable_account_creation")) {
     exit();
 }
 
-db_init();
-init_session();
-
+// see whether the new account should be pre-enrolled in a team,
+// and initialized with its founder's project prefs
+//
 $teamid = post_int("teamid", true);
 if ($teamid) {
     $team = lookup_team($teamid);
@@ -42,16 +43,16 @@ if ($teamid) {
 }
 
 if(defined('INVITE_CODES')) {
-    $invite_code = process_user_text($_POST["invite_code"]);
+    $invite_code = process_user_text(post_str("invite_code"));
     if (strlen($invite_code)==0) {
-        show_error( tr(AC_INVITE_REQUIRED) );
+        show_error(tra("You must supply an invitation code to create an account."));
     }
     if (!preg_match(INVITE_CODES, $invite_code)) {
-        show_error( tr(AC_INVITE_INVALID) );
+        show_error(tra("The invitation code you gave is not valid."));
     }
 } 
 
-$new_name = process_user_text($_POST["new_name"]);
+$new_name = process_user_text(post_str("new_name"));
 if (strlen($new_name)==0) {
     show_error("You must supply a name for your account");
 }
@@ -59,8 +60,7 @@ if ($new_name != strip_tags($new_name)) {
     show_error("HTML tags not allowed in name");
 }
 
-
-$new_email_addr = process_user_text($_POST["new_email_addr"]);
+$new_email_addr = process_user_text(post_str("new_email_addr"));
 $new_email_addr = strtolower($new_email_addr);
 if (!is_valid_email_addr($new_email_addr)) {
     show_error("Invalid email address:
@@ -95,39 +95,42 @@ if (strlen($passwd)<$min_passwd_length) {
 
 $passwd_hash = md5($passwd.$new_email_addr);
 
-$country = $_POST["country"];
+$country = post_str("country");
+if ($country == "") {
+    $country = "International";
+}
 if (!is_valid_country($country)) {
     echo "bad country";
     exit();
 }
 
-$postal_code = strip_tags(process_user_text($_POST["postal_code"]));
+$postal_code = post_str("postal_code", true);
 
-$authenticator = random_string();
-$cross_project_id = random_string();
-$country = boinc_real_escape_string($country);
-$now = time();
-$query = "insert into user (create_time, email_addr, name, authenticator, country, postal_code, total_credit, expavg_credit, expavg_time, project_prefs, teamid, venue, url, send_email, show_hosts, cross_project_id, passwd_hash) values($now, '$new_email_addr', '$new_name', '$authenticator', '$country', '$postal_code', 0, 0, unix_timestamp(), '$project_prefs', $teamid, 'home', '', 1, 1, '$cross_project_id', '$passwd_hash')";
-$result = mysql_query($query);
-if (!$result) {
+$user = make_user(
+    $new_email_addr, $new_name, $passwd_hash,
+    $country, $postal_code, $project_prefs, $teamid
+);
+if (!$user) {
     show_error("Couldn't create account");
 }
 
 // In success case, redirect to a fixed page so that user can
 // return to it without getting "Repost form data" stuff
 
-$user->name = $new_name;
-$user->email_addr = $new_email_addr;
-$user->authenticator = $authenticator;
 send_auth_email($user, true, false);
 
 if(defined('INVITE_CODES')) {
-    error_log("New account '$new_name' created using invitation code '$invite_code'");
+    error_log("Account '$new_email_addr' created using invitation code '$invite_code'");
 }
 
-session_start();
-$_SESSION["authenticator"] = $authenticator;
-Header("Location: home.php?new_acct=1&via_web=1");
-setcookie('auth', $authenticator, time()+3600*24*365);
+$next_url = post_str('next_url', true);
+if ($next_url) {
+    Header("Location: $next_url");
+} else {
+    Header("Location: home.php");
+    send_cookie('init', "1", true);
+    send_cookie('via_web', "1", true);
+}
+send_cookie('auth', $user->authenticator, true);
 
 ?>
