@@ -2,10 +2,10 @@
 
 require_once("../inc/db.inc");
 require_once("../inc/util.inc");
-require_once("../inc/download_network.inc");
+require_once("../inc/cache.inc");
 
-init_session();
 
+start_cache(3600);
 page_head("Download BOINC add-on software");
 echo "
     <p>
@@ -22,16 +22,21 @@ echo "
     Instructions for installing and running BOINC are
     <a href=http://boinc.berkeley.edu/participate.php>here</a>.
     <li>
-    The <a href='http://www.boinc.dk/index.php?page=mirror_file_list'>BOINC Download Network</a>
-    is designed and maintained by <a href='http://www.boinc.dk'>BOINC.dk</a> as a service for the BOINC community.
-    Visit the BOINC Download Network site to add
-    an entry to this list.
-
+    This list is managed centrally at <a href='http://boinc.berkeley.edu/addons.php'>the BOINC website</a>.
     </ul>
 ";
-BOINC_download_network_print_download_links();
+
+$httpFile = @fopen("http://boinc.berkeley.edu/addons.php?strip_header=true", "rb");
+if (!$httpFile){
+    echo "";
+} else {
+    fpassthru($httpFile);
+    fclose($httpFile);
+}
+
 echo "
     <p><p>
 ";
 page_tail();
+end_cache(3600);
 ?>
