@@ -4,8 +4,6 @@ require_once('../inc/util.inc');
 require_once('../inc/time.inc');
 require_once('../inc/forum.inc');
 require_once('../inc/user.inc');
-require_once('../inc/db.inc');
-db_init();
 
 $userid = get_int("userid");
 $offset = get_int("offset", true);
@@ -17,33 +15,31 @@ $user = lookup_user_id($userid);
 $logged_in_user = get_logged_in_user(false);
 
 if( $logged_in_user = get_logged_in_user(false) ) {
-    $logged_in_user = getForumPreferences($logged_in_user);
-    if ($user->id==$logged_in_user->id ||  isSpecialUser($logged_in_user,0)) {
+    BoincForumPrefs::lookup($logged_in_user);
+    if ($user->id==$logged_in_user->id ||  $logged_in_user->prefs->privilege(0)) {
         $hide = false;
     }
 }
 page_head("Posts by $user->name");
 
 if($hide) {
-    $result = mysql_query("select * from post
-        where user=$userid
-        and   hidden=0
-        order by id desc limit $offset,$count"
-    );
+    $posts = BoincPost::enum("user=$userid and hidden=0 order by id desc limit $offset,$count");
 } else {
-    $result = mysql_query("select * from post
-        where user=$userid
-        order by id desc limit $offset,$count"
-    );
+    $posts = BoincPost::enum("user=$userid order by id desc limit $offset,$count");
 }
 $n = 0;
 start_table();
-while ($post = mysql_fetch_object($result)) {
-    show_post2($post, $n+$offset+1);
+$options = get_output_options($logged_in_user);
+
+foreach ($posts as $post) {
+    $thread = BoincThread::lookup_id($post->thread);
+    if (!$thread) continue;
+    $forum = BoincForum::lookup_id($thread->forum);
+    if (!$forum) continue;
+    show_post_and_context($post, $thread, $forum, $options, $n+$offset+1);
     $n++;
 }
 echo "</table>\n";
-mysql_free_result($result);
 
 if ($n == $count) {
     $offset += $count;
