@@ -3,15 +3,16 @@
 include_once("../inc/db.inc");
 include_once("../inc/util.inc");
 
-if (isset($_COOKIE['auth'])) {
-    check_tokens($_COOKIE['auth']);
-    session_start();
-    session_destroy();
-    setcookie('auth', "", time());
+$user = get_logged_in_user();
+
+if ($user) {
+    check_tokens($user->authenticator);
+    clear_cookie('auth');
     page_head("Logged out");
     echo "You are now logged out";
     page_tail();
 } else {
     error_page("not logged in");
 }
+
 ?>
