@@ -2,7 +2,7 @@
 
 // RPC handler for account lookup
 
-require_once("../inc/db.inc");
+require_once("../inc/boinc_db.inc");
 require_once("../inc/util.inc");
 require_once("../inc/email.inc");
 require_once("../inc/xml.inc");
@@ -14,7 +14,8 @@ if ($retval) xml_error($retval);
 $email_addr = get_str("email_addr");
 $passwd_hash = process_user_text(get_str("passwd_hash", true));
 
-$user = lookup_user_email_addr($email_addr);
+$email_addr = BoincDb::escape_string($email_addr);
+$user = BoincUser::lookup("email_addr='$email_addr'");
 if (!$user) {
     xml_error(-136);
 }
@@ -33,7 +34,7 @@ $auth_hash = md5($user->authenticator.$user->email_addr);
 //
 if (!strlen($user->passwd_hash)) {
     $user->passwd_hash = $auth_hash;
-    mysql_query("update user set passwd_hash='$user->passwd_hash' where id=$user->id");
+    $user->update("passwd_hash='$user->passwd_hash'");
 }
 
 // if the given password hash matches (auth+email), accept it
