@@ -4,10 +4,7 @@ include_once("../inc/db.inc");
 include_once("../inc/util.inc");
 include_once("../inc/team.inc");
 
-init_session();
-db_init();
-
-    page_head("Teams");
+page_head("Teams");
 
 echo "<p>".PROJECT." participants may form <b>teams</b>.
     <p>
@@ -22,17 +19,13 @@ echo "<p>".PROJECT." participants may form <b>teams</b>.
     <li> disband a team if it has no members
     </ul>
     <p>
-    To join a team, visit its team page and click Join.
-    <hr>
-    <ul>
-    <li> <form method=get action=team_lookup.php>
-    Search for teams whose name contains:
-    <input name=team_name>
-    <input type=submit name=search value=Search>
-    </form>
-    <li> <a href=team_create_form.php>Create a team</a>
-    </ul>
-    Show top teams:
+    To join a team, visit its team page and click <b>Join this team</b>.
+    <h3>Find a team</h3>
+";
+team_search_form(null);
+echo "
+
+    <h3>Top teams</h3>
     <ul>
     <li> <a href=top_teams.php>All teams</a>
 ";
@@ -44,7 +37,10 @@ for ($i=1; $i<8; $i++) {
 
 echo "
     </ul>
+    <h3>Create a new team</h3>
+    If you can't find a team that's right for you, you can
+    <a href=team_create_form.php>create a team</a>.
 ";
-    page_tail();
+page_tail();
 
 ?>
