@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _APP_IPC_
 #define _APP_IPC_
@@ -70,7 +70,6 @@ struct SHARED_MEM {
         // <resume/>
     MSG_CHANNEL process_control_reply;
         // app->core
-        // same as above
     MSG_CHANNEL graphics_request;
         // core->app
         // request a graphics mode:
@@ -82,9 +81,9 @@ struct SHARED_MEM {
         // same as above
     MSG_CHANNEL heartbeat;
         // core->app
-        // <heartbeat/>             sent every second, even while app is suspended
-        // <disable_heartbeat/>     disables heartbeat mechanism
-        // <enable_heartbeat/>      enable heartbeat mechanism (default)
+        // <heartbeat/>         sent every second, even while app is suspended
+        // <wss>                app's current working set size
+        // <max_wss>            max working set size
     MSG_CHANNEL app_status;
         // app->core
         // status message every second, of the form
@@ -92,7 +91,6 @@ struct SHARED_MEM {
         // <checkpoint_cpu_time>...
         // <working_set_size>...
         // <fraction_done> ...
-        // <non_cpu_intensive>x</non_cpu_intensive>
     MSG_CHANNEL trickle_up;
         // app->core
         // <have_new_trickle_up/>
@@ -115,7 +113,6 @@ struct MSG_QUEUE {
 	bool timeout(double);
 };
 
-#define DEFAULT_FRACTION_DONE_UPDATE_PERIOD     1
 #define DEFAULT_CHECKPOINT_PERIOD               300
 
 #define SHM_PREFIX          "shm_"
@@ -181,20 +178,19 @@ struct APP_INIT_DATA {
     double rsc_fpops_bound;
     double rsc_memory_bound;
     double rsc_disk_bound;
+    double computation_deadline;
 
     // the following are used for compound apps,
-    // where each stage of the computation is a fixed
-    // fraction of the total.
+    // where each stage of the computation is a fixed fraction of the total.
     double fraction_done_start;
     double fraction_done_end;
 
-    // Items below here are for implementation only
-    // (not used by app developers)
+    // Items below here are for BOINC runtime system,
+    // and should not be directly accessed by apps
     //
     double checkpoint_period;     // recommended checkpoint period
     SHMEM_SEG_NAME shmem_seg_name;
     double wu_cpu_time;       // cpu time from previous episodes
-    double fraction_done_update_period;
 
     APP_INIT_DATA();
     APP_INIT_DATA(const APP_INIT_DATA&);  // copy constructor
