@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 // boinc_win.h : include file for standard system include files,
 // or project specific include files that are used frequently,
@@ -72,6 +72,8 @@
 #include <windows.h>
 #include <share.h>
 #include <shlobj.h>
+#include <userenv.h>
+#include <aclapi.h>
 
 #if !defined(__CYGWIN32__) || defined(USE_WINSOCK)
 
@@ -236,6 +238,9 @@ extern "C" {
 #endif
 void __cdecl _fpreset (void);
 void __cdecl fpreset (void);
+#define SetClassLongPtr SetClassLong
+#define GCLP_HICON GCL_HICON
+#define GCLP_HICONSM GCL_HICONSM
 #ifdef __cplusplus
 }
 #endif
