@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _COMMON_DEFS_
 #define _COMMON_DEFS_
@@ -111,6 +111,7 @@ enum SUSPEND_REASON {
     SUSPEND_REASON_DISK_SIZE = 32,
     SUSPEND_REASON_CPU_USAGE_LIMIT = 64,
     SUSPEND_REASON_NO_RECENT_INPUT = 128,
+    SUSPEND_REASON_INITIAL_DELAY = 256,
 };
 
 // States of a result on a client.
@@ -176,6 +177,7 @@ struct VERSION_INFO {
     int major;
     int minor;
     int release;
+    bool prerelease;
     int parse(MIOFILE&); 
     void write(MIOFILE&); 
     bool greater_than(VERSION_INFO&);
@@ -186,8 +188,12 @@ struct VERSION_INFO {
 #define REG_BLANK_NAME      "Blank"
 #define REG_BLANK_TIME      "Blank Time"
 #define REG_STARTUP_NAME    "BOINC"
+#define CLIENT_AUTH_FILENAME    "client_auth.xml"
 #else
-#define LOCK_FILE_NAME              "lockfile"
+#define LOCK_FILE_NAME      "lockfile"
 #endif
 
+#define GRAPHICS_APP_FILENAME "graphics_app"
+#define ASSIGNED_WU_STR "asgn"
+
 #endif
