@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _BOINC_DIAGNOSTICS_
 #define _BOINC_DIAGNOSTICS_
@@ -60,6 +60,8 @@
 //
 #define BOINC_DIAG_STDERR                  "stderr"
 #define BOINC_DIAG_STDOUT                  "stdout"
+#define BOINC_DIAG_GFX_STDERR              "stderrgfx"
+#define BOINC_DIAG_GFX_STDOUT              "stdoutgfx"
 
 
 #ifdef __cplusplus
@@ -69,6 +71,7 @@ extern "C" {
 
 // These are functions common to all platforms
 extern int boinc_init_diagnostics( int flags );
+extern int boinc_init_graphics_diagnostics( int flags );
 extern int boinc_install_signal_handlers();
 extern int boinc_finish_diag();
 
@@ -97,10 +100,7 @@ extern void diagnostics_set_max_file_sizes(int stdout_size, int stderr_size);
 extern int diagnostics_init_thread_list();
 extern int diagnostics_finish_thread_list();
 extern int diagnostics_update_thread_list();
-extern int diagnostics_set_thread_name( char* name );
 extern int diagnostics_set_thread_exempt_suspend();
-extern int diagnostics_set_thread_graphics();
-extern int diagnostics_set_thread_worker();
 
 // Message Monitoring
 extern int diagnostics_init_message_monitor();
