@@ -15,11 +15,16 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _FILESYS_
 #define _FILESYS_
 
+#define FILE_RETRY_INTERVAL 5
+    // On Windows, retry for this period of time, since some other program
+    // (virus scan, defrag, index) may have the file open.
+
+
 #if defined(_WIN32) && !defined(__CYGWIN32__)
 #else
 #include <stdio.h>
@@ -32,19 +37,11 @@
 
 #endif /* !WIN32 */
 
-#define FILE_RETRY_INTERVAL 5
-    // On Windows, retry for this period of time, since some other program
-    // (virus scan, defrag, index) may have the file open.
-
 #ifdef __cplusplus
 extern "C" {
 #endif
   extern int boinc_delete_file(const char*);
-  extern int delete_project_owned_file(const char* path, bool retry);
-  extern int remove_project_owned_dir(const char* name);
   extern int boinc_touch_file(const char *path);
-  extern int clean_out_dir(const char*);
-  extern int client_clean_out_dir(const char*);
   extern FILE* boinc_fopen(const char* path, const char* mode);
   extern int boinc_copy(const char* orig, const char* newf);
   extern int boinc_rename(const char* old, const char* newf);
@@ -53,9 +50,6 @@ extern "C" {
   extern int boinc_chown(const char*, gid_t);
 #endif
   extern int boinc_rmdir(const char*);
-#ifdef SANDBOX
-  extern int boinc_exec(char* util_filename, char* cmdline);
-#endif
   extern int remove_project_owned_file_or_dir(const char* path);
   extern void boinc_getcwd(char*);
   extern void relative_to_absolute(const char* relname, char* path);
@@ -63,8 +57,10 @@ extern "C" {
   extern char boinc_failed_file[256];
   extern int is_file(const char* path);
   extern int is_dir(const char* path);
+  extern int is_symlink(const char* path);
   extern int boinc_truncate(const char*, double);
   extern int boinc_file_exists(const char* path);
+  extern int boinc_file_or_symlink_exists(const char* path);
 
 #ifdef __cplusplus
 }
@@ -74,8 +70,9 @@ extern "C" {
 #ifdef __cplusplus
 
 extern int file_size(const char*, double&);
+extern int clean_out_dir(const char*);
 extern int dir_size(const char* dirpath, double&, bool recurse=true);
-extern int get_filesystem_info(double& total, double& free);
+extern int get_filesystem_info(double& total, double& free, char* path=".");
 
 // TODO TODO TODO
 // remove this code - the DirScanner class does the same thing.
