@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 // a C++ interface to BOINC GUI RPC
 
@@ -150,6 +150,7 @@ class APP_VERSION {
 public:
     std::string app_name;
     int version_num;
+    std::string plan_class;
     APP* app;
     PROJECT* project;
 
@@ -214,6 +215,8 @@ public:
     bool too_large;
     bool needs_shmem;
     bool edf_scheduled;
+    std::string graphics_exec_path;
+    std::string slot_path;
 
     APP* app;
     WORKUNIT* wup;
@@ -307,6 +310,7 @@ public:
 
     GLOBAL_PREFS global_prefs;  // working prefs, i.e. network + override
     VERSION_INFO version_info;  // populated only if talking to pre-5.6 CC
+    bool executing_as_daemon;   // true if Client is running as a service / daemon
 
     CC_STATE();
     ~CC_STATE();
@@ -353,7 +357,7 @@ struct DISK_USAGE {
     double d_free;
     double d_boinc;     // amount used by BOINC itself, not projects
 
-    DISK_USAGE(){}
+    DISK_USAGE(){clear();}
     ~DISK_USAGE();
 
     void print();
@@ -534,7 +538,9 @@ public:
     RPC_CLIENT();
     ~RPC_CLIENT();
     int init(const char* host, int port=0);
-    int init_asynch(const char* host, double timeout, bool retry);
+    int init_asynch(
+        const char* host, double timeout, bool retry, int port=GUI_RPC_PORT
+    );
         // timeout == how long to wait until give up
         //    If the caller (i.e. BOINC Manager) just launched the core client,
         //    this should be large enough to allow the process to
@@ -567,10 +573,7 @@ public:
         // otherwise, after duration expires,
         // restore last permanent mode
     int set_network_mode(int mode, double duration);
-    int get_screensaver_mode(int& status);
-    int set_screensaver_mode(
-        bool enabled, double blank_time, DISPLAY_INFO&
-    );
+    int get_screensaver_tasks(int& suspend_reason, RESULTS&);
     int run_benchmarks();
     int set_proxy_settings(GR_PROXY_INFO&);
     int get_proxy_settings(GR_PROXY_INFO&);
