@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _BOINC_MSG_LOG_H_
 #define _BOINC_MSG_LOG_H_
@@ -35,19 +35,20 @@
 #endif
 
 #ifdef _USING_FCGI_
-#define __attribute__(x) /*nothing*/
+#define __attribute__(x) //nothing
 #endif
 
 class MSG_LOG {
+public:
     int debug_level;
-    int indent_level;
     char spaces[80];
     FILE* output;
-public:
+    int indent_level;
     int pid;
 
     MSG_LOG(FILE* output);
     virtual ~MSG_LOG(){}
+
     void enter_level(int = 1);
     void leave_level() { enter_level(-1); }
     MSG_LOG& operator++() { enter_level(); return *this; }
