@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef PARSE_H
 #define PARSE_H
@@ -23,12 +23,18 @@
 #ifdef _WIN32
 #include "boinc_win.h"
 #else
-#include <cstdio>
-#include <cstdlib>
-#include <string>
+#include "config.h"
+#include <stdio.h>
+#include <stdlib.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
 #include <math.h>
-#ifdef solaris
+#ifdef HAVE_IEEEFP_H
 #include <ieeefp.h>
+extern "C" {
+int finite(double);
+}
 #endif
 #endif
 
