@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _PREFS_
 #define _PREFS_
@@ -51,7 +51,7 @@ struct GLOBAL_PREFS_MASK {
     bool dont_verify_images;
     bool work_buf_min_days;
     bool work_buf_additional_days;
-    bool max_cpus;
+    bool max_ncpus_pct;
     bool cpu_scheduling_period_minutes;
     bool disk_interval;
     bool disk_max_used_gb;
@@ -80,7 +80,7 @@ public:
     enum TimeMode {
         Always = 7000,
         Never,
-        Between,
+        Between
     };
     TIME_SPAN()
         : start_hour(0), end_hour(0) {}
@@ -130,7 +130,7 @@ public:
 
 
 struct GLOBAL_PREFS {
-    int mod_time;
+    double mod_time;
     bool run_on_batteries;
         // poorly named; what it really means is:
         // if false, suspend while on batteries
@@ -145,7 +145,7 @@ struct GLOBAL_PREFS {
     TIME_PREFS net_times;
     double work_buf_min_days;
     double work_buf_additional_days;
-    int max_cpus;
+    double max_ncpus_pct;
     double cpu_scheduling_period_minutes;
     double disk_interval;
     double disk_max_used_gb;
