@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 // platform-independent interface to shared memory
 
@@ -27,48 +27,34 @@
 #include <sys/shm.h>
 #endif
 
+// create_shmem(): create a shared-memory segment of the given size.
+// attach_shmem(): attach to a shared-memory segment
+// detach_shmem(): detach from a shared-mem segment.
+//    Once all processes have detached, the segment is destroyed
+// The above with _mmap: V6 mmap() shared memory for Unix/Linux/Mac
+
 #ifdef _WIN32
-
-// create a shared-memory segment of the given size.
-//
-HANDLE create_shmem(LPCTSTR seg_name, int size, void** pp, bool disable_mapview);
-
-// attach to a shared-memory segment
-//
+HANDLE create_shmem(
+    LPCTSTR seg_name, int size, void** pp, bool try_global=true
+);
 HANDLE attach_shmem(LPCTSTR seg_name, void** pp);
-
-// detach from a shared-mem segment.
-// Once all processes have detached, the segment is destroyed
-//
 int detach_shmem(HANDLE hSharedMem, void* p);
-
 #else
-
-// create a shared-memory segment of the given size.
-//
+#ifndef __EMX__
+#define MMAPPED_FILE_NAME    "boinc_mmap_file"
+extern int create_shmem_mmap(char *path, size_t size, void** pp);
+extern int attach_shmem_mmap(char *path, void** pp);
+extern int detach_shmem_mmap(void* p, size_t size);
+#endif
 extern int create_shmem(key_t, int size, gid_t gid, void**);
-
+extern int attach_shmem(key_t, void**);
+extern int detach_shmem(void*);
+extern int shmem_info(key_t key);
 // Destroy a shared-memory segment.
 // If there are attachments to it,
 // print a message in a loop until the attachments are gone
 //
 extern int destroy_shmem(key_t);
+#endif      // !defined(_WIN32)
 
-// attach to a shared-memory segment
-//
-extern int attach_shmem(key_t, void**);
-
-// detach from a shared-mem segment
-//
-extern int detach_shmem(void*);
-
-extern int shmem_info(key_t key);
-
-#ifndef __EMX__
-// For testing on Apple, Linux, UNIX systems with limited number 
-// of shared memory segments per process and / or system-wide
-void stress_shmem(short reduce_by);
-#endif
-
-#endif
-#endif
+#endif      // BOINC_SHMEM_H
