@@ -15,11 +15,20 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #pragma once
 
 extern BOOL IsWindows2000Compatible();
 extern BOOL IsTerminalServicesEnabled();
-extern BOOL ValidateProductSuite (LPSTR SuiteName);
-extern BOOL TerminateProcessById (DWORD dwProcessId);
+extern BOOL ValidateProductSuite(LPSTR SuiteName);
+extern BOOL TerminateProcessById(DWORD dwProcessId);
+extern BOOL AddAceToWindowStation(HWINSTA hwinsta, PSID psid);
+extern BOOL AddAceToDesktop(HDESK hdesk, PSID psid);
+extern BOOL GetAccountSid(
+    LPCTSTR SystemName,         // where to lookup account
+    LPCTSTR AccountName,        // account of interest
+    PSID *Sid                   // resultant buffer containing SID
+);
+extern int suspend_or_resume_threads(DWORD pid, bool resume);
+extern void chdir_to_data_dir();
