@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include <cstdio>
 
@@ -23,5 +23,5 @@
 #include "server_types.h"
 
 extern void handle_request(
-    FILE* fin, FILE* fout, SCHED_SHMEM&, char* code_sign_key
+    FILE* fin, FILE* fout, char* code_sign_key
 );
