@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include "boinc_db.h"
 #include "sched_config.h"
@@ -52,9 +52,12 @@
     // client asked for work but we didn't send any,
     // because of a reason not easily changed
     // (like wrong kind of computer)
-#define DELAY_NO_WORK_CACHE         20*60
+#define DELAY_NO_WORK_CACHE         0
     // client asked for work but we didn't send any,
     // because user had too many results in cache.
+    // Rely on client's exponential backoff
+#define DELAY_MAX (2*86400)
+    // maximum delay request
 
 extern SCHED_CONFIG config;
 extern GUI_URLS gui_urls;
@@ -62,6 +65,13 @@ extern PROJECT_FILES project_files;
 extern key_t sema_key;
 extern int g_pid;
 extern SCHED_SHMEM* ssp;
+extern bool batch;
+    // read sequences of requests from stdin (for testing)
+extern bool mark_jobs_done;
+    // mark jobs as successfully done immediately after send
+    // (for debugging/testing)
 
-extern void send_message(const char*, int delay, bool send_header);
 extern int open_database();
+extern void debug_sched(
+    SCHEDULER_REQUEST&, SCHEDULER_REPLY&, const char *trigger
+);
