@@ -15,14 +15,14 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-extern void send_work_locality(
-    SCHEDULER_REQUEST&, SCHEDULER_REPLY&, PLATFORM_LIST&, SCHED_SHMEM&
-);
+extern void send_work_locality(SCHEDULER_REQUEST&, SCHEDULER_REPLY&);
 
 extern int decrement_disk_space_locality(
     WORKUNIT& wu, SCHEDULER_REQUEST& request, SCHEDULER_REPLY& reply
 );
 
 extern int delete_file_from_host(SCHEDULER_REQUEST&, SCHEDULER_REPLY&);
+
+extern void send_file_deletes(SCHEDULER_REQUEST&, SCHEDULER_REPLY&);
