@@ -15,25 +15,34 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _BOINC_SCHED_MSGS_H_
 #define _BOINC_SCHED_MSGS_H_
 
 #include "msg_log.h"
 
+#ifdef _USING_FCGI_
+#include "fcgi_stdio.h"
+#endif
+
+enum { MSG_CRITICAL=1, MSG_NORMAL, MSG_DEBUG };
+
 class SCHED_MSG_LOG : public MSG_LOG {
     const char* v_format_kind(int kind) const;
     bool v_message_wanted(int kind) const;
 public:
     int debug_level;
-    enum Kind {
-        MSG_CRITICAL=1,
-        MSG_NORMAL=2,
-        MSG_DEBUG=3
-    };
+    enum { MSG_CRITICAL=1, MSG_NORMAL, MSG_DEBUG };
     SCHED_MSG_LOG(): MSG_LOG(stderr) { debug_level = MSG_NORMAL; }
     void set_debug_level(int new_level) { debug_level = new_level; }
+    void set_indent_level(const int new_indent_level);
+#ifdef _USING_FCGI_
+    ~SCHED_MSG_LOG();
+    void redirect(FILE* f);
+    void close();
+    void flush();
+#endif
 };
 
 extern SCHED_MSG_LOG log_messages;
