@@ -15,28 +15,19 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-extern int get_app_version(
-    WORKUNIT& wu, APP* &app, APP_VERSION* &avp,
-    SCHEDULER_REQUEST& sreq, SCHEDULER_REPLY& reply,
-    PLATFORM_LIST& platforms, SCHED_SHMEM& ss
-);
-
-extern int send_work(
-    SCHEDULER_REQUEST&, SCHEDULER_REPLY&, PLATFORM_LIST&, SCHED_SHMEM&
-);
+extern void send_work(SCHEDULER_REQUEST&, SCHEDULER_REPLY&);
 
 extern int add_result_to_reply(
     DB_RESULT& result, WORKUNIT& wu, SCHEDULER_REQUEST&, SCHEDULER_REPLY&,
-    PLATFORM_LIST&, APP* app, APP_VERSION* avp
+    BEST_APP_VERSION* bavp
 );
 
 extern bool anonymous(PLATFORM*);
 
-extern bool find_app_version(
-    WORK_REQ& wreq, WORKUNIT& wu, PLATFORM_LIST& platform, SCHED_SHMEM& ss,
-    APP*& app, APP_VERSION*& avp
+extern BEST_APP_VERSION* get_app_version(
+    SCHEDULER_REQUEST&, SCHEDULER_REPLY&, WORKUNIT&
 );
 
 extern bool app_core_compatible(WORK_REQ& wreq, APP_VERSION& av);
@@ -51,9 +42,10 @@ extern bool app_core_compatible(WORK_REQ& wreq, APP_VERSION& av);
 #define INFEASIBLE_WORKLOAD 6
 #define INFEASIBLE_DUP      7
 #define INFEASIBLE_HR       8
+#define INFEASIBLE_BANDWIDTH 9
 
-extern int wu_is_infeasible(
-    WORKUNIT&, SCHEDULER_REQUEST&, SCHEDULER_REPLY&, APP*
+extern int wu_is_infeasible_fast(
+    WORKUNIT&, SCHEDULER_REQUEST&, SCHEDULER_REPLY&, APP&
 );
  
 extern double max_allowable_disk(SCHEDULER_REQUEST&, SCHEDULER_REPLY&);
@@ -66,4 +58,5 @@ extern int update_wu_transition_time(WORKUNIT wu, time_t x);
 
 extern void lock_sema();
 extern void unlock_sema();
-
+extern const char* infeasible_string(int);
+extern bool app_not_selected(WORKUNIT&, SCHEDULER_REQUEST&, SCHEDULER_REPLY&);
