@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef SCHED_UTIL_H
 #define SCHED_UTIL_H
@@ -76,7 +76,6 @@ extern int mylockf(int fd);
 //
 extern double fpops_to_credit(double fpops, double intops); 
 
-extern int count_unsent_results(int&);
-extern int count_workunits(int&, const char* query="");
-
+extern int count_workunits(int&, const char* query);
+extern int count_unsent_results(int&, int appid);
 #endif
