@@ -15,7 +15,7 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef H_VALIDATE_UTIL
 #define H_VALIDATE_UTIL
@@ -27,8 +27,11 @@
 
 extern int get_output_file_path(RESULT const& result, std::string& path);
 extern int get_output_file_paths(RESULT const& result, std::vector<std::string>&);
+extern int get_logical_name(RESULT const& result, std::string const& path, std::string& name);
 extern double median_mean_credit(WORKUNIT&, std::vector<RESULT>& results);
 extern double get_credit_from_wu(WORKUNIT&, std::vector<RESULT>& results);
+extern double stddev_credit(WORKUNIT&, std::vector<RESULT>& results);
+extern double two_credit(WORKUNIT&, std::vector<RESULT>& results);
 extern int update_credit_per_cpu_sec(
     double credit, double cpu_time, double& credit_per_cpu_sec
 );
