@@ -3,7 +3,7 @@
 
 #include <vector>
 
-extern int init_result(RESULT const&, void*&);
+extern int init_result(RESULT&, void*&);
 extern int compare_results(RESULT &, void*, RESULT const&, void*, bool&);
 extern int cleanup_result(RESULT const&, void*);
 extern double compute_granted_credit(WORKUNIT&, std::vector<RESULT>& results);
