@@ -15,11 +15,13 @@
 // To view the GNU Lesser General Public License visit
 // http://www.gnu.org/copyleft/lesser.html
 // or write to the Free Software Foundation, Inc.,
-// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef H_BACKEND_LIB
 #define H_BACKEND_LIB
 
+#include <limits.h>
+
 #include "crypt.h"
 #include "sched_config.h"
 #include "boinc_db.h"
@@ -40,6 +42,16 @@ extern int read_filename(const char* path, char* buf, int len);
 extern void initialize_result(DB_RESULT&, DB_WORKUNIT&);
 
 extern int create_result(
+    WORKUNIT&,
+    char* result_template_filename, 
+    char* suffix,
+    R_RSA_PRIVATE_KEY& key, 
+    SCHED_CONFIG& config,
+    char* query_string=0,
+    int priority_increase=0
+);
+
+extern int create_result_ti(
     TRANSITIONER_ITEM&,
     char* result_template_filename, 
     char* suffix,
